pub(crate) fn declared_flowctrl(
params: &NetParameters,
) -> Option<(Protocols, u8)>Expand description
Return the flow control information that we should include in our hsdesc.
pub(crate) fn declared_flowctrl(
params: &NetParameters,
) -> Option<(Protocols, u8)>Return the flow control information that we should include in our hsdesc.