dos_params_from_token_bucket_config

Function dos_params_from_token_bucket_config 

fn dos_params_from_token_bucket_config(
    c: &TokenBucketConfig,
) -> Result<DosParams, ConfigBuildError>
Helper: Try to create a DosParams from a given token bucket configuration. Give an error if the value is out of range.

This is a separate function so we can use the same logic when validating and when making the extension object.