extend_key_map

Function extend_key_map 

fn extend_key_map(
    key_map: &mut BTreeMap<HsClientNickname, HsClientDescEncKey>,
    keys: impl IntoIterator<Item = (HsClientNickname, HsClientDescEncKey)>,
)
Helper for extending a key map with additional keys.

Logs a warning if any of the keys are already present in the map.