pub struct RestrictedDiscoveryConfig {
pub(crate) enabled: bool,
watch_configuration: bool,
key_dirs: DirectoryKeyProviderList,
static_keys: StaticKeyProvider,
}Expand description
Configuration for enabling restricted discovery mode.
Client nickname uniqueness
The client nicknames specified in key_dirs and static_keys
must be unique. Any nickname occurring in static_keys must not
already have an entry in any of the configured key_dirs,
and any one nickname must not occur in more than one of the key_dirs.
Violating this rule will cause the additional keys to be ignored. If there are multiple entries for the same nickname, the entry with the highest precedence will be used, and all the others will be ignored. The precedence rules are as follows:
- the
static_keystake precedence over the keys fromkey_dirs - the ordering of the directories in
key_dirsrepresents the order of precedence
Reloading the configuration
Currently, the static_keys and key_dirs directories will not be monitored for updates,
even when automatic config reload is enabled. We hope to change that in the future.
In the meantime, you will need to restart your service every time you update
its restricted discovery settings in order for the changes to be applied.
See the module-level documentation for more details.
Fields
enabled: boolWhether to enable restricted discovery mode.
Services running in restricted discovery mode are only discoverable by the configured clients.
Can only be enabled if the restricted-discovery feature is enabled.
If you enable this, you must also specify the authorized clients (via static_keys),
or the directories where the authorized client keys should be read from (via key_dirs).
Restricted discovery mode is disabled by default.
watch_configuration: boolIf true, the provided key_dirs will be watched for changes.
key_dirs: DirectoryKeyProviderListDirectories containing the client keys, each in the
descriptor:x25519:<base32-encoded-x25519-public-key> format.
Each file in this directory must have a file name of the form <nickname>.auth,
where <nickname> is a valid HsClientNickname.
static_keys: StaticKeyProviderA static mapping from client nicknames to keys.
Each client key must be in the descriptor:x25519:<base32-encoded-x25519-public-key>
format.
Implementations
Sourceimpl RestrictedDiscoveryConfig
impl RestrictedDiscoveryConfig
Sourcepub fn builder() -> RestrictedDiscoveryConfigBuilder
pub fn builder() -> RestrictedDiscoveryConfigBuilder
Return a new [RestrictedDiscoveryConfig Builder] to construct an instance of this type.
Sourceimpl RestrictedDiscoveryConfig
impl RestrictedDiscoveryConfig
Sourcepub fn enabled(&self) -> &bool
pub fn enabled(&self) -> &bool
Method borrowing RestrictedDiscoveryConfig::enabled field.
Whether to enable restricted discovery mode.
Sourcepub fn watch_configuration(&self) -> bool
pub fn watch_configuration(&self) -> bool
Method returning copy of RestrictedDiscoveryConfig::watch_configuration field.
If true, the provided key_dirs will be watched for changes.
Sourcepub fn watch_configuration_mut(&mut self) -> &mut bool
pub fn watch_configuration_mut(&mut self) -> &mut bool
Method returning mutable borrow of RestrictedDiscoveryConfig::watch_configuration field.
If true, the provided key_dirs will be watched for changes.
Sourcepub fn key_dirs(&self) -> &DirectoryKeyProviderList
pub fn key_dirs(&self) -> &DirectoryKeyProviderList
Method borrowing RestrictedDiscoveryConfig::key_dirs field.
Directories containing the client keys, each in the
Sourcepub fn static_keys(&self) -> &StaticKeyProvider
pub fn static_keys(&self) -> &StaticKeyProvider
Method borrowing RestrictedDiscoveryConfig::static_keys field.
A static mapping from client nicknames to keys.
Sourceimpl RestrictedDiscoveryConfig
impl RestrictedDiscoveryConfig
Sourcepub(crate) fn read_keys(
&self,
path_resolver: &CfgPathResolver,
) -> Option<BTreeMap<HsClientNickname, HsClientDescEncKey>>
pub(crate) fn read_keys( &self, path_resolver: &CfgPathResolver, ) -> Option<BTreeMap<HsClientNickname, HsClientDescEncKey>>
Read the client keys from all the configured key providers.
Returns None if restricted mode is disabled.
When reconfiguring a RunningOnionService,
call this function to obtain an up-to-date view of the authorized clients.
Note: if there are multiple entries for the same HsClientNickname,
only one of them will be used (the others are ignored).
The deduplication logic is as follows:
- the
static_keystake precedence over the keys fromkey_dirs - the ordering of the directories in
key_dirsrepresents the order of precedence