pub struct RestrictedDiscoveryConfigBuilder {
enabled: Option<bool>,
watch_configuration: Option<bool>,
key_dirs: DirectoryKeyProviderListBuilder,
static_keys: StaticKeyProviderBuilder,
}Expand description
A builder to create an instance of RestrictedDiscoveryConfig.
Fields
enabled: Option<bool>In-progress value for enabled.
watch_configuration: Option<bool>In-progress value for watch_configuration.
key_dirs: DirectoryKeyProviderListBuilderIn-progress value for key_dirs.
static_keys: StaticKeyProviderBuilderIn-progress value for static_keys.
Implementations
Sourceimpl RestrictedDiscoveryConfigBuilder
impl RestrictedDiscoveryConfigBuilder
Sourcepub fn enabled(&mut self, val: bool) -> &mut Self
pub fn enabled(&mut self, val: bool) -> &mut Self
Provide a value for enabled.
If no value is provided for enabled, build will use Default::default().
enabled
Whether to enable restricted discovery mode.
Services running in restricted discovery mode are only discoverable by the configured clients.
Can only be enabled if the restricted-discovery feature is enabled.
If you enable this, you must also specify the authorized clients (via static_keys),
or the directories where the authorized client keys should be read from (via key_dirs).
Restricted discovery mode is disabled by default.
Sourcepub fn watch_configuration(&mut self, val: bool) -> &mut Self
pub fn watch_configuration(&mut self, val: bool) -> &mut Self
Sourcepub fn key_dirs(&mut self) -> &mut DirectoryKeyProviderListBuilder
pub fn key_dirs(&mut self) -> &mut DirectoryKeyProviderListBuilder
Return a mutable reference to the inner builder for key_dirs.
key_dirs
Directories containing the client keys, each in the
descriptor:x25519:<base32-encoded-x25519-public-key> format.
Each file in this directory must have a file name of the form <nickname>.auth,
where <nickname> is a valid HsClientNickname.
Sourcepub fn static_keys(&mut self) -> &mut StaticKeyProviderBuilder
pub fn static_keys(&mut self) -> &mut StaticKeyProviderBuilder
Return a mutable reference to the inner builder for static_keys.
static_keys
A static mapping from client nicknames to keys.
Each client key must be in the descriptor:x25519:<base32-encoded-x25519-public-key>
format.
Sourceimpl RestrictedDiscoveryConfigBuilder
impl RestrictedDiscoveryConfigBuilder
Sourcepub fn build(&self) -> Result<RestrictedDiscoveryConfig, ConfigBuildError>
pub fn build(&self) -> Result<RestrictedDiscoveryConfig, ConfigBuildError>
Try to construct a new RestrictedDiscoveryConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl RestrictedDiscoveryConfigBuilder
impl RestrictedDiscoveryConfigBuilder
Sourcefn post_build_validate(
config: RestrictedDiscoveryConfig,
) -> Result<RestrictedDiscoveryConfig, ConfigBuildError>
fn post_build_validate( config: RestrictedDiscoveryConfig, ) -> Result<RestrictedDiscoveryConfig, ConfigBuildError>
Build the RestrictedDiscoveryConfig.
Returns an error if:
- restricted mode is enabled but the
restricted-discoveryfeature is not enabled - restricted mode is enabled but no client key providers are configured
- restricted mode is disabled, but some client key providers are configured