pub struct OnionServiceConfig {
pub(crate) nickname: HsNickname,
pub(crate) enabled: bool,
pub(crate) num_intro_points: u8,
rate_limit_at_intro: Option<TokenBucketConfig>,
max_concurrent_streams_per_circuit: u32,
pub(crate) enable_pow: bool,
pub(crate) pow_rend_queue_depth: usize,
pub(crate) restricted_discovery: RestrictedDiscoveryConfig,
disable_pow_compilation: bool,
}Expand description
Configuration for one onion service.
Fields
nickname: HsNicknameThe nickname used to look up this service’s keys, state, configuration, etc.
enabled: boolIf true, this service will be started. It should be available to commands that don’t require it to start regardless.
num_intro_points: u8Number of intro points; defaults to 3; max 20.
rate_limit_at_intro: Option<TokenBucketConfig>A rate-limit on the acceptable rate of introduction requests.
We send this to the introduction point to configure how many introduction requests it sends us. If this is not set, the introduction point chooses a default based on the current consensus.
We do not enforce this limit ourselves.
This configuration is sent as a DOS_PARAMS extension, as documented in
https://spec.torproject.org/rend-spec/introduction-protocol.html#EST_INTRO_DOS_EXT.
max_concurrent_streams_per_circuit: u32How many streams will we allow to be open at once for a single circuit on this service?
If a client attempts to open more than this many streams on a rendezvous circuit, the circuit will be torn down.
Equivalent to C Tor’s HiddenServiceMaxStreamsCloseCircuit option.
enable_pow: boolIf true, we will require proof-of-work when we’re under heavy load.
pow_rend_queue_depth: usizeThe maximum number of entries allowed in the rendezvous request queue when PoW is enabled.
If you are seeing dropped requests, have a bursty traffic pattern, and have some memory to spare, you may want to increase this.
Each request will take a few KB, the default queue is expected to take 32MB at most.
restricted_discovery: RestrictedDiscoveryConfigConfigure restricted discovery mode.
When this is enabled, we encrypt our list of introduction point and keys so that only clients holding one of the listed keys can decrypt it.
disable_pow_compilation: boolWhether to use the compiled backend for proof-of-work.
Implementations
Sourceimpl OnionServiceConfig
impl OnionServiceConfig
Sourcepub fn builder() -> OnionServiceConfigBuilder
pub fn builder() -> OnionServiceConfigBuilder
Return a new [OnionServiceConfig Builder] to construct an instance of this type.
Sourceimpl OnionServiceConfig
impl OnionServiceConfig
Sourcepub fn nickname(&self) -> &HsNickname
pub fn nickname(&self) -> &HsNickname
Method borrowing OnionServiceConfig::nickname field.
The nickname used to look up this service’s keys, state, configuration, etc.
Sourcepub fn enabled(&self) -> &bool
pub fn enabled(&self) -> &bool
Method borrowing OnionServiceConfig::enabled field.
If true, this service will be started. It should be available to
Sourcepub fn num_intro_points(&self) -> &u8
pub fn num_intro_points(&self) -> &u8
Method borrowing OnionServiceConfig::num_intro_points field.
Number of intro points; defaults to 3; max 20.
Sourcepub fn rate_limit_at_intro(&self) -> &Option<TokenBucketConfig>
pub fn rate_limit_at_intro(&self) -> &Option<TokenBucketConfig>
Method borrowing OnionServiceConfig::rate_limit_at_intro field.
A rate-limit on the acceptable rate of introduction requests.
Sourcepub fn max_concurrent_streams_per_circuit(&self) -> &u32
pub fn max_concurrent_streams_per_circuit(&self) -> &u32
Method borrowing OnionServiceConfig::max_concurrent_streams_per_circuit field.
How many streams will we allow to be open at once for a single circuit on
Sourcepub fn enable_pow(&self) -> &bool
pub fn enable_pow(&self) -> &bool
Method borrowing OnionServiceConfig::enable_pow field.
If true, we will require proof-of-work when we’re under heavy load.
Sourcepub fn pow_rend_queue_depth(&self) -> &usize
pub fn pow_rend_queue_depth(&self) -> &usize
Method borrowing OnionServiceConfig::pow_rend_queue_depth field.
The maximum number of entries allowed in the rendezvous request queue when PoW is enabled.
Sourcepub fn restricted_discovery(&self) -> &RestrictedDiscoveryConfig
pub fn restricted_discovery(&self) -> &RestrictedDiscoveryConfig
Method borrowing OnionServiceConfig::restricted_discovery field.
Configure restricted discovery mode.
Sourcepub fn restricted_discovery_mut(&mut self) -> &mut RestrictedDiscoveryConfig
pub fn restricted_discovery_mut(&mut self) -> &mut RestrictedDiscoveryConfig
Method returning mutable borrow of OnionServiceConfig::restricted_discovery field.
Configure restricted discovery mode.
Sourcepub fn disable_pow_compilation(&self) -> &bool
pub fn disable_pow_compilation(&self) -> &bool
Method borrowing OnionServiceConfig::disable_pow_compilation field.
Whether to use the compiled backend for proof-of-work.
Sourceimpl OnionServiceConfig
impl OnionServiceConfig
Sourcepub(crate) fn for_transition_to(
&self,
other: OnionServiceConfig,
how: Reconfigure,
) -> Result<OnionServiceConfig, ReconfigureError>
pub(crate) fn for_transition_to( &self, other: OnionServiceConfig, how: Reconfigure, ) -> Result<OnionServiceConfig, ReconfigureError>
Check whether an onion service running with this configuration can
switch over other according to the rules of how.
Sourcepub(crate) fn dos_extension(&self) -> Result<Option<DosParams>, FatalError>
pub(crate) fn dos_extension(&self) -> Result<Option<DosParams>, FatalError>
Return the DosParams extension we should send for this configuration, if any.
Sourcepub(crate) fn filter_settings(&self) -> RequestFilter
pub(crate) fn filter_settings(&self) -> RequestFilter
Return a RequestFilter based on this configuration.