OnionServiceConfigBuilder

Struct OnionServiceConfigBuilder 

pub struct OnionServiceConfigBuilder {
    nickname: Option<HsNickname>,
    enabled: Option<bool>,
    num_intro_points: Option<u8>,
    rate_limit_at_intro: Option<Option<TokenBucketConfig>>,
    max_concurrent_streams_per_circuit: Option<u32>,
    enable_pow: Option<bool>,
    pow_rend_queue_depth: Option<usize>,
    restricted_discovery: RestrictedDiscoveryConfigBuilder,
    disable_pow_compilation: Option<bool>,
}
A builder to create an instance of OnionServiceConfig.

Fields

nickname: Option<HsNickname>

In-progress value for nickname.

See OnionServiceConfig.nickname

enabled: Option<bool>

In-progress value for enabled.

See OnionServiceConfig.enabled

num_intro_points: Option<u8>

In-progress value for num_intro_points.

See OnionServiceConfig.num_intro_points

rate_limit_at_intro: Option<Option<TokenBucketConfig>>

In-progress value for rate_limit_at_intro.

See OnionServiceConfig.rate_limit_at_intro

max_concurrent_streams_per_circuit: Option<u32>

In-progress value for max_concurrent_streams_per_circuit.

See OnionServiceConfig.max_concurrent_streams_per_circuit

enable_pow: Option<bool>

In-progress value for enable_pow.

See OnionServiceConfig.enable_pow

pow_rend_queue_depth: Option<usize>

In-progress value for pow_rend_queue_depth.

See OnionServiceConfig.pow_rend_queue_depth

restricted_discovery: RestrictedDiscoveryConfigBuilder

In-progress value for restricted_discovery.

See OnionServiceConfig.restricted_discovery

disable_pow_compilation: Option<bool>

In-progress value for disable_pow_compilation.

See OnionServiceConfig.disable_pow_compilation

Implementations

Source

impl OnionServiceConfigBuilder

pub fn nickname(&mut self, val: HsNickname) -> &mut Self

Provide a value for nickname.

If no value is provided for nickname, build will fail with an error.

nickname

The nickname used to look up this service’s keys, state, configuration, etc.

pub fn enabled(&mut self, val: bool) -> &mut Self

Provide a value for enabled.

If no value is provided for enabled, build will use Default::default().

enabled

If true, this service will be started. It should be available to commands that don’t require it to start regardless.

pub fn num_intro_points(&mut self, val: u8) -> &mut Self

Provide a value for num_intro_points.

If no value is provided for num_intro_points, build will use Default::default().

num_intro_points

Number of intro points; defaults to 3; max 20.

pub fn rate_limit_at_intro( &mut self, val: impl PossiblyOption<TokenBucketConfig>, ) -> &mut Self

Provide a value for rate_limit_at_intro.

If no value is provided for rate_limit_at_intro, build will use Default::default(). For convenience, this function accepts both TokenBucketConfig and Option<$T> .

rate_limit_at_intro

A rate-limit on the acceptable rate of introduction requests.

We send this to the introduction point to configure how many introduction requests it sends us. If this is not set, the introduction point chooses a default based on the current consensus.

We do not enforce this limit ourselves.

This configuration is sent as a DOS_PARAMS extension, as documented in https://spec.torproject.org/rend-spec/introduction-protocol.html#EST_INTRO_DOS_EXT.

pub fn max_concurrent_streams_per_circuit(&mut self, val: u32) -> &mut Self

Provide a value for max_concurrent_streams_per_circuit.

If no value is provided for max_concurrent_streams_per_circuit, build will use Default::default().

max_concurrent_streams_per_circuit

How many streams will we allow to be open at once for a single circuit on this service?

If a client attempts to open more than this many streams on a rendezvous circuit, the circuit will be torn down.

Equivalent to C Tor’s HiddenServiceMaxStreamsCloseCircuit option.

pub fn enable_pow(&mut self, val: bool) -> &mut Self

Provide a value for enable_pow.

If no value is provided for enable_pow, build will use Default::default().

enable_pow

If true, we will require proof-of-work when we’re under heavy load.

pub fn pow_rend_queue_depth(&mut self, val: usize) -> &mut Self

Provide a value for pow_rend_queue_depth.

If no value is provided for pow_rend_queue_depth, build will use Default::default().

pow_rend_queue_depth

The maximum number of entries allowed in the rendezvous request queue when PoW is enabled.

If you are seeing dropped requests, have a bursty traffic pattern, and have some memory to spare, you may want to increase this.

Each request will take a few KB, the default queue is expected to take 32MB at most.

pub fn restricted_discovery(&mut self) -> &mut RestrictedDiscoveryConfigBuilder

Return a mutable reference to the inner builder for restricted_discovery.

restricted_discovery

Configure restricted discovery mode.

When this is enabled, we encrypt our list of introduction point and keys so that only clients holding one of the listed keys can decrypt it.

pub fn disable_pow_compilation(&mut self, val: bool) -> &mut Self

Provide a value for disable_pow_compilation.

If no value is provided for disable_pow_compilation, build will use Default::default().

disable_pow_compilation

Whether to use the compiled backend for proof-of-work.

Source

impl OnionServiceConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<OnionServiceConfig, ConfigBuildError>

Try to construct a new OnionServiceConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.

Source

impl OnionServiceConfigBuilder

fn validate(&self) -> Result<(), ConfigBuildError>

Builder helper: check whether the options in this builder are consistent.

pub fn peek_nickname(&self) -> Option<&HsNickname>

Return the configured nickname for this service, if it has one.