#[non_exhaustive]pub enum IntroRequestError {
NetdirUnavailable(Error),
UnsupportedOnionKey,
InvalidRendezvousPoint(VerbatimCircTargetDecodeError),
InvalidHandshake(Error),
InvalidPayload(Error),
InvalidLinkSpecs(ChanTargetDecodeError),
UnsupportedCapability,
Subcredentials(FatalError),
}Expand description
An error produced while trying to process an introduction request we have received from a client via an introduction point.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
We couldn’t get a timely network directory in chosen circuits.
UnsupportedOnionKey
Got an onion key with an unrecognized type (not ntor).
InvalidRendezvousPoint(VerbatimCircTargetDecodeError)
The rendezvous point in the Introduce2 message was invalid and couldn’t be used.
InvalidHandshake(Error)
The handshake (e.g. hs_ntor) in the Introduce2 message was invalid and could not be completed.
InvalidPayload(Error)
The decrypted payload of the Introduce2 message could not be parsed.
InvalidLinkSpecs(ChanTargetDecodeError)
We weren’t able to build a ChanTarget from the Introduce2 message.
UnsupportedCapability
The client requested a capability or combination of capabilities that we don’t support, or don’t support negotiating.
Subcredentials(FatalError)
We weren’t able to obtain the subcredentials for decrypting the Introduce2 message.