pub(crate) enum ShutdownStatus {
Continue,
Terminate,
}Expand description
Return value from one call to the main loop iteration
Used by the publisher reactor and by the IptManager.
Variants
Continue
We should continue to operate this component
Terminate
We should shut down: the service, or maybe the whole process, is shutting down