pub(crate) enum IptStoreError {
Store(Error),
Fatal(FatalError),
}Expand description
An error arising when trying to store introduction points
These don’t escape the crate, except to be logged.
These errors might be fatal, or they might be something we should retry.
Variants
Implementations
Sourceimpl IptStoreError
impl IptStoreError
Sourcepub(crate) fn log_retry_max(
self,
nick: &HsNickname,
) -> Result<Duration, FatalError>
pub(crate) fn log_retry_max( self, nick: &HsNickname, ) -> Result<Duration, FatalError>
Log this error, and report latest time to retry
It’s OK to retry this earlier, if we are prompted somehow by other work; this is the longest time we should wait, so that we poll periodically to see if the situation has improved.
If the operation shouldn’t be retried, the problem was a fatal error, which is simply returned.