pub struct Ed25519Identity {
id: CtByteArray<tor_llcrypto::::pk::ed25519::Ed25519Identity::{constant#0}>,
}Expand description
An unchecked, unvalidated Ed25519 key.
This key is an “identity” in the sense that it identifies (up to) one Ed25519 key. It may also represent the identity for a particular entity, such as a relay or an onion service.
This type is distinct from an Ed25519 PublicKey for several reasons:
- We’re storing it in a compact format, whereas the public key implementation might want an expanded form for more efficient key validation.
- This type hasn’t checked whether the bytes here actually are a valid Ed25519 public key.
Fields
id: CtByteArray<tor_llcrypto::::pk::ed25519::Ed25519Identity::{constant#0}>Implementations
Sourceimpl Ed25519Identity
impl Ed25519Identity
Sourcepub fn new(id: [u8; 32]) -> Ed25519Identity
pub fn new(id: [u8; 32]) -> Ed25519Identity
Construct a new Ed25519 identity from a 32-byte sequence.
This might or might not actually be a valid Ed25519 public key.
use tor_llcrypto::pk::ed25519::{Ed25519Identity, PublicKey};
let bytes = b"klsadjfkladsfjklsdafkljasdfsdsd!";
let id = Ed25519Identity::new(*bytes);
let pk: Result<PublicKey,_> = (&id).try_into();
assert!(pk.is_ok());
let bytes = b"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa";
let id = Ed25519Identity::new(*bytes);
let pk: Result<PublicKey,_> = (&id).try_into();
assert!(pk.is_err());Sourcepub fn from_bytes(id: &[u8]) -> Option<Ed25519Identity>
pub fn from_bytes(id: &[u8]) -> Option<Ed25519Identity>
If id is of the correct length, wrap it in an Ed25519Identity.
Sourcepub fn from_base64(s: &str) -> Option<Ed25519Identity>
pub fn from_base64(s: &str) -> Option<Ed25519Identity>
Decode an Ed25519Identity from a base64-encoded string.
The string must have no padding, spaces, or any extra characters.