pub struct Keypair(pub(crate) SigningKey);Expand description
An Ed25519 keypair.
(We do not provide a separate “private key only” type.)
See ed25519_dalek::SigningKey for more information.
Tuple Fields
0: SigningKeyImplementations
Sourceimpl Keypair
impl Keypair
Sourcepub fn from_bytes(bytes: &[u8; 32]) -> Keypair
pub fn from_bytes(bytes: &[u8; 32]) -> Keypair
Construct an ed25519 keypair from the byte representation of its secret key.
Sourcepub fn as_bytes(&self) -> &[u8; 32]
pub fn as_bytes(&self) -> &[u8; 32]
Return a reference to the byte representation of the secret key in this keypair.
Sourcepub fn to_bytes(&self) -> [u8; 32]
pub fn to_bytes(&self) -> [u8; 32]
Return to the byte representation of the secret key in this keypair.
Sourcepub fn verifying_key(&self) -> PublicKey
pub fn verifying_key(&self) -> PublicKey
Return the public key in this keypair.