pub(crate) enum Cow<'a, B>{
Borrowed(&'a B),
Owned(<B as ToOwned>::Owned),
}Expand description
A clone-on-write smart pointer.
The type Cow is a smart pointer providing clone-on-write functionality: it
can enclose and provide immutable access to borrowed data, and clone the
data lazily when mutation or ownership is required. The type is designed to
work with general borrowed data via the Borrow trait.
Cow implements Deref, which means that you can call
non-mutating methods directly on the data it encloses. If mutation
is desired, to_mut will obtain a mutable reference to an owned
value, cloning if necessary.
If you need reference-counting pointers, note that
Rc::make_mut and
Arc::make_mut can provide clone-on-write
functionality as well.
Examples
use std::borrow::Cow;
fn abs_all(input: &mut Cow<'_, [i32]>) {
for i in 0..input.len() {
let v = input[i];
if v < 0 {
// Clones into a vector if not already owned.
input.to_mut()[i] = -v;
}
}
}
// No clone occurs because `input` doesn't need to be mutated.
let slice = [0, 1, 2];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// Clone occurs because `input` needs to be mutated.
let slice = [-1, 0, 1];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// No clone occurs because `input` is already owned.
let mut input = Cow::from(vec![-1, 0, 1]);
abs_all(&mut input);Another example showing how to keep Cow in a struct:
use std::borrow::Cow;
struct Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
values: Cow<'a, [X]>,
}
impl<'a, X: Clone + 'a> Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
fn new(v: Cow<'a, [X]>) -> Self {
Items { values: v }
}
}
// Creates a container from borrowed values of a slice
let readonly = [1, 2];
let borrowed = Items::new((&readonly[..]).into());
match borrowed {
Items { values: Cow::Borrowed(b) } => println!("borrowed {b:?}"),
_ => panic!("expect borrowed value"),
}
let mut clone_on_write = borrowed;
// Mutates the data from slice into owned vec and pushes a new value on top
clone_on_write.values.to_mut().push(3);
println!("clone_on_write = {:?}", clone_on_write.values);
// The data was mutated. Let's check it out.
match clone_on_write {
Items { values: Cow::Owned(_) } => println!("clone_on_write contains owned data"),
_ => panic!("expect owned data"),
}Variants
Implementations
Sourceimpl<B> Cow<'_, B>
impl<B> Cow<'_, B>
Sourcepub const fn is_borrowed(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_borrowed(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is borrowed, i.e. if to_mut would require additional work.
Note: this is an associated function, which means that you have to call
it as Cow::is_borrowed(&c) instead of c.is_borrowed(). This is so
that there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow = Cow::Borrowed("moo");
assert!(Cow::is_borrowed(&cow));
let bull: Cow<'_, str> = Cow::Owned("...moo?".to_string());
assert!(!Cow::is_borrowed(&bull));Sourcepub const fn is_owned(c: &Cow<'_, B>) -> bool
🔬This is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_owned(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is owned, i.e. if to_mut would be a no-op.
Note: this is an associated function, which means that you have to call
it as Cow::is_owned(&c) instead of c.is_owned(). This is so that
there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow: Cow<'_, str> = Cow::Owned("moo".to_string());
assert!(Cow::is_owned(&cow));
let bull = Cow::Borrowed("...moo?");
assert!(!Cow::is_owned(&bull));1.0.0 · Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);1.0.0 · Sourcepub fn into_owned(self) -> <B as ToOwned>::Owned
pub fn into_owned(self) -> <B as ToOwned>::Owned
Extracts the owned data.
Clones the data if it is not already owned.
Examples
Calling into_owned on a Cow::Borrowed returns a clone of the borrowed data:
use std::borrow::Cow;
let s = "Hello world!";
let cow = Cow::Borrowed(s);
assert_eq!(
cow.into_owned(),
String::from(s)
);Calling into_owned on a Cow::Owned returns the owned data. The data is moved out of the
Cow without being cloned.
use std::borrow::Cow;
let s = "Hello world!";
let cow: Cow<'_, str> = Cow::Owned(String::from(s));
assert_eq!(
cow.into_owned(),
String::from(s)
);Trait Implementations
1.14.0 · Sourceimpl<'a> AddAssign<&'a str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> AddAssign<&'a str> for Cow<'a, str>
no_global_oom_handling only.Sourcefn add_assign(&mut self, rhs: &'a str)
fn add_assign(&mut self, rhs: &'a str)
+= operation. Read moreSourceimpl<'a, A> Arbitrary<'a> for Cow<'a, A>
impl<'a, A> Arbitrary<'a> for Cow<'a, A>
Sourcefn arbitrary(u: &mut Unstructured<'a>) -> Result<Cow<'a, A>, Error>
fn arbitrary(u: &mut Unstructured<'a>) -> Result<Cow<'a, A>, Error>
Self from the given unstructured data. Read moreSourcefn size_hint(depth: usize) -> (usize, Option<usize>)
fn size_hint(depth: usize) -> (usize, Option<usize>)
Unstructured this type
needs to construct itself. Read moreSourcefn try_size_hint(
depth: usize,
) -> Result<(usize, Option<usize>), MaxRecursionReached>
fn try_size_hint( depth: usize, ) -> Result<(usize, Option<usize>), MaxRecursionReached>
Unstructured this type
needs to construct itself. Read moreSourcefn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
fn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
Self from the entirety of the given
unstructured data. Read moreSourceimpl<'a> Arg for Cow<'a, CStr>
Available on crate feature alloc only.
impl<'a> Arg for Cow<'a, CStr>
alloc only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, OsStr>
Available on crate feature std only.
impl<'a> Arg for Cow<'a, OsStr>
std only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, str>
Available on crate feature alloc only.
impl<'a> Arg for Cow<'a, str>
alloc only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'de, 'a> Deserialize<'de> for Cow<'a, [u8]>where
'de: 'a,
Available on crate features std or alloc only.
impl<'de, 'a> Deserialize<'de> for Cow<'a, [u8]>where
'de: 'a,
std or alloc only.fn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, [u8]>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, 'a> Deserialize<'de> for Cow<'a, Bytes>where
'de: 'a,
Available on crate features std or alloc only.
impl<'de, 'a> Deserialize<'de> for Cow<'a, Bytes>where
'de: 'a,
std or alloc only.fn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, Bytes>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
Available on crate features std or alloc only.
impl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
std or alloc only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<T> EncodeAsVarULE<T> for Cow<'_, T>
Available on crate feature alloc only.
impl<T> EncodeAsVarULE<T> for Cow<'_, T>
alloc only.Sourcefn encode_var_ule_as_slices<R>(&self, cb: impl FnOnce(&[&[u8]]) -> R) -> R
fn encode_var_ule_as_slices<R>(&self, cb: impl FnOnce(&[&[u8]]) -> R) -> R
cb with a piecewise list of byte slices that when concatenated
produce the memory pattern of the corresponding instance of T. Read moreSourcefn encode_var_ule_len(&self) -> usize
fn encode_var_ule_len(&self) -> usize
VarULE typeSourcefn encode_var_ule_write(&self, dst: &mut [u8])
fn encode_var_ule_write(&self, dst: &mut [u8])
VarULE type to the dst buffer. dst should
be the size of Self::encode_var_ule_len()1.52.0 · Sourceimpl<'a> Extend<Cow<'a, OsStr>> for OsString
impl<'a> Extend<Cow<'a, OsStr>> for OsString
Sourcefn extend<T>(&mut self, iter: T)
fn extend<T>(&mut self, iter: T)
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)1.19.0 · Sourceimpl<'a> Extend<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> Extend<Cow<'a, str>> for String
no_global_oom_handling only.Sourcefn extend<I>(&mut self, iter: I)
fn extend<I>(&mut self, iter: I)
Sourcefn extend_one(&mut self, s: Cow<'a, str>)
fn extend_one(&mut self, s: Cow<'a, str>)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl<'b> Extend<Cow<'b, str>> for String
impl<'b> Extend<Cow<'b, str>> for String
1.28.0 · Sourceimpl<'a> From<&'a String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> From<&'a String> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'a, K, V> From<&'a TiSlice<K, V>> for Cow<'a, TiSlice<K, V>>where
V: Clone,
Available on crate feature alloc only.
impl<'a, K, V> From<&'a TiSlice<K, V>> for Cow<'a, TiSlice<K, V>>where
V: Clone,
alloc only.1.14.0 · Sourceimpl<'a, T> From<Cow<'a, [T]>> for Vec<T>
impl<'a, T> From<Cow<'a, [T]>> for Vec<T>
Sourcefn from(s: Cow<'a, [T]>) -> Vec<T>
fn from(s: Cow<'a, [T]>) -> Vec<T>
Converts a clone-on-write slice into a vector.
If s already owns a Vec<T>, it will be returned directly.
If s is borrowing a slice, a new Vec<T> will be allocated and
filled by cloning s’s items into it.
Examples
let o: Cow<'_, [i32]> = Cow::Owned(vec![1, 2, 3]);
let b: Cow<'_, [i32]> = Cow::Borrowed(&[1, 2, 3]);
assert_eq!(Vec::from(o), Vec::from(b));1.14.0 · Sourceimpl<'a> From<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> From<Cow<'a, str>> for String
no_global_oom_handling only.Sourcefn from(s: Cow<'a, str>) -> String
fn from(s: Cow<'a, str>) -> String
Converts a clone-on-write string to an owned
instance of String.
This extracts the owned string, clones the string if it is not already owned.
Example
// If the string is not owned...
let cow: Cow<'_, str> = Cow::Borrowed("eggplant");
// It will allocate on the heap and copy the string.
let owned: String = String::from(cow);
assert_eq!(&owned[..], "eggplant");1.12.0 · Sourceimpl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'a> FromIterator<AsciiChar> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<AsciiChar> for Cow<'a, str>
no_global_oom_handling only.1.80.0 · Sourceimpl<'a> FromIterator<Cow<'a, str>> for Box<str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for Box<str>
no_global_oom_handling only.1.19.0 · Sourceimpl<'a> FromIterator<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for String
no_global_oom_handling only.1.12.0 · Sourceimpl<'a> FromIterator<String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<String> for Cow<'a, str>
no_global_oom_handling only.1.12.0 · Sourceimpl<'a> FromIterator<char> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<char> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'b> FromStream<Cow<'b, str>> for String
impl<'b> FromStream<Cow<'b, str>> for String
Sourceimpl<'b, T> FromStream<T> for Cow<'b, [T]>
impl<'b, T> FromStream<T> for Cow<'b, [T]>
Sourceimpl<'a, B> IntoAsciiString for Cow<'a, B>
impl<'a, B> IntoAsciiString for Cow<'a, B>
Sourceunsafe fn into_ascii_string_unchecked(self) -> AsciiString
unsafe fn into_ascii_string_unchecked(self) -> AsciiString
AsciiString without checking for non-ASCII characters. Read moreSourcefn into_ascii_string(self) -> Result<AsciiString, FromAsciiError<Cow<'a, B>>>
fn into_ascii_string(self) -> Result<AsciiString, FromAsciiError<Cow<'a, B>>>
AsciiString. Read moreSourceimpl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
Available on crate features std or alloc only.
impl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
std or alloc only.Sourcetype Deserializer = CowStrDeserializer<'a, E>
type Deserializer = CowStrDeserializer<'a, E>
Sourcefn into_deserializer(self) -> CowStrDeserializer<'a, E>
fn into_deserializer(self) -> CowStrDeserializer<'a, E>
1.0.0 · Sourceimpl<B> Ord for Cow<'_, B>
impl<B> Ord for Cow<'_, B>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
1.90.0 · Sourceimpl PartialEq<&CStr> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<&CStr> for Cow<'_, CStr>
no_global_oom_handling only.Sourceimpl PartialEq<ByteString> for Cow<'_, [u8]>
impl PartialEq<ByteString> for Cow<'_, [u8]>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, ByteStr>
impl PartialEq<ByteString> for Cow<'_, ByteStr>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, str>
impl PartialEq<ByteString> for Cow<'_, str>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.1.90.0 · Sourceimpl PartialEq<CString> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<CString> for Cow<'_, CStr>
no_global_oom_handling only.1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for &OsStr
impl PartialEq<Cow<'_, OsStr>> for &OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for &Path
impl PartialEq<Cow<'_, OsStr>> for &Path
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for OsStr
impl PartialEq<Cow<'_, OsStr>> for OsStr
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for Path
impl PartialEq<Cow<'_, OsStr>> for Path
1.8.0 · Sourceimpl PartialEq<Cow<'_, OsStr>> for PathBuf
impl PartialEq<Cow<'_, OsStr>> for PathBuf
1.8.0 · Sourceimpl PartialEq<Cow<'_, Path>> for &OsStr
impl PartialEq<Cow<'_, Path>> for &OsStr
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for &Path
impl PartialEq<Cow<'_, Path>> for &Path
1.8.0 · Sourceimpl PartialEq<Cow<'_, Path>> for OsStr
impl PartialEq<Cow<'_, Path>> for OsStr
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for Path
impl PartialEq<Cow<'_, Path>> for Path
1.6.0 · Sourceimpl PartialEq<Cow<'_, Path>> for PathBuf
impl PartialEq<Cow<'_, Path>> for PathBuf
Sourceimpl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Path
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b Path
impl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Path>> for Path
impl<'a, 'b> PartialEq<Cow<'a, Path>> for Path
1.0.0 · Sourceimpl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
Sourceimpl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Path
impl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Path
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, [u8]>
impl PartialOrd<&ByteStr> for Cow<'_, [u8]>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, str>
impl PartialOrd<&ByteStr> for Cow<'_, str>
1.8.0 · Sourceimpl PartialOrd<&OsStr> for Cow<'_, OsStr>
impl PartialOrd<&OsStr> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<&OsStr> for Cow<'_, Path>
impl PartialOrd<&OsStr> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<&Path> for Cow<'_, OsStr>
impl PartialOrd<&Path> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<&Path> for Cow<'_, Path>
impl PartialOrd<&Path> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<&'b Path> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'a Path> for Cow<'b, OsStr>
Sourceimpl PartialOrd<ByteString> for Cow<'_, [u8]>
impl PartialOrd<ByteString> for Cow<'_, [u8]>
Sourceimpl PartialOrd<ByteString> for Cow<'_, ByteStr>
impl PartialOrd<ByteString> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<ByteString> for Cow<'_, str>
impl PartialOrd<ByteString> for Cow<'_, str>
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for &OsStr
impl PartialOrd<Cow<'_, OsStr>> for &OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for &Path
impl PartialOrd<Cow<'_, OsStr>> for &Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for OsStr
impl PartialOrd<Cow<'_, OsStr>> for OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for Path
impl PartialOrd<Cow<'_, OsStr>> for Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, OsStr>> for PathBuf
impl PartialOrd<Cow<'_, OsStr>> for PathBuf
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for &OsStr
impl PartialOrd<Cow<'_, Path>> for &OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for &Path
impl PartialOrd<Cow<'_, Path>> for &Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for OsStr
impl PartialOrd<Cow<'_, Path>> for OsStr
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for Path
impl PartialOrd<Cow<'_, Path>> for Path
1.8.0 · Sourceimpl PartialOrd<Cow<'_, Path>> for PathBuf
impl PartialOrd<Cow<'_, Path>> for PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Path
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for &'b Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for Path
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Path
1.8.0 · Sourceimpl PartialOrd<OsStr> for Cow<'_, OsStr>
impl PartialOrd<OsStr> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<OsStr> for Cow<'_, Path>
impl PartialOrd<OsStr> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<OsString> for Cow<'_, OsStr>
impl PartialOrd<OsString> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<OsString> for Cow<'_, Path>
impl PartialOrd<OsString> for Cow<'_, Path>
1.8.0 · Sourceimpl PartialOrd<Path> for Cow<'_, OsStr>
impl PartialOrd<Path> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<Path> for Cow<'_, Path>
impl PartialOrd<Path> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialOrd<Path> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<Path> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Path> for Cow<'a, Path>
1.8.0 · Sourceimpl PartialOrd<PathBuf> for Cow<'_, OsStr>
impl PartialOrd<PathBuf> for Cow<'_, OsStr>
1.8.0 · Sourceimpl PartialOrd<PathBuf> for Cow<'_, Path>
impl PartialOrd<PathBuf> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialOrd<PathBuf> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<PathBuf> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<PathBuf> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<PathBuf> for Cow<'a, Path>
1.0.0 · Sourceimpl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, B> PartialOrd for Cow<'a, B>
Sourceimpl<'a> RawOsStrCow<'a> for Cow<'a, RawOsStr>
impl<'a> RawOsStrCow<'a> for Cow<'a, RawOsStr>
Sourceimpl<'a> Replacer for &'a Cow<'a, [u8]>
impl<'a> Replacer for &'a Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for &'a Cow<'a, str>
impl<'a> Replacer for &'a Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, [u8]>
impl<'a> Replacer for Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, str>
impl<'a> Replacer for Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Serialize for Cow<'a, [u8]>
Available on crate features std or alloc only.
impl<'a> Serialize for Cow<'a, [u8]>
std or alloc only.fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<'a> Serialize for Cow<'a, Bytes>
Available on crate features std or alloc only.
impl<'a> Serialize for Cow<'a, Bytes>
std or alloc only.fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<'a, T> Serialize for Cow<'a, T>
Available on crate features std or alloc only.
impl<'a, T> Serialize for Cow<'a, T>
std or alloc only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Sourceimpl<'s> StringBuilder<'s> for Cow<'s, str>
Available on crate feature alloc only.
impl<'s> StringBuilder<'s> for Cow<'s, str>
alloc only.Sourceimpl WriteTomlKey for Cow<'_, str>
Available on crate feature alloc only.
impl WriteTomlKey for Cow<'_, str>
alloc only.Sourceimpl WriteTomlValue for Cow<'_, str>
Available on crate feature alloc only.
impl WriteTomlValue for Cow<'_, str>
alloc only.impl<T> DerefPure for Cow<'_, [T]>where
T: Clone,
no_global_oom_handling only.impl<T> DerefPure for Cow<'_, T>where
T: Clone,
impl DerefPure for Cow<'_, str>
no_global_oom_handling only.impl<B> Eq for Cow<'_, B>
impl<T> IoSafe for Cow<'_, T>