Binary

Trait Binary 

1.0.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize

Source

impl Binary for u1

Source

impl Binary for u2

Source

impl Binary for u3

Source

impl Binary for u4

Source

impl Binary for u5

Source

impl Binary for u6

Source

impl Binary for u7

Source

impl Binary for u24

Source

impl Binary for u40

Source

impl Binary for u48

Source

impl Binary for u56

Source

impl Binary for EventMask

Source

impl Binary for WatchMask

Source

impl Binary for EventKindMask

Source

impl Binary for BigInt

Source

impl Binary for BigUint

Source

impl Binary for CipherCtxFlags

Source

impl Binary for CMSOptions

Source

impl Binary for OcspFlag

Source

impl Binary for Pkcs7Flags

Source

impl Binary for ExtensionContext

Source

impl Binary for ShutdownState

Source

impl Binary for SslMode

Source

impl Binary for SslOptions

Source

impl Binary for SslSessionCacheMode

Source

impl Binary for SslVerifyMode

Source

impl Binary for X509CheckFlags

Source

impl Binary for X509VerifyFlags

Source

impl Binary for rustix::backend::event::epoll::CreateFlags

Source

impl Binary for EventFlags

Source

impl Binary for PollFlags

Source

impl Binary for EventfdFlags

Source

impl Binary for rustix::backend::fs::inotify::CreateFlags

Source

impl Binary for ReadFlags

Source

impl Binary for WatchFlags

Source

impl Binary for Access

Source

impl Binary for AtFlags

Source

impl Binary for FallocateFlags

Source

impl Binary for MemfdFlags

Source

impl Binary for Mode

Source

impl Binary for OFlags

Source

impl Binary for RenameFlags

Source

impl Binary for ResolveFlags

Source

impl Binary for SealFlags

Source

impl Binary for StatVfsMountFlags

Source

impl Binary for DupFlags

Source

impl Binary for FdFlags

Source

impl Binary for ReadWriteFlags

Source

impl Binary for RecvFlags

Source

impl Binary for ReturnFlags

Source

impl Binary for SendFlags

Source

impl Binary for PipeFlags

Source

impl Binary for SpliceFlags

Source

impl Binary for TimerfdFlags

Source

impl Binary for TimerfdTimerFlags

Source

impl Binary for IFlags

Source

impl Binary for StatxAttributes

Source

impl Binary for StatxFlags

Source

impl Binary for XattrFlags

Source

impl Binary for SocketFlags

Source

impl Binary for TxTimeFlags

Source

impl Binary for SocketAddrXdpFlags

Source

impl Binary for XdpDescOptions

Source

impl Binary for XdpOptionsFlags

Source

impl Binary for XdpRingFlags

Source

impl Binary for XdpUmemRegFlags

Source

impl Binary for Pid

Source

impl Binary for PidfdFlags

Source

impl Binary for PidfdGetfdFlags

Source

impl Binary for FloatingPointEmulationControl

Source

impl Binary for FloatingPointExceptionMode

Source

impl Binary for SpeculationFeatureControl

Source

impl Binary for SpeculationFeatureState

Source

impl Binary for UnalignedAccessControl

Source

impl Binary for WaitIdOptions

Source

impl Binary for WaitOptions

Source

impl Binary for ControlModes

Source

impl Binary for InputModes

Source

impl Binary for LocalModes

Source

impl Binary for OutputModes

Source

impl Binary for Gid

Source

impl Binary for Uid

Source

impl Binary for BeginFlags

Source

impl Binary for Z0

Source

impl Binary for UInt<UTerm, B0>

Source

impl Binary for UInt<UTerm, B1>

Source

impl Binary for UTerm

Source

impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,

Source

impl<'a, T, O> Binary for Domain<'a, Const, T, O>
where O: BitOrder, T: BitStore,

Source

impl<A, O> Binary for BitArray<A, O>
where O: BitOrder, A: BitViewSized,

Source

impl<O> Binary for I16<O>
where O: ByteOrder,

Source

impl<O> Binary for I32<O>
where O: ByteOrder,

Source

impl<O> Binary for I64<O>
where O: ByteOrder,

Source

impl<O> Binary for I128<O>
where O: ByteOrder,

Source

impl<O> Binary for Isize<O>
where O: ByteOrder,

Source

impl<O> Binary for U16<O>
where O: ByteOrder,

Source

impl<O> Binary for U32<O>
where O: ByteOrder,

Source

impl<O> Binary for U64<O>
where O: ByteOrder,

Source

impl<O> Binary for U128<O>
where O: ByteOrder,

Source

impl<O> Binary for Usize<O>
where O: ByteOrder,

Source

impl<R> Binary for BitEnd<R>
where R: BitRegister,

Source

impl<R> Binary for BitIdx<R>
where R: BitRegister,

Source

impl<R> Binary for BitMask<R>
where R: BitRegister,

Source

impl<R> Binary for BitPos<R>
where R: BitRegister,

Source

impl<R> Binary for BitSel<R>
where R: BitRegister,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

Source

impl<T> Binary for crypto_bigint::non_zero::NonZero<T>
where T: Binary + Zero,

Source

impl<T> Binary for crypto_bigint::wrapping::Wrapping<T>
where T: Binary,

Source

impl<T> Binary for BoxSensitive<T>
where T: Binary,

Source

impl<T> Binary for Sensitive<T>
where T: Binary,

Source

impl<T> Binary for FmtBinary<T>
where T: Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtDisplay<T>
where T: Display + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtList<T>
where &'a T: for<'a> IntoIterator, <&'a T as IntoIterator>::Item: for<'a> Binary,

Source

impl<T> Binary for FmtLowerExp<T>
where T: LowerExp + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtLowerHex<T>
where T: LowerHex + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtOctal<T>
where T: Octal + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtPointer<T>
where T: Pointer + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtUpperExp<T>
where T: UpperExp + Binary,

Available on non-tarpaulin_include only.
Source

impl<T> Binary for FmtUpperHex<T>
where T: UpperHex + Binary,

Available on non-tarpaulin_include only.
1.28.0 · Source

impl<T> Binary for core::num::nonzero::NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for core::num::wrapping::Wrapping<T>
where T: Binary,

Source

impl<T, O> Binary for BitBox<T, O>
where O: BitOrder, T: BitStore,

Source

impl<T, O> Binary for BitSlice<T, O>
where T: BitStore, O: BitOrder,

Bit-Slice Rendering

This implementation prints the contents of a &BitSlice in one of binary, octal, or hexadecimal. It is important to note that this does not render the raw underlying memory! They render the semantically-ordered contents of the bit-slice as numerals. This distinction matters if you use type parameters that differ from those presumed by your debugger (which is usually <u8, Msb0>).

The output separates the T elements as individual list items, and renders each element as a base- 2, 8, or 16 numeric string. When walking an element, the bits traversed by the bit-slice are considered to be stored in most-significant-bit-first ordering. This means that index [0] is the high bit of the left-most digit, and index [n] is the low bit of the right-most digit, in a given printed word.

In order to render according to expectations of the Arabic numeral system, an element being transcribed is chunked into digits from the least-significant end of its rendered form. This is most noticeable in octal, which will always have a smaller ceiling on the left-most digit in a printed word, while the right-most digit in that word is able to use the full 0 ..= 7 numeral range.

Examples
use bitvec::prelude::*;

let data = [
  0b000000_10u8,
// digits print LTR
  0b10_001_101,
// significance is computed RTL
  0b01_000000,
];
let bits = &data.view_bits::<Msb0>()[6 .. 18];

assert_eq!(format!("{:b}", bits), "[10, 10001101, 01]");
assert_eq!(format!("{:o}", bits), "[2, 215, 1]");
assert_eq!(format!("{:X}", bits), "[2, 8D, 1]");

The {:#} format modifier causes the standard 0b, 0o, or 0x prefix to be applied to each printed word. The other format specifiers are not interpreted by this implementation, and apply to the entire rendered text, not to individual words.

Source

impl<T, O> Binary for BitVec<T, O>
where O: BitOrder, T: BitStore,

Source

impl<U> Binary for NInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U> Binary for PInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B0>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<const MIN: i8, const MAX: i8> Binary for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Binary for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Binary for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Binary for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Binary for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Binary for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Binary for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Binary for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Binary for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Binary for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Binary for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Binary for RangedUsize<MIN, MAX>

Source

impl<const NICHE: i8> Binary for NonAnyI8<NICHE>

Source

impl<const NICHE: i16> Binary for NonAnyI16<NICHE>

Source

impl<const NICHE: i32> Binary for NonAnyI32<NICHE>

Source

impl<const NICHE: i64> Binary for NonAnyI64<NICHE>

Source

impl<const NICHE: i128> Binary for NonAnyI128<NICHE>

Source

impl<const NICHE: isize> Binary for NonAnyIsize<NICHE>

Source

impl<const NICHE: u8> Binary for NonAnyU8<NICHE>

Source

impl<const NICHE: u16> Binary for NonAnyU16<NICHE>

Source

impl<const NICHE: u32> Binary for NonAnyU32<NICHE>

Source

impl<const NICHE: u64> Binary for NonAnyU64<NICHE>

Source

impl<const NICHE: u128> Binary for NonAnyU128<NICHE>

Source

impl<const NICHE: usize> Binary for NonAnyUsize<NICHE>