Octal

Trait Octal 

1.0.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize

Source

impl Octal for u1

Source

impl Octal for u2

Source

impl Octal for u3

Source

impl Octal for u4

Source

impl Octal for u5

Source

impl Octal for u6

Source

impl Octal for u7

Source

impl Octal for u24

Source

impl Octal for u40

Source

impl Octal for u48

Source

impl Octal for u56

Source

impl Octal for EventMask

Source

impl Octal for WatchMask

Source

impl Octal for EventKindMask

Source

impl Octal for BigInt

Source

impl Octal for BigUint

Source

impl Octal for CipherCtxFlags

Source

impl Octal for CMSOptions

Source

impl Octal for OcspFlag

Source

impl Octal for Pkcs7Flags

Source

impl Octal for ExtensionContext

Source

impl Octal for ShutdownState

Source

impl Octal for SslMode

Source

impl Octal for SslOptions

Source

impl Octal for SslSessionCacheMode

Source

impl Octal for SslVerifyMode

Source

impl Octal for X509CheckFlags

Source

impl Octal for X509VerifyFlags

Source

impl Octal for rustix::backend::event::epoll::CreateFlags

Source

impl Octal for EventFlags

Source

impl Octal for PollFlags

Source

impl Octal for EventfdFlags

Source

impl Octal for rustix::backend::fs::inotify::CreateFlags

Source

impl Octal for ReadFlags

Source

impl Octal for WatchFlags

Source

impl Octal for Access

Source

impl Octal for AtFlags

Source

impl Octal for FallocateFlags

Source

impl Octal for MemfdFlags

Source

impl Octal for Mode

Source

impl Octal for OFlags

Source

impl Octal for RenameFlags

Source

impl Octal for ResolveFlags

Source

impl Octal for SealFlags

Source

impl Octal for StatVfsMountFlags

Source

impl Octal for DupFlags

Source

impl Octal for FdFlags

Source

impl Octal for ReadWriteFlags

Source

impl Octal for RecvFlags

Source

impl Octal for ReturnFlags

Source

impl Octal for SendFlags

Source

impl Octal for PipeFlags

Source

impl Octal for SpliceFlags

Source

impl Octal for TimerfdFlags

Source

impl Octal for TimerfdTimerFlags

Source

impl Octal for IFlags

Source

impl Octal for StatxAttributes

Source

impl Octal for StatxFlags

Source

impl Octal for XattrFlags

Source

impl Octal for SocketFlags

Source

impl Octal for TxTimeFlags

Source

impl Octal for SocketAddrXdpFlags

Source

impl Octal for XdpDescOptions

Source

impl Octal for XdpOptionsFlags

Source

impl Octal for XdpRingFlags

Source

impl Octal for XdpUmemRegFlags

Source

impl Octal for Pid

Source

impl Octal for PidfdFlags

Source

impl Octal for PidfdGetfdFlags

Source

impl Octal for FloatingPointEmulationControl

Source

impl Octal for FloatingPointExceptionMode

Source

impl Octal for SpeculationFeatureControl

Source

impl Octal for SpeculationFeatureState

Source

impl Octal for UnalignedAccessControl

Source

impl Octal for WaitIdOptions

Source

impl Octal for WaitOptions

Source

impl Octal for ControlModes

Source

impl Octal for InputModes

Source

impl Octal for LocalModes

Source

impl Octal for OutputModes

Source

impl Octal for Gid

Source

impl Octal for Uid

Source

impl Octal for BeginFlags

Source

impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,

Source

impl<'a, T, O> Octal for Domain<'a, Const, T, O>
where O: BitOrder, T: BitStore,

Source

impl<A, O> Octal for BitArray<A, O>
where O: BitOrder, A: BitViewSized,

Source

impl<O> Octal for I16<O>
where O: ByteOrder,

Source

impl<O> Octal for I32<O>
where O: ByteOrder,

Source

impl<O> Octal for I64<O>
where O: ByteOrder,

Source

impl<O> Octal for I128<O>
where O: ByteOrder,

Source

impl<O> Octal for Isize<O>
where O: ByteOrder,

Source

impl<O> Octal for U16<O>
where O: ByteOrder,

Source

impl<O> Octal for U32<O>
where O: ByteOrder,

Source

impl<O> Octal for U64<O>
where O: ByteOrder,

Source

impl<O> Octal for U128<O>
where O: ByteOrder,

Source

impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

Source

impl<T> Octal for crypto_bigint::non_zero::NonZero<T>
where T: Octal + Zero,

Source

impl<T> Octal for crypto_bigint::wrapping::Wrapping<T>
where T: Octal,

Source

impl<T> Octal for BoxSensitive<T>
where T: Octal,

Source

impl<T> Octal for Sensitive<T>
where T: Octal,

Source

impl<T> Octal for FmtBinary<T>
where T: Binary + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtDisplay<T>
where T: Display + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtList<T>
where &'a T: for<'a> IntoIterator, <&'a T as IntoIterator>::Item: for<'a> Octal,

Source

impl<T> Octal for FmtLowerExp<T>
where T: LowerExp + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtLowerHex<T>
where T: LowerHex + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtOctal<T>
where T: Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtPointer<T>
where T: Pointer + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtUpperExp<T>
where T: UpperExp + Octal,

Available on non-tarpaulin_include only.
Source

impl<T> Octal for FmtUpperHex<T>
where T: UpperHex + Octal,

Available on non-tarpaulin_include only.
1.28.0 · Source

impl<T> Octal for core::num::nonzero::NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for core::num::wrapping::Wrapping<T>
where T: Octal,

Source

impl<T, O> Octal for BitBox<T, O>
where O: BitOrder, T: BitStore,

Source

impl<T, O> Octal for BitSlice<T, O>
where T: BitStore, O: BitOrder,

Bit-Slice Rendering

This implementation prints the contents of a &BitSlice in one of binary, octal, or hexadecimal. It is important to note that this does not render the raw underlying memory! They render the semantically-ordered contents of the bit-slice as numerals. This distinction matters if you use type parameters that differ from those presumed by your debugger (which is usually <u8, Msb0>).

The output separates the T elements as individual list items, and renders each element as a base- 2, 8, or 16 numeric string. When walking an element, the bits traversed by the bit-slice are considered to be stored in most-significant-bit-first ordering. This means that index [0] is the high bit of the left-most digit, and index [n] is the low bit of the right-most digit, in a given printed word.

In order to render according to expectations of the Arabic numeral system, an element being transcribed is chunked into digits from the least-significant end of its rendered form. This is most noticeable in octal, which will always have a smaller ceiling on the left-most digit in a printed word, while the right-most digit in that word is able to use the full 0 ..= 7 numeral range.

Examples
use bitvec::prelude::*;

let data = [
  0b000000_10u8,
// digits print LTR
  0b10_001_101,
// significance is computed RTL
  0b01_000000,
];
let bits = &data.view_bits::<Msb0>()[6 .. 18];

assert_eq!(format!("{:b}", bits), "[10, 10001101, 01]");
assert_eq!(format!("{:o}", bits), "[2, 215, 1]");
assert_eq!(format!("{:X}", bits), "[2, 8D, 1]");

The {:#} format modifier causes the standard 0b, 0o, or 0x prefix to be applied to each printed word. The other format specifiers are not interpreted by this implementation, and apply to the entire rendered text, not to individual words.

Source

impl<T, O> Octal for BitVec<T, O>
where O: BitOrder, T: BitStore,

Source

impl<const MIN: i8, const MAX: i8> Octal for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Octal for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Octal for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Octal for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Octal for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Octal for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Octal for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Octal for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Octal for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Octal for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Octal for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Octal for RangedUsize<MIN, MAX>

Source

impl<const NICHE: i8> Octal for NonAnyI8<NICHE>

Source

impl<const NICHE: i16> Octal for NonAnyI16<NICHE>

Source

impl<const NICHE: i32> Octal for NonAnyI32<NICHE>

Source

impl<const NICHE: i64> Octal for NonAnyI64<NICHE>

Source

impl<const NICHE: i128> Octal for NonAnyI128<NICHE>

Source

impl<const NICHE: isize> Octal for NonAnyIsize<NICHE>

Source

impl<const NICHE: u8> Octal for NonAnyU8<NICHE>

Source

impl<const NICHE: u16> Octal for NonAnyU16<NICHE>

Source

impl<const NICHE: u32> Octal for NonAnyU32<NICHE>

Source

impl<const NICHE: u64> Octal for NonAnyU64<NICHE>

Source

impl<const NICHE: u128> Octal for NonAnyU128<NICHE>

Source

impl<const NICHE: usize> Octal for NonAnyUsize<NICHE>