pub struct DirEntry(DirEntry);Expand description
Entries returned by the ReadDir iterator.
An instance of DirEntry represents an entry inside of a directory on the
filesystem. Each entry can be inspected via methods to learn about the full
path or possibly other metadata through per-platform extension traits.
Platform-specific behavior
On Unix, the DirEntry struct contains an internal reference to the open
directory. Holding DirEntry objects will consume a file handle even
after the ReadDir iterator is dropped.
Note that this may change in the future.
Tuple Fields
0: DirEntryImplementations
Sourceimpl DirEntry
impl DirEntry
1.0.0 · Sourcepub fn path(&self) -> PathBuf
pub fn path(&self) -> PathBuf
Returns the full path to the file that this entry represents.
The full path is created by joining the original path to read_dir
with the filename of this entry.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
for entry in fs::read_dir(".")? {
let dir = entry?;
println!("{:?}", dir.path());
}
Ok(())
}This prints output like:
"./whatever.txt"
"./foo.html"
"./hello_world.rs"The exact text, of course, depends on what files you have in ..
1.1.0 · Sourcepub fn metadata(&self) -> Result<Metadata, Error>
pub fn metadata(&self) -> Result<Metadata, Error>
Returns the metadata for the file that this entry points at.
This function will not traverse symlinks if this entry points at a
symlink. To traverse symlinks use fs::metadata or fs::File::metadata.
Platform-specific behavior
On Windows this function is cheap to call (no extra system calls
needed), but on Unix platforms this function is the equivalent of
calling symlink_metadata on the path.
Examples
use std::fs;
if let Ok(entries) = fs::read_dir(".") {
for entry in entries {
if let Ok(entry) = entry {
// Here, `entry` is a `DirEntry`.
if let Ok(metadata) = entry.metadata() {
// Now let's show our entry's permissions!
println!("{:?}: {:?}", entry.path(), metadata.permissions());
} else {
println!("Couldn't get metadata for {:?}", entry.path());
}
}
}
}1.1.0 · Sourcepub fn file_type(&self) -> Result<FileType, Error>
pub fn file_type(&self) -> Result<FileType, Error>
Returns the file type for the file that this entry points at.
This function will not traverse symlinks if this entry points at a symlink.
Platform-specific behavior
On Windows and most Unix platforms this function is free (no extra
system calls needed), but some Unix platforms may require the equivalent
call to symlink_metadata to learn about the target file type.
Examples
use std::fs;
if let Ok(entries) = fs::read_dir(".") {
for entry in entries {
if let Ok(entry) = entry {
// Here, `entry` is a `DirEntry`.
if let Ok(file_type) = entry.file_type() {
// Now let's show our entry's file type!
println!("{:?}: {:?}", entry.path(), file_type);
} else {
println!("Couldn't get file type for {:?}", entry.path());
}
}
}
}1.1.0 · Sourcepub fn file_name(&self) -> OsString
pub fn file_name(&self) -> OsString
Returns the file name of this directory entry without any leading path component(s).
As an example, the output of the function will result in “foo” for all the following paths:
- “./foo”
- “/the/foo”
- “../../foo”
Examples
use std::fs;
if let Ok(entries) = fs::read_dir(".") {
for entry in entries {
if let Ok(entry) = entry {
// Here, `entry` is a `DirEntry`.
println!("{:?}", entry.file_name());
}
}
}Trait Implementations
1.1.0 · Sourceimpl DirEntryExt for DirEntry
impl DirEntryExt for DirEntry
Sourceimpl DirEntryExt2 for DirEntry
impl DirEntryExt2 for DirEntry
Sourcefn file_name_ref(&self) -> &OsStr
fn file_name_ref(&self) -> &OsStr
dir_entry_ext2)OsStr of this entry’s filename. Read moreAuto Trait Implementations
impl Freeze for DirEntry
impl RefUnwindSafe for DirEntry
impl Send for DirEntry
impl Sync for DirEntry
impl Unpin for DirEntry
impl UnsafeUnpin for DirEntry
impl UnwindSafe for DirEntry