pub struct Metadata(FileAttr);Expand description
Metadata information about a file.
This structure is returned from the metadata or
symlink_metadata function or method and represents known
metadata about a file such as its permissions, size, modification
times, etc.
Tuple Fields
0: FileAttrImplementations
Sourceimpl Metadata
impl Metadata
1.1.0 · Sourcepub fn file_type(&self) -> FileType
pub fn file_type(&self) -> FileType
Returns the file type for this metadata.
Examples
fn main() -> std::io::Result<()> {
use std::fs;
let metadata = fs::metadata("foo.txt")?;
println!("{:?}", metadata.file_type());
Ok(())
}1.0.0 · Sourcepub fn is_dir(&self) -> bool
pub fn is_dir(&self) -> bool
Returns true if this metadata is for a directory. The
result is mutually exclusive to the result of
Metadata::is_file, and will be false for symlink metadata
obtained from symlink_metadata.
Examples
fn main() -> std::io::Result<()> {
use std::fs;
let metadata = fs::metadata("foo.txt")?;
assert!(!metadata.is_dir());
Ok(())
}1.0.0 · Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
Returns true if this metadata is for a regular file. The
result is mutually exclusive to the result of
Metadata::is_dir, and will be false for symlink metadata
obtained from symlink_metadata.
When the goal is simply to read from (or write to) the source, the most
reliable way to test the source can be read (or written to) is to open
it. Only using is_file can break workflows like diff <( prog_a ) on
a Unix-like system for example. See File::open or
OpenOptions::open for more information.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
assert!(metadata.is_file());
Ok(())
}1.58.0 · Sourcepub fn is_symlink(&self) -> bool
pub fn is_symlink(&self) -> bool
Returns true if this metadata is for a symbolic link.
Examples
use std::fs;
use std::path::Path;
use std::os::unix::fs::symlink;
fn main() -> std::io::Result<()> {
let link_path = Path::new("link");
symlink("/origin_does_not_exist/", link_path)?;
let metadata = fs::symlink_metadata(link_path)?;
assert!(metadata.is_symlink());
Ok(())
}1.0.0 · Sourcepub fn len(&self) -> u64
pub fn len(&self) -> u64
Returns the size of the file, in bytes, this metadata is for.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
assert_eq!(0, metadata.len());
Ok(())
}1.0.0 · Sourcepub fn permissions(&self) -> Permissions
pub fn permissions(&self) -> Permissions
Returns the permissions of the file this metadata is for.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
assert!(!metadata.permissions().readonly());
Ok(())
}1.10.0 · Sourcepub fn modified(&self) -> Result<SystemTime, Error>
pub fn modified(&self) -> Result<SystemTime, Error>
Returns the last modification time listed in this metadata.
The returned value corresponds to the mtime field of stat on Unix
platforms and the ftLastWriteTime field on Windows platforms.
Errors
This field might not be available on all platforms, and will return an
Err on platforms where it is not available.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
if let Ok(time) = metadata.modified() {
println!("{time:?}");
} else {
println!("Not supported on this platform");
}
Ok(())
}1.10.0 · Sourcepub fn accessed(&self) -> Result<SystemTime, Error>
pub fn accessed(&self) -> Result<SystemTime, Error>
Returns the last access time of this metadata.
The returned value corresponds to the atime field of stat on Unix
platforms and the ftLastAccessTime field on Windows platforms.
Note that not all platforms will keep this field update in a file’s
metadata, for example Windows has an option to disable updating this
time when files are accessed and Linux similarly has noatime.
Errors
This field might not be available on all platforms, and will return an
Err on platforms where it is not available.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
if let Ok(time) = metadata.accessed() {
println!("{time:?}");
} else {
println!("Not supported on this platform");
}
Ok(())
}1.10.0 · Sourcepub fn created(&self) -> Result<SystemTime, Error>
pub fn created(&self) -> Result<SystemTime, Error>
Returns the creation time listed in this metadata.
The returned value corresponds to the btime field of statx on
Linux kernel starting from to 4.11, the birthtime field of stat on other
Unix platforms, and the ftCreationTime field on Windows platforms.
Errors
This field might not be available on all platforms, and will return an
Err on platforms or filesystems where it is not available.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::metadata("foo.txt")?;
if let Ok(time) = metadata.created() {
println!("{time:?}");
} else {
println!("Not supported on this platform or filesystem");
}
Ok(())
}Trait Implementations
1.1.0 · Sourceimpl MetadataExt for Metadata
impl MetadataExt for Metadata
Sourcefn atime(&self) -> i64
fn atime(&self) -> i64
Sourcefn atime_nsec(&self) -> i64
fn atime_nsec(&self) -> i64
Sourcefn mtime(&self) -> i64
fn mtime(&self) -> i64
Sourcefn mtime_nsec(&self) -> i64
fn mtime_nsec(&self) -> i64
Sourcefn ctime(&self) -> i64
fn ctime(&self) -> i64
Sourcefn ctime_nsec(&self) -> i64
fn ctime_nsec(&self) -> i64
1.1.0 · Sourceimpl MetadataExt for Metadata
impl MetadataExt for Metadata
Sourcefn as_raw_stat(&self) -> &stat
fn as_raw_stat(&self) -> &stat
other methods of this trait are now preferred
stat structure which contains
the raw information returned by the OS. Read moreSourcefn st_rdev(&self) -> u64
fn st_rdev(&self) -> u64
Sourcefn st_size(&self) -> u64
fn st_size(&self) -> u64
Sourcefn st_atime(&self) -> i64
fn st_atime(&self) -> i64
Sourcefn st_atime_nsec(&self) -> i64
fn st_atime_nsec(&self) -> i64
Sourcefn st_mtime(&self) -> i64
fn st_mtime(&self) -> i64
Sourcefn st_mtime_nsec(&self) -> i64
fn st_mtime_nsec(&self) -> i64
Sourcefn st_ctime(&self) -> i64
fn st_ctime(&self) -> i64
Sourcefn st_ctime_nsec(&self) -> i64
fn st_ctime_nsec(&self) -> i64
Sourcefn st_blksize(&self) -> u64
fn st_blksize(&self) -> u64