pub trait FusedFuture: Future {
// Required method
fn is_terminated(&self) -> bool;
}Expand description
A future which tracks whether or not the underlying future should no longer be polled.
is_terminated will return true if a future should no longer be polled.
Usually, this state occurs after poll (or try_poll) returned
Poll::Ready. However, is_terminated may also return true if a future
has become inactive and can no longer make progress and should be ignored
or dropped rather than being polled again.
Required Methods
Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
Returns true if the underlying future should no longer be polled.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'w, IF, OS, IM, OM> FusedFuture for SinkPrepareSendFuture<'w, IF, OS, OM>
impl<'w, IF, OS, IM, OM> FusedFuture for SinkPrepareSendFuture<'w, IF, OS, OM>
fn is_terminated(&self) -> bool
Sourceimpl<F> FusedFuture for &mut F
impl<F> FusedFuture for &mut F
fn is_terminated(&self) -> bool
Sourceimpl<F> FusedFuture for Box<F>
impl<F> FusedFuture for Box<F>
fn is_terminated(&self) -> bool
Sourceimpl<P> FusedFuture for Pin<P>
impl<P> FusedFuture for Pin<P>
fn is_terminated(&self) -> bool
Sourceimpl<St, A, B, FromA, FromB> FusedFuture for Unzip<St, FromA, FromB>
impl<St, A, B, FromA, FromB> FusedFuture for Unzip<St, FromA, FromB>
fn is_terminated(&self) -> bool
Sourceimpl<St, C> FusedFuture for Collect<St, C>
impl<St, C> FusedFuture for Collect<St, C>
fn is_terminated(&self) -> bool
Sourceimpl<St, C> FusedFuture for TryCollect<St, C>
impl<St, C> FusedFuture for TryCollect<St, C>
fn is_terminated(&self) -> bool
Sourceimpl<St, F> FusedFuture for NextIf<'_, St, F>
impl<St, F> FusedFuture for NextIf<'_, St, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for All<St, Fut, F>
impl<St, Fut, F> FusedFuture for All<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for Any<St, Fut, F>
impl<St, Fut, F> FusedFuture for Any<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for ForEach<St, Fut, F>
impl<St, Fut, F> FusedFuture for ForEach<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for ForEachConcurrent<St, Fut, F>
impl<St, Fut, F> FusedFuture for ForEachConcurrent<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for TryAll<St, Fut, F>
impl<St, Fut, F> FusedFuture for TryAll<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for TryAny<St, Fut, F>
impl<St, Fut, F> FusedFuture for TryAny<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, F> FusedFuture for TryForEachConcurrent<St, Fut, F>
impl<St, Fut, F> FusedFuture for TryForEachConcurrent<St, Fut, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, T, F> FusedFuture for Fold<St, Fut, T, F>
impl<St, Fut, T, F> FusedFuture for Fold<St, Fut, T, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Fut, T, F> FusedFuture for TryFold<St, Fut, T, F>
impl<St, Fut, T, F> FusedFuture for TryFold<St, Fut, T, F>
fn is_terminated(&self) -> bool
Sourceimpl<St, Si> FusedFuture for Forward<St, Si>
impl<St, Si> FusedFuture for Forward<St, Si>
fn is_terminated(&self) -> bool
Sourceimpl<St, T> FusedFuture for NextIfEq<'_, St, T>
impl<St, T> FusedFuture for NextIfEq<'_, St, T>
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for Concat<St>where
St: FusedStream,
<St as Stream>::Item: Extend<<<St as Stream>::Item as IntoIterator>::Item> + IntoIterator + Default,
impl<St> FusedFuture for Concat<St>where
St: FusedStream,
<St as Stream>::Item: Extend<<<St as Stream>::Item as IntoIterator>::Item> + IntoIterator + Default,
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for Count<St>where
St: FusedStream,
impl<St> FusedFuture for Count<St>where
St: FusedStream,
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for Next<'_, St>
impl<St> FusedFuture for Next<'_, St>
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for Peek<'_, St>where
St: Stream,
impl<St> FusedFuture for Peek<'_, St>where
St: Stream,
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for PeekMut<'_, St>where
St: Stream,
impl<St> FusedFuture for PeekMut<'_, St>where
St: Stream,
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for SelectNextSome<'_, St>
impl<St> FusedFuture for SelectNextSome<'_, St>
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for StreamFuture<St>
impl<St> FusedFuture for StreamFuture<St>
fn is_terminated(&self) -> bool
Sourceimpl<St> FusedFuture for TryNext<'_, St>
impl<St> FusedFuture for TryNext<'_, St>
fn is_terminated(&self) -> bool
Sourceimpl<T> FusedFuture for MutexLockFuture<'_, T>where
T: ?Sized,
impl<T> FusedFuture for MutexLockFuture<'_, T>where
T: ?Sized,
fn is_terminated(&self) -> bool
Sourceimpl<T> FusedFuture for OwnedMutexLockFuture<T>where
T: ?Sized,
impl<T> FusedFuture for OwnedMutexLockFuture<T>where
T: ?Sized,
fn is_terminated(&self) -> bool
Sourceimpl<T> FusedFuture for Receiver<T>
impl<T> FusedFuture for Receiver<T>
fn is_terminated(&self) -> bool
Implementors
impl<A, B> FusedFuture for Either<A, B>
impl<A, B> FusedFuture for Select<A, B>
impl<F, R> FusedFuture for Lazy<F>
impl<F> FusedFuture for AssertUnwindSafe<F>where
F: FusedFuture,
Available on crate feature
std only.