Extend

Trait Extend 

1.0.0 · Source
pub trait Extend<A> {
    // Required method
    fn extend<T>(&mut self, iter: T)
       where T: IntoIterator<Item = A>;

    // Provided methods
    fn extend_one(&mut self, item: A) { ... }
    fn extend_reserve(&mut self, additional: usize) { ... }
}
Extend a collection with the contents of an iterator.

Iterators produce a series of values, and collections can also be thought of as a series of values. The Extend trait bridges this gap, allowing you to extend a collection by including the contents of that iterator. When extending a collection with an already existing key, that entry is updated or, in the case of collections that permit multiple entries with equal keys, that entry is inserted.

Examples

Basic usage:

// You can extend a String with some chars:
let mut message = String::from("The first three letters are: ");

message.extend(&['a', 'b', 'c']);

assert_eq!("abc", &message[29..32]);

Implementing Extend:

// A sample collection, that's just a wrapper over Vec<T>
#[derive(Debug)]
struct MyCollection(Vec<i32>);

// Let's give it some methods so we can create one and add things
// to it.
impl MyCollection {
    fn new() -> MyCollection {
        MyCollection(Vec::new())
    }

    fn add(&mut self, elem: i32) {
        self.0.push(elem);
    }
}

// since MyCollection has a list of i32s, we implement Extend for i32
impl Extend<i32> for MyCollection {

    // This is a bit simpler with the concrete type signature: we can call
    // extend on anything which can be turned into an Iterator which gives
    // us i32s. Because we need i32s to put into MyCollection.
    fn extend<T: IntoIterator<Item=i32>>(&mut self, iter: T) {

        // The implementation is very straightforward: loop through the
        // iterator, and add() each element to ourselves.
        for elem in iter {
            self.add(elem);
        }
    }
}

let mut c = MyCollection::new();

c.add(5);
c.add(6);
c.add(7);

// let's extend our collection with three more numbers
c.extend(vec![1, 2, 3]);

// we've added these elements onto the end
assert_eq!("MyCollection([5, 6, 7, 1, 2, 3])", format!("{c:?}"));

Required Methods

1.0.0 · Source

fn extend<T>(&mut self, iter: T)
where T: IntoIterator<Item = A>,

Extends a collection with the contents of an iterator.

As this is the only required method for this trait, the trait-level docs contain more details.

Examples
// You can extend a String with some chars:
let mut message = String::from("abc");

message.extend(['d', 'e', 'f'].iter());

assert_eq!("abcdef", &message);

Provided Methods

fn extend_one(&mut self, item: A)

🔬This is a nightly-only experimental API. (extend_one)

Extends a collection with exactly one element.

fn extend_reserve(&mut self, additional: usize)

🔬This is a nightly-only experimental API. (extend_one)

Reserves capacity in a collection for the given number of additional elements.

The default implementation does nothing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.28.0 · Source

impl Extend<()> for ()

Source

impl Extend<(String, Value)> for serde_json::map::Map<String, Value>

Source

impl Extend<(String, Value)> for toml::map::Map<String, Value>

Source

impl Extend<Access> for Access

Source

impl Extend<AsciiChar> for String

Available on non-no_global_oom_handling only.
Source

impl Extend<AtFlags> for AtFlags

Source

impl Extend<BeginFlags> for BeginFlags

Source

impl Extend<Bytes> for BytesMut

Source

impl Extend<CMSOptions> for CMSOptions

Source

impl Extend<CipherCtxFlags> for CipherCtxFlags

Source

impl Extend<ControlModes> for ControlModes

Source

impl Extend<CreateFlags> for rustix::backend::event::epoll::CreateFlags

Source

impl Extend<CreateFlags> for rustix::backend::fs::inotify::CreateFlags

Source

impl Extend<DupFlags> for DupFlags

Source

impl Extend<EventFlags> for EventFlags

Source

impl Extend<EventKindMask> for EventKindMask

Source

impl Extend<EventMask> for EventMask

Source

impl Extend<EventfdFlags> for EventfdFlags

Source

impl Extend<ExtensionContext> for ExtensionContext

Source

impl Extend<FallocateFlags> for FallocateFlags

Source

impl Extend<FdFlags> for FdFlags

Source

impl Extend<FloatingPointEmulationControl> for FloatingPointEmulationControl

Source

impl Extend<FloatingPointExceptionMode> for FloatingPointExceptionMode

Source

impl Extend<IFlags> for IFlags

Source

impl Extend<InputModes> for InputModes

Source

impl Extend<LocalModes> for LocalModes

Source

impl Extend<MemfdFlags> for MemfdFlags

Source

impl Extend<Mode> for Mode

Source

impl Extend<OFlags> for OFlags

Source

impl Extend<OcspFlag> for OcspFlag

1.52.0 · Source

impl Extend<OsString> for OsString

Source

impl Extend<OutputModes> for OutputModes

Source

impl Extend<PidfdFlags> for PidfdFlags

Source

impl Extend<PidfdGetfdFlags> for PidfdGetfdFlags

Source

impl Extend<PipeFlags> for PipeFlags

Source

impl Extend<Pkcs7Flags> for Pkcs7Flags

Source

impl Extend<PollFlags> for PollFlags

Source

impl Extend<ReadFlags> for ReadFlags

Source

impl Extend<ReadWriteFlags> for ReadWriteFlags

Source

impl Extend<RecvFlags> for RecvFlags

Source

impl Extend<RenameFlags> for RenameFlags

Source

impl Extend<ResolveFlags> for ResolveFlags

Source

impl Extend<ReturnFlags> for ReturnFlags

Source

impl Extend<SealFlags> for SealFlags

Source

impl Extend<SendFlags> for SendFlags

Source

impl Extend<ShutdownState> for ShutdownState

Source

impl Extend<SocketAddrXdpFlags> for SocketAddrXdpFlags

Source

impl Extend<SocketFlags> for SocketFlags

Source

impl Extend<SpeculationFeatureControl> for SpeculationFeatureControl

Source

impl Extend<SpeculationFeatureState> for SpeculationFeatureState

Source

impl Extend<SpliceFlags> for SpliceFlags

Source

impl Extend<SslMode> for SslMode

Source

impl Extend<SslOptions> for SslOptions

Source

impl Extend<SslSessionCacheMode> for SslSessionCacheMode

Source

impl Extend<SslVerifyMode> for SslVerifyMode

Source

impl Extend<StatVfsMountFlags> for StatVfsMountFlags

Source

impl Extend<StatxAttributes> for StatxAttributes

Source

impl Extend<StatxFlags> for StatxFlags

1.4.0 · Source

impl Extend<String> for String

Available on non-no_global_oom_handling only.
Source

impl Extend<Table> for ArrayOfTables

Source

impl Extend<TimerfdFlags> for TimerfdFlags

Source

impl Extend<TimerfdTimerFlags> for TimerfdTimerFlags

Source

impl Extend<TrustAnchor<'static>> for RootCertStore

Source

impl Extend<TxTimeFlags> for TxTimeFlags

Source

impl Extend<UnalignedAccessControl> for UnalignedAccessControl

Source

impl Extend<WaitIdOptions> for WaitIdOptions

Source

impl Extend<WaitOptions> for WaitOptions

Source

impl Extend<WatchFlags> for WatchFlags

Source

impl Extend<WatchMask> for WatchMask

Source

impl Extend<X509CheckFlags> for X509CheckFlags

Source

impl Extend<X509VerifyFlags> for X509VerifyFlags

Source

impl Extend<XattrFlags> for XattrFlags

Source

impl Extend<XdpDescOptions> for XdpDescOptions

Source

impl Extend<XdpOptionsFlags> for XdpOptionsFlags

Source

impl Extend<XdpRingFlags> for XdpRingFlags

Source

impl Extend<XdpUmemRegFlags> for XdpUmemRegFlags

1.0.0 · Source

impl Extend<char> for String

Available on non-no_global_oom_handling only.
Source

impl Extend<u8> for BytesMut

Source

impl Extend<u8> for SimpleAssembler

Source

impl<'a, 'b, R> Extend<&'b u8> for Modifier<'a, R>
where R: Relocation,

Source

impl<'a, 'b> Extend<&'b u8> for UncommittedModifier<'a>

1.2.0 · Source

impl<'a, K, V, A> Extend<(&'a K, &'a V)> for BTreeMap<K, V, A>
where K: Ord + Copy, V: Copy, A: Allocator + Clone,

Source

impl<'a, K, V, S, A> Extend<&'a (K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

1.4.0 · Source

impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for tor_hsservice::internal_prelude::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Source

impl<'a, K, V, S, A> Extend<(&'a K, &'a V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash + Copy, V: Copy, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<'a, K, V, S> Extend<(&'a <K as WeakElement>::Strong, &'a V)> for PtrWeakKeyHashMap<K, V, S>
where K: 'a + WeakElement, <K as WeakElement>::Strong: Clone + Deref, V: 'a + Clone, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a <K as WeakElement>::Strong, &'a V)> for WeakKeyHashMap<K, V, S>
where K: 'a + WeakKey, <K as WeakElement>::Strong: Clone, V: 'a + Clone, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a K, &'a <V as WeakElement>::Strong)> for WeakValueHashMap<K, V, S>
where K: 'a + Eq + Hash + Clone, V: 'a + WeakElement, <V as WeakElement>::Strong: Clone, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(&'a K, &'a V)> for IndexMap<K, V, S>
where K: Hash + Eq + Copy, V: Copy, S: BuildHasher,

Source

impl<'a, K, V, S> Extend<(K, &'a V)> for SparseSecondaryMap<K, V, S>
where K: Key, V: 'a + Copy, S: BuildHasher,

Source

impl<'a, K, V> Extend<&'a V> for TiVec<K, V>
where V: 'a + Copy,

Source

impl<'a, K, V> Extend<(&'a K, &'a V)> for EnumMap<K, V>
where K: EnumArray<V> + Copy, V: Copy,

Source

impl<'a, K, V> Extend<(K, &'a V)> for SecondaryMap<K, V>
where K: Key, V: 'a + Copy,

Source

impl<'a, M, T1, T2, O1, O2> Extend<BitRef<'a, M, T2, O2>> for BitVec<T1, O1>
where M: Mutability, T1: BitStore, T2: BitStore, O1: BitOrder, O2: BitOrder,

Available on non-tarpaulin_include only.

Bit-Vector Extension by Proxy References

DO NOT use this. You clearly have a bit-slice. Use .extend_from_bitslice() instead!

Iterating over a bit-slice requires loading from memory and constructing a proxy reference for each bit. This is needlessly slow; the specialized method is able to avoid this per-bit cost and possibly even use batched operations.

Source

impl<'a, R> Extend<&'a u8> for Assembler<R>
where R: Relocation,

Source

impl<'a, R> Extend<&'a u8> for VecAssembler<R>
where R: Relocation,

Source

impl<'a, R> Extend<u8> for Modifier<'a, R>
where R: Relocation,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for BTreeSet<T, A>
where T: 'a + Ord + Copy, A: Allocator + Clone,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for BinaryHeap<T, A>
where T: 'a + Ord + Copy, A: Allocator,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for LinkedList<T, A>
where T: 'a + Copy, A: Allocator,

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for Vec<T, A>
where T: Copy + 'a, A: Allocator,

Available on non-no_global_oom_handling only.

Extend implementation that copies elements out of references before pushing them onto the Vec.

This implementation is specialized for slice iterators, where it uses copy_from_slice to append the entire slice at once.

1.2.0 · Source

impl<'a, T, A> Extend<&'a T> for VecDeque<T, A>
where T: 'a + Copy, A: Allocator,

Source

impl<'a, T, O> Extend<&'a T> for BitVec<T, O>
where T: BitStore, O: BitOrder,

Available on non-tarpaulin_include only.
Source

impl<'a, T, O> Extend<&'a bool> for BitVec<T, O>
where T: BitStore, O: BitOrder,

Available on non-tarpaulin_include only.
1.4.0 · Source

impl<'a, T, S, A> Extend<&'a T> for tor_hsservice::internal_prelude::HashSet<T, S, A>
where T: 'a + Eq + Hash + Copy, S: BuildHasher, A: Allocator,

Source

impl<'a, T, S, A> Extend<&'a T> for hashbrown::set::HashSet<T, S, A>
where T: 'a + Eq + Hash + Copy, S: BuildHasher, A: Allocator,

Source

impl<'a, T, S> Extend<&'a T> for IndexSet<T, S>
where T: Hash + Eq + Copy + 'a, S: BuildHasher,

Source

impl<'a, T> Extend<&'a EnumSet<T>> for EnumSet<T>
where T: EnumSetType,

Source

impl<'a, T> Extend<&'a EnumSet<T>> for MixedEnumSet<T>

Source

impl<'a, T> Extend<&'a MixedEnumSet<T>> for MixedEnumSet<T>

Source

impl<'a, T> Extend<&'a T> for EnumSet<T>
where T: EnumSetType,

Source

impl<'a, T> Extend<&'a T> for MixedEnumSet<T>

Source

impl<'a> Extend<&'a AsciiChar> for String

Available on non-no_global_oom_handling only.
1.52.0 · Source

impl<'a> Extend<&'a OsStr> for OsString

1.2.0 · Source

impl<'a> Extend<&'a char> for String

Available on non-no_global_oom_handling only.
1.0.0 · Source

impl<'a> Extend<&'a str> for String

Available on non-no_global_oom_handling only.
Source

impl<'a> Extend<&'a u8> for BytesMut

Source

impl<'a> Extend<&'a u8> for PrefixedPayload

Source

impl<'a> Extend<&'a u8> for SimpleAssembler

1.52.0 · Source

impl<'a> Extend<Cow<'a, OsStr>> for OsString

1.19.0 · Source

impl<'a> Extend<Cow<'a, str>> for String

Available on non-no_global_oom_handling only.
Source

impl<'a> Extend<u8> for UncommittedModifier<'a>

Source

impl<'slice, 'fd> Extend<SendAncillaryMessage<'slice, 'fd>> for SendAncillaryBuffer<'_, 'slice, 'fd>

Source

impl<A> Extend<<A as Array>::Item> for SmallVec<A>
where A: Array,

Source

impl<A> Extend<A> for AsciiString
where A: AsRef<AsciiStr>,

1.45.0 · Source

impl<A> Extend<Box<str, A>> for String
where A: Allocator,

Available on non-no_global_oom_handling only.


impl<F, R> Extend<R> for FlagSet<F>
where F: Flags, R: Into<FlagSet<F>>,

Source

impl<Fut> Extend<Fut> for FuturesOrdered<Fut>
where Fut: Future,

Source

impl<Fut> Extend<Fut> for FuturesUnordered<Fut>

Source

impl<I, P, H> Extend<(I, P)> for DoublePriorityQueue<I, P, H>
where I: Hash + Eq, P: Ord, H: BuildHasher,

Source

impl<I, P, H> Extend<(I, P)> for PriorityQueue<I, P, H>
where I: Hash + Eq, P: Ord, H: BuildHasher,

Source

impl<ID> Extend<ID> for RelayIdSet
where ID: Into<RelayId>,

1.0.0 · Source

impl<K, V, A> Extend<(K, V)> for BTreeMap<K, V, A>
where K: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<K, V, S, A> Extend<(K, V)> for tor_hsservice::internal_prelude::HashMap<K, V, S, A>
where K: Eq + Hash, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<K, V, S, A> Extend<(K, V)> for hashbrown::map::HashMap<K, V, S, A>
where K: Eq + Hash, S: BuildHasher, A: Allocator,

Inserts all new key-values from the iterator and replaces values with existing keys with new values returned from the iterator.

Source

impl<K, V, S> Extend<(<K as WeakElement>::Strong, <V as WeakElement>::Strong)> for PtrWeakWeakHashMap<K, V, S>

Source

impl<K, V, S> Extend<(<K as WeakElement>::Strong, <V as WeakElement>::Strong)> for WeakWeakHashMap<K, V, S>
where K: WeakKey, V: WeakElement, S: BuildHasher,

Source

impl<K, V, S> Extend<(<K as WeakElement>::Strong, V)> for PtrWeakKeyHashMap<K, V, S>

Source

impl<K, V, S> Extend<(<K as WeakElement>::Strong, V)> for WeakKeyHashMap<K, V, S>
where K: WeakKey, S: BuildHasher,

Source

impl<K, V, S> Extend<(K, <V as WeakElement>::Strong)> for WeakValueHashMap<K, V, S>
where K: Eq + Hash, V: WeakElement, S: BuildHasher,

Source

impl<K, V, S> Extend<(K, V)> for IndexMap<K, V, S>
where K: Hash + Eq, S: BuildHasher,

Source

impl<K, V, S> Extend<(K, V)> for LiteMap<K, V, S>
where K: Ord, S: StoreBulkMut<K, V>,

Source

impl<K, V, S> Extend<(K, V)> for SparseSecondaryMap<K, V, S>
where K: Key, S: BuildHasher,

Source

impl<K, V> Extend<(K, V)> for EnumMap<K, V>
where K: EnumArray<V>,

Source

impl<K, V> Extend<(K, V)> for InlineTable
where K: Into<Key>, V: Into<Value>,

Source

impl<K, V> Extend<(K, V)> for toml::map::Map<K, V>
where K: Ord + Hash,

Source

impl<K, V> Extend<(K, V)> for SecondaryMap<K, V>
where K: Key,

Source

impl<K, V> Extend<(K, V)> for Table
where K: Into<Key>, V: Into<Item>,

Source

impl<K, V> Extend<V> for TiVec<K, V>

Source

impl<L, R, A> Extend<A> for Either<L, R>
where L: Extend<A>, R: Extend<A>,

1.0.0 · Source

impl<P> Extend<P> for tor_hsservice::internal_prelude::PathBuf
where P: AsRef<Path>,

Source

impl<P> Extend<P> for async_std::path::pathbuf::PathBuf
where P: AsRef<Path>,

Source

impl<R> Extend<u8> for Assembler<R>
where R: Relocation,

Source

impl<R> Extend<u8> for VecAssembler<R>
where R: Relocation,

Source

impl<St> Extend<St> for SelectAll<St>
where St: Stream + Unpin,

1.0.0 · Source

impl<T, A> Extend<T> for BTreeSet<T, A>
where T: Ord, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Extend<T> for BinaryHeap<T, A>
where T: Ord, A: Allocator,

1.0.0 · Source

impl<T, A> Extend<T> for LinkedList<T, A>
where A: Allocator,

1.0.0 · Source

impl<T, A> Extend<T> for Vec<T, A>
where A: Allocator,

Available on non-no_global_oom_handling only.
1.0.0 · Source

impl<T, A> Extend<T> for VecDeque<T, A>
where A: Allocator,

1.56.0 · Source

impl<T, ExtendT> Extend<(T₁, T₂, …, Tₙ)> for (ExtendT₁, ExtendT₂, …, ExtendTₙ)
where ExtendT: Extend<T>,

This trait is implemented for tuples up to twelve items long. The impls for 1- and 3- through 12-ary tuples were stabilized after 2-tuples, in 1.85.0.

Source

impl<T, F> Extend<F> for JoinSet<T>
where F: Future<Output = T> + Send + 'static, T: Send + 'static,

Extend a JoinSet with futures from an iterator.

This is equivalent to calling JoinSet::spawn on each element of the iterator.

Examples

use tokio::task::JoinSet;

#[tokio::main]
async fn main() {
    let mut set: JoinSet<_> = (0..5).map(|i| async move { i }).collect();

    set.extend((5..10).map(|i| async move { i }));

    let mut seen = [false; 10];
    while let Some(res) = set.join_next().await {
        let idx = res.unwrap();
        seen[idx] = true;
    }

    for i in 0..10 {
        assert!(seen[i]);
    }
}
Source

impl<T, O> Extend<T> for BitVec<T, O>
where T: BitStore, O: BitOrder,

Source

impl<T, O> Extend<bool> for BitVec<T, O>
where T: BitStore, O: BitOrder,

Bit-Vector Extension

This extends a bit-vector from anything that produces individual bits.

Original

impl<T> Extend<T> for Vec<T>

Notes

This .extend() call is the second-slowest possible way to append bits into a bit-vector, faster only than calling iter.for_each(|bit| bv.push(bit)). DO NOT use this if you have any other choice.

If you are extending a bit-vector from the contents of a bit-slice, then you should use .extend_from_bitslice() instead. That method is specialized to perform upfront allocation and, where possible, use a batch copy rather than copying each bit individually from the source into the bit-vector.

1.0.0 · Source

impl<T, S, A> Extend<T> for tor_hsservice::internal_prelude::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S, A> Extend<T> for hashbrown::set::HashSet<T, S, A>
where T: Eq + Hash, S: BuildHasher, A: Allocator,

Source

impl<T, S> Extend<<T as WeakElement>::Strong> for PtrWeakHashSet<T, S>

Source

impl<T, S> Extend<<T as WeakElement>::Strong> for WeakHashSet<T, S>
where T: WeakKey, S: BuildHasher,

Source

impl<T, S> Extend<T> for IndexSet<T, S>
where T: Hash + Eq, S: BuildHasher,

Source

impl<T, const CAP: usize> Extend<T> for ArrayVec<T, CAP>

Extend the ArrayVec with an iterator.

Panics if extending the vector exceeds its capacity.

Source

impl<T> Extend<(HeaderName, T)> for HeaderMap<T>

Source

impl<T> Extend<(Option<HeaderName>, T)> for HeaderMap<T>

Source

impl<T> Extend<(String, T)> for NetParams<T>

Source

impl<T> Extend<EnumSet<T>> for EnumSet<T>
where T: EnumSetType,

Source

impl<T> Extend<EnumSet<T>> for MixedEnumSet<T>

Source

impl<T> Extend<MixedEnumSet<T>> for MixedEnumSet<T>

Source

impl<T> Extend<T> for EnumSet<T>
where T: EnumSetType,

Source

impl<T> Extend<T> for MixedEnumSet<T>

Source

impl<V> Extend<V> for Array
where V: Into<Value>,