pub(crate) struct InstanceRawSubdir {
dir: CheckedDir,
flock_guard: Arc<LockFileGuard>,
}Expand description
Subdirectory within an instance’s state, for raw filesystem operations
Dereferences to fs_mistrust::CheckedDir and can be used mostly like one.
Obtained from InstanceStateHandle::raw_subdir.
Existence of this value implies exclusive access to the instance.
If you need to manage the lock, and the directory path, separately,
raw_lock_guard
will help.
Fields
dir: CheckedDirflock_guard: Arc<LockFileGuard>Methods from Deref<Target = CheckedDir>
Sourcepub fn make_directory<P>(&self, path: P) -> Result<(), Error>
pub fn make_directory<P>(&self, path: P) -> Result<(), Error>
Construct a new directory within this CheckedDir, if it does not already exist.
path must be a relative path to the new directory, containing no ..
components.
Sourcepub fn make_secure_directory<P>(&self, path: P) -> Result<CheckedDir, Error>
pub fn make_secure_directory<P>(&self, path: P) -> Result<CheckedDir, Error>
Construct a new CheckedDir within this CheckedDir
Creates the directory if it does not already exist.
path must be a relative path to the new directory, containing no ..
components.
Sourcepub fn file_access(&self) -> FileAccess<'_>
pub fn file_access(&self) -> FileAccess<'_>
Create a new FileAccess for reading or writing files within this directory.
Sourcepub fn open<P>(&self, path: P, options: &OpenOptions) -> Result<File, Error>
pub fn open<P>(&self, path: P, options: &OpenOptions) -> Result<File, Error>
Open a file within this CheckedDir, using a set of OpenOptions.
path must be a relative path to the new directory, containing no ..
components. We check, but do not create, the file’s parent directories.
We check the file’s permissions after opening it. If the file already
exists, it must not be a symlink.
If the file is created (and this is a unix-like operating system), we
always create it with mode 600, regardless of any mode options set in
options.
Sourcepub fn read_directory<P>(&self, path: P) -> Result<ReadDir, Error>
pub fn read_directory<P>(&self, path: P) -> Result<ReadDir, Error>
List the contents of a directory within this CheckedDir.
path must be a relative path, containing no .. components. Before
listing the directory, we verify that that no untrusted user is able
change its contents or make it point somewhere else.
The return value is an iterator as returned by std::fs::ReadDir. We
do not check any properties of the elements of this iterator.
Sourcepub fn remove_file<P>(&self, path: P) -> Result<(), Error>
pub fn remove_file<P>(&self, path: P) -> Result<(), Error>
Remove a file within this CheckedDir.
path must be a relative path, containing no .. components.
Note that we ensure that the parent of the file to be removed is unmodifiable by any untrusted user, but we do not check any permissions on the file itself, since those are irrelevant to removing it.
Sourcepub fn as_path(&self) -> &Path
pub fn as_path(&self) -> &Path
Return a reference to this directory as a Path.
Note that this function lets you work with a broader collection of functions, including functions that might let you access or create a file that is accessible by non-trusted users. Be careful!
Sourcepub fn join<P>(&self, path: P) -> Result<PathBuf, Error>
pub fn join<P>(&self, path: P) -> Result<PathBuf, Error>
Return a new PathBuf containing this directory’s path, with path
appended to it.
Return an error if path has any components that could take us outside
of this directory.
Sourcepub fn read_to_string<P>(&self, path: P) -> Result<String, Error>
pub fn read_to_string<P>(&self, path: P) -> Result<String, Error>
Read the contents of the file at path within this directory, as a
String, if possible.
Return an error if path is absent, if its permissions are incorrect,
if it has any components that could take us outside of this directory,
or if its contents are not UTF-8.
Sourcepub fn read<P>(&self, path: P) -> Result<Vec<u8>, Error>
pub fn read<P>(&self, path: P) -> Result<Vec<u8>, Error>
Read the contents of the file at path within this directory, as a
vector of bytes, if possible.
Return an error if path is absent, if its permissions are incorrect,
or if it has any components that could take us outside of this
directory.
Sourcepub fn write_and_replace<P, C>(&self, path: P, contents: C) -> Result<(), Error>
pub fn write_and_replace<P, C>(&self, path: P, contents: C) -> Result<(), Error>
Store contents into the file located at path within this directory.
We won’t write to path directly: instead, we’ll write to a temporary
file in the same directory as path, and then replace path with that
temporary file if we were successful. (This isn’t truly atomic on all
file systems, but it’s closer than many alternatives.)
Limitations
This function will clobber any existing files with the same name as
path but with the extension tmp. (That is, if you are writing to
“foo.txt”, it will replace “foo.tmp” in the same directory.)
This function may give incorrect behavior if multiple threads or processes are writing to the same file at the same time: it is the programmer’s responsibility to use appropriate locking to avoid this.
Sourcepub fn metadata<P>(&self, path: P) -> Result<Metadata, Error>
pub fn metadata<P>(&self, path: P) -> Result<Metadata, Error>
Return the Metadata of the file located at path.
path must be a relative path, containing no .. components.
We check the file’s parent directories,
and the file’s permissions.
If the file exists, it must not be a symlink.
Returns Error::NotFound if the file does not exist.
Return an error if path is absent, if its permissions are incorrect1,
if the permissions of any of its the parent directories are incorrect,
or if it has any components that could take us outside of this directory.
the permissions are incorrect if the path is readable or writable by untrusted users ↩