pub(crate) struct LockFileGuard {
pub(crate) locked: LockFile,
}Expand description
A lock-file for which we hold the lock.
So long as this object exists, we hold the lock on this file. When it is dropped, we will release the lock.
Semantics
- Only one
LockFileGuardcan exist at one time for any particularpath. - This applies across all tasks and threads in all programs; other acquisitions of the lock in the same process are prevented.
- This applies across even separate machines, if
pathis on a shared filesystem.
Restrictions
pathmust only be deleted (or renamed) via the APIs in this module- This restriction applies to all programs on the computer,
so for example automatic file cleaning with
findandrmis forbidden. - Cross-filesystem locking is broken on Linux before 2.6.12.
Fields
locked: LockFileImplementations
Sourceimpl LockFileGuard
impl LockFileGuard
Sourcepub fn lock<P>(path: P) -> Result<LockFileGuard, Error>
pub fn lock<P>(path: P) -> Result<LockFileGuard, Error>
Try to construct a new LockFileGuard representing a lock we hold on
the file path.
Blocks until we can get the lock.
Sourcepub fn try_lock<P>(path: P) -> Result<Option<LockFileGuard>, Error>
pub fn try_lock<P>(path: P) -> Result<Option<LockFileGuard>, Error>
Try to construct a new LockFileGuard representing a lock we hold on
the file path.
Does not block; returns Ok(None) if somebody else holds the lock.