pub(crate) struct Relay<'a> {
pub(crate) rs: &'a RouterStatus,
pub(crate) md: &'a Microdesc,
pub(crate) cc: Option<CountryCode>,
}Expand description
A view of a relay on the Tor network, suitable for building circuits.
Fields
rs: &'a RouterStatusmd: &'a Microdesccc: Option<CountryCode>Implementations
Sourceimpl<'a> Relay<'a>
impl<'a> Relay<'a>
Sourcepub fn low_level_details(&self) -> RelayDetails<'_>
pub fn low_level_details(&self) -> RelayDetails<'_>
Return a RelayDetails for this relay.
Callers should generally avoid using this information directly if they can; it’s better to use a higher-level function that exposes semantic information rather than these properties.
Sourcepub fn id(&self) -> &Ed25519Identity
pub fn id(&self) -> &Ed25519Identity
Return the Ed25519 ID for this relay.
Sourcepub fn rsa_id(&self) -> &RsaIdentity
pub fn rsa_id(&self) -> &RsaIdentity
Return the RsaIdentity for this relay.
Sourcepub fn rs(&self) -> &RouterStatus
pub fn rs(&self) -> &RouterStatus
Return a reference to this relay’s “router status” entry in the consensus.
The router status entry contains information about the relay that the authorities voted on directly. For most use cases, you shouldn’t need them.
This function is only available if the crate was built with
its experimental-api feature.
Sourcepub fn md(&self) -> &Microdesc
pub fn md(&self) -> &Microdesc
Return a reference to this relay’s “microdescriptor” entry in the consensus.
A “microdescriptor” is a synopsis of the information about a relay, used to determine its capabilities and route traffic through it. For most use cases, you shouldn’t need it.
This function is only available if the crate was built with
its experimental-api feature.