pub(crate) struct RelayIds {
ed_identity: Option<Ed25519Identity>,
rsa_identity: Option<RsaIdentity>,
}Expand description
RelayIds is an owned copy of the set of known identities of a relay.
Note that an object of this type will not necessarily have every type of identity: it’s possible that we don’t know all the identities, or that one of the identity types has become optional.
Fields
ed_identity: Option<Ed25519Identity>rsa_identity: Option<RsaIdentity>Implementations
Sourceimpl RelayIds
impl RelayIds
Sourcepub const fn empty() -> RelayIds
pub const fn empty() -> RelayIds
Return an empty set of identities.
This is not a Default method, since this is not what you should
usually construct.
Sourcepub fn from_relay_ids<T>(other: &T) -> RelayIdswhere
T: HasRelayIds + ?Sized,
pub fn from_relay_ids<T>(other: &T) -> RelayIdswhere
T: HasRelayIds + ?Sized,
Construct a new RelayIds object from another object that implements
HasRelayIds.
Note that it is possible to construct an empty RelayIds object if
the input does not contain any recognized identity type.