pub(crate) struct RetryDelay {
last_delay_ms: u32,
low_bound_ms: u32,
}Expand description
An implementation for retrying a remote operation based on a decorrelated jitter schedule.
The algorithm used here has several desirable properties:
- It is randomized, so that multiple timeouts don’t have a danger of getting synchronized with each other and hammering the same servers all at once.
- It tends on average to wait longer and longer over time, so that if the server is down, it won’t get pummeled by a zillion failing clients when it comes back up.
- It has a chance of retrying promptly, which results in better client performance on average.
For a more full specification, see dir-spec.txt.
Fields
last_delay_ms: u32low_bound_ms: u32Implementations
Sourceimpl RetryDelay
impl RetryDelay
Sourcepub fn from_msec(base_delay_msec: u32) -> RetryDelay
pub fn from_msec(base_delay_msec: u32) -> RetryDelay
Construct a new RetryDelay from a given base delay in milliseconds.
The base delay defines the lowest possible interval that can be returned.
Limitations
If the base delay is less than 1000, a base delay of 1000 is used instead, since that’s what the C tor implementation does.
Sourcepub fn from_duration(d: Duration) -> RetryDelay
pub fn from_duration(d: Duration) -> RetryDelay
Construct a new RetryDelay from a given base delay.
See from_msec for more information.
Sourcepub fn next_delay<R>(&mut self, rng: &mut R) -> Durationwhere
R: Rng,
pub fn next_delay<R>(&mut self, rng: &mut R) -> Durationwhere
R: Rng,
Return the next delay to be used (as a Duration),
according to a given random number generator.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Return this RetryDelay to its original state.