pub(crate) struct Slug(Box<str>);Expand description
An owned slug, checked for syntax
The syntax check can be relied on for safety/soundness.
Tuple Fields
0: Box<str>Implementations
Sourceimpl Slug
impl Slug
Sourcepub fn new(s: String) -> Result<Slug, BadSlug>
pub fn new(s: String) -> Result<Slug, BadSlug>
Make a Slug out of an owned String, if it has the correct syntax
Sourcepub unsafe fn new_unchecked(s: String) -> Slug
pub unsafe fn new_unchecked(s: String) -> Slug
Make a Slug out of an owned String, without checking the syntax
Safety
It’s the caller’s responsibility to check the syntax of the input string.