pub(crate) trait Hash {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Hash for DivError
impl Hash for PositDecodeError
impl Hash for amplify_num::hex::Error
impl Hash for ascii::ascii_char::AsciiChar
impl Hash for async_signal::Signal
impl Hash for point_conversion_form_t
impl Hash for byteorder::BigEndian
impl Hash for byteorder::LittleEndian
impl Hash for RV
impl Hash for dynasmrt::aarch64::RX
impl Hash for RXSP
impl Hash for LabelKind
impl Hash for TargetKind
impl Hash for RelocationSize
impl Hash for RF
impl Hash for dynasmrt::riscv::RX
impl Hash for dynasmrt::x64::RC
impl Hash for Rq
impl Hash for dynasmrt::x64::Rx
impl Hash for RB
impl Hash for dynasmrt::x86::RC
impl Hash for RD
impl Hash for Rd
impl Hash for Rf
impl Hash for Rh
impl Hash for Rm
impl Hash for Rs
impl Hash for dynasmrt::x86::Rx
impl Hash for TrustedGroup
impl Hash for TrustedUser
impl Hash for PollNext
impl Hash for ExtensionType
impl Hash for CalendarAlgorithm
impl Hash for HijriCalendarAlgorithm
impl Hash for CollationCaseFirst
impl Hash for CollationNumericOrdering
impl Hash for CollationType
impl Hash for CurrencyFormatStyle
impl Hash for EmojiPresentationStyle
impl Hash for FirstDay
impl Hash for HourCycle
impl Hash for LineBreakStyle
impl Hash for LineBreakWordHandling
impl Hash for MeasurementSystem
impl Hash for MeasurementUnitOverride
impl Hash for SentenceBreakSupressions
impl Hash for CommonVariantType
impl Hash for GeneralCategory
impl Hash for BufferFormat
impl Hash for inotify::events::EventKind
impl Hash for tpacket_versions
impl Hash for fsconfig_command
impl Hash for membarrier_cmd
impl Hash for membarrier_cmd_flag
impl Hash for procfs_ino
impl Hash for procmap_query_flags
impl Hash for linux_raw_sys::net::_bindgen_ty_1
impl Hash for linux_raw_sys::net::_bindgen_ty_2
impl Hash for linux_raw_sys::net::_bindgen_ty_3
impl Hash for linux_raw_sys::net::_bindgen_ty_4
impl Hash for linux_raw_sys::net::_bindgen_ty_5
impl Hash for linux_raw_sys::net::_bindgen_ty_6
impl Hash for linux_raw_sys::net::_bindgen_ty_7
impl Hash for linux_raw_sys::net::_bindgen_ty_8
impl Hash for linux_raw_sys::net::_bindgen_ty_9
impl Hash for linux_raw_sys::net::_bindgen_ty_10
impl Hash for hwtstamp_flags
impl Hash for hwtstamp_provider_qualifier
impl Hash for hwtstamp_rx_filters
impl Hash for hwtstamp_tx_types
impl Hash for net_device_flags
impl Hash for nf_dev_hooks
impl Hash for nf_inet_hooks
impl Hash for nf_ip6_hook_priorities
impl Hash for nf_ip_hook_priorities
impl Hash for socket_state
impl Hash for tcp_ca_state
impl Hash for tcp_fastopen_client_fail
impl Hash for txtime_flags
impl Hash for linux_raw_sys::netlink::_bindgen_ty_1
impl Hash for linux_raw_sys::netlink::_bindgen_ty_2
impl Hash for linux_raw_sys::netlink::_bindgen_ty_3
impl Hash for linux_raw_sys::netlink::_bindgen_ty_4
impl Hash for linux_raw_sys::netlink::_bindgen_ty_5
impl Hash for linux_raw_sys::netlink::_bindgen_ty_6
impl Hash for linux_raw_sys::netlink::_bindgen_ty_7
impl Hash for linux_raw_sys::netlink::_bindgen_ty_8
impl Hash for linux_raw_sys::netlink::_bindgen_ty_9
impl Hash for linux_raw_sys::netlink::_bindgen_ty_10
impl Hash for _bindgen_ty_11
impl Hash for _bindgen_ty_12
impl Hash for _bindgen_ty_13
impl Hash for _bindgen_ty_14
impl Hash for _bindgen_ty_15
impl Hash for _bindgen_ty_16
impl Hash for _bindgen_ty_17
impl Hash for _bindgen_ty_18
impl Hash for _bindgen_ty_19
impl Hash for _bindgen_ty_20
impl Hash for _bindgen_ty_21
impl Hash for _bindgen_ty_22
impl Hash for _bindgen_ty_23
impl Hash for _bindgen_ty_24
impl Hash for _bindgen_ty_25
impl Hash for _bindgen_ty_26
impl Hash for _bindgen_ty_27
impl Hash for _bindgen_ty_28
impl Hash for _bindgen_ty_29
impl Hash for _bindgen_ty_30
impl Hash for _bindgen_ty_31
impl Hash for _bindgen_ty_32
impl Hash for _bindgen_ty_33
impl Hash for _bindgen_ty_34
impl Hash for _bindgen_ty_35
impl Hash for _bindgen_ty_36
impl Hash for _bindgen_ty_37
impl Hash for _bindgen_ty_38
impl Hash for _bindgen_ty_39
impl Hash for _bindgen_ty_40
impl Hash for _bindgen_ty_41
impl Hash for _bindgen_ty_42
impl Hash for _bindgen_ty_43
impl Hash for _bindgen_ty_44
impl Hash for _bindgen_ty_45
impl Hash for _bindgen_ty_46
impl Hash for _bindgen_ty_47
impl Hash for _bindgen_ty_48
impl Hash for _bindgen_ty_49
impl Hash for _bindgen_ty_50
impl Hash for _bindgen_ty_51
impl Hash for _bindgen_ty_52
impl Hash for _bindgen_ty_53
impl Hash for _bindgen_ty_54
impl Hash for _bindgen_ty_55
impl Hash for _bindgen_ty_56
impl Hash for _bindgen_ty_57
impl Hash for _bindgen_ty_58
impl Hash for _bindgen_ty_59
impl Hash for _bindgen_ty_60
impl Hash for _bindgen_ty_61
impl Hash for _bindgen_ty_62
impl Hash for _bindgen_ty_63
impl Hash for _bindgen_ty_64
impl Hash for _bindgen_ty_65
impl Hash for _bindgen_ty_66
impl Hash for _bindgen_ty_67
impl Hash for _bindgen_ty_68
impl Hash for _bindgen_ty_69
impl Hash for _bindgen_ty_70
impl Hash for ifla_geneve_df
impl Hash for ifla_gtp_role
impl Hash for ifla_vxlan_df
impl Hash for ifla_vxlan_label_policy
impl Hash for in6_addr_gen_mode
impl Hash for ipvlan_mode
impl Hash for macsec_offload
impl Hash for macsec_validation_type
impl Hash for macvlan_macaddr_mode
impl Hash for macvlan_mode
impl Hash for netkit_action
impl Hash for netkit_mode
impl Hash for netkit_scrub
impl Hash for netlink_attribute_type
impl Hash for netlink_policy_type_attr
impl Hash for nl80211_ac
impl Hash for nl80211_acl_policy
impl Hash for nl80211_ap_settings_flags
impl Hash for nl80211_ap_sme_features
impl Hash for nl80211_attr_coalesce_rule
impl Hash for nl80211_attr_cqm
impl Hash for nl80211_attrs
impl Hash for nl80211_auth_type
impl Hash for nl80211_band
impl Hash for nl80211_band_attr
impl Hash for nl80211_band_iftype_attr
impl Hash for nl80211_bitrate_attr
impl Hash for nl80211_bss
impl Hash for nl80211_bss_cannot_use_reasons
impl Hash for nl80211_bss_color_attributes
impl Hash for nl80211_bss_scan_width
impl Hash for nl80211_bss_select_attr
impl Hash for nl80211_bss_status
impl Hash for nl80211_bss_use_for
impl Hash for nl80211_chan_width
impl Hash for nl80211_channel_type
impl Hash for nl80211_coalesce_condition
impl Hash for nl80211_commands
impl Hash for nl80211_connect_failed_reason
impl Hash for nl80211_cqm_rssi_threshold_event
impl Hash for nl80211_crit_proto_id
impl Hash for nl80211_dfs_regions
impl Hash for nl80211_dfs_state
impl Hash for nl80211_eht_gi
impl Hash for nl80211_eht_ru_alloc
impl Hash for nl80211_ext_feature_index
impl Hash for nl80211_external_auth_action
impl Hash for nl80211_feature_flags
impl Hash for nl80211_fils_discovery_attributes
impl Hash for nl80211_frequency_attr
impl Hash for nl80211_ftm_responder_attributes
impl Hash for nl80211_ftm_responder_stats
impl Hash for nl80211_he_gi
impl Hash for nl80211_he_ltf
impl Hash for nl80211_he_ru_alloc
impl Hash for nl80211_if_combination_attrs
impl Hash for nl80211_iface_limit_attrs
impl Hash for nl80211_iftype
impl Hash for nl80211_iftype_akm_attributes
impl Hash for nl80211_key_attributes
impl Hash for nl80211_key_default_types
impl Hash for nl80211_key_mode
impl Hash for nl80211_key_type
impl Hash for nl80211_mbssid_config_attributes
impl Hash for nl80211_mesh_power_mode
impl Hash for nl80211_mesh_setup_params
impl Hash for nl80211_meshconf_params
impl Hash for nl80211_mfp
impl Hash for nl80211_mntr_flags
impl Hash for nl80211_mpath_flags
impl Hash for nl80211_mpath_info
impl Hash for nl80211_nan_func_attributes
impl Hash for nl80211_nan_func_term_reason
impl Hash for nl80211_nan_function_type
impl Hash for nl80211_nan_match_attributes
impl Hash for nl80211_nan_publish_type
impl Hash for nl80211_nan_srf_attributes
impl Hash for nl80211_obss_pd_attributes
impl Hash for nl80211_packet_pattern_attr
impl Hash for nl80211_peer_measurement_attrs
impl Hash for nl80211_peer_measurement_ftm_capa
impl Hash for nl80211_peer_measurement_ftm_failure_reasons
impl Hash for nl80211_peer_measurement_ftm_req
impl Hash for nl80211_peer_measurement_ftm_resp
impl Hash for nl80211_peer_measurement_peer_attrs
impl Hash for nl80211_peer_measurement_req
impl Hash for nl80211_peer_measurement_resp
impl Hash for nl80211_peer_measurement_status
impl Hash for nl80211_peer_measurement_type
impl Hash for nl80211_plink_action
impl Hash for nl80211_plink_state
impl Hash for nl80211_pmksa_candidate_attr
impl Hash for nl80211_preamble
impl Hash for nl80211_probe_resp_offload_support_attr
impl Hash for nl80211_protocol_features
impl Hash for nl80211_ps_state
impl Hash for nl80211_radar_event
impl Hash for nl80211_rate_info
impl Hash for nl80211_reg_initiator
impl Hash for nl80211_reg_rule_attr
impl Hash for nl80211_reg_rule_flags
impl Hash for nl80211_reg_type
impl Hash for nl80211_rekey_data
impl Hash for nl80211_rxmgmt_flags
impl Hash for nl80211_s1g_short_beacon_attrs
impl Hash for nl80211_sae_pwe_mechanism
impl Hash for nl80211_sar_attrs
impl Hash for nl80211_sar_specs_attrs
impl Hash for nl80211_sar_type
impl Hash for nl80211_scan_flags
impl Hash for nl80211_sched_scan_match_attr
impl Hash for nl80211_sched_scan_plan
impl Hash for nl80211_smps_mode
impl Hash for nl80211_sta_bss_param
impl Hash for nl80211_sta_flags
impl Hash for nl80211_sta_info
impl Hash for nl80211_sta_p2p_ps_status
impl Hash for nl80211_sta_wme_attr
impl Hash for nl80211_survey_info
impl Hash for nl80211_tdls_operation
impl Hash for nl80211_tdls_peer_capability
impl Hash for nl80211_tid_config
impl Hash for nl80211_tid_config_attr
impl Hash for nl80211_tid_stats
impl Hash for nl80211_timeout_reason
impl Hash for nl80211_tx_power_setting
impl Hash for nl80211_tx_rate_attributes
impl Hash for nl80211_tx_rate_setting
impl Hash for nl80211_txq_attr
impl Hash for nl80211_txq_stats
impl Hash for nl80211_txrate_gi
impl Hash for nl80211_unsol_bcast_probe_resp_attributes
impl Hash for nl80211_user_reg_hint_type
impl Hash for nl80211_wiphy_radio_attrs
impl Hash for nl80211_wiphy_radio_freq_range
impl Hash for nl80211_wmm_rule
impl Hash for nl80211_wowlan_tcp_attrs
impl Hash for nl80211_wowlan_triggers
impl Hash for nl80211_wpa_versions
impl Hash for nl_mmap_status
impl Hash for nlmsgerr_attrs
impl Hash for ovpn_mode
impl Hash for rt_class_t
impl Hash for rt_scope_t
impl Hash for rtattr_type_t
impl Hash for rtnetlink_groups
impl Hash for log::Level
impl Hash for log::LevelFilter
impl Hash for Timer
impl Hash for Operation
impl Hash for maybenot::event::Event
impl Hash for TriggerEvent
impl Hash for Advice
impl Hash for UncheckedAdvice
impl Hash for CompressionStrategy
impl Hash for TDEFLFlush
impl Hash for TDEFLStatus
impl Hash for CompressionLevel
impl Hash for DataFormat
impl Hash for MZError
impl Hash for MZFlush
impl Hash for MZStatus
impl Hash for TINFLStatus
impl Hash for nom::error::ErrorKind
impl Hash for CheckedError
impl Hash for RecursiveMode
impl Hash for WatcherKind
impl Hash for DebouncedEventKind
impl Hash for AccessKind
impl Hash for AccessMode
impl Hash for CreateKind
impl Hash for DataChange
impl Hash for notify_types::event::EventKind
impl Hash for Flag
impl Hash for MetadataKind
impl Hash for ModifyKind
impl Hash for RemoveKind
impl Hash for RenameMode
impl Hash for Sign
impl Hash for PollMode
impl Hash for TimerfdClockId
impl Hash for ClockId
impl Hash for Direction
impl Hash for Timeout
impl Hash for Shutdown
impl Hash for Action
impl Hash for OptionalActions
impl Hash for QueueSelector
impl Hash for rustls_pki_types::server_name::IpAddr
impl Hash for serde_json::value::Value
impl Hash for serde_value::Value
impl Hash for Cipher
impl Hash for Algorithm
impl Hash for EcdsaCurve
impl Hash for HashAlg
impl Hash for KdfAlg
impl Hash for EcdsaPublicKey
impl Hash for ssh_key_fork_arti::public::key_data::KeyData
impl Hash for strum::ParseError
impl Hash for ProcessStatus
impl Hash for sysinfo::common::system::Signal
impl Hash for Month
impl Hash for Weekday
impl Hash for Encoding
impl Hash for IntegerRadix
impl Hash for ScalarKind
impl Hash for TokenKind
impl Hash for toml_parser::parser::event::EventKind
impl Hash for BoolOrAuto
impl Hash for PaddingLevel
impl Hash for ConfigurationSource
impl Hash for CertType
impl Hash for KeyType
impl Hash for KeystoreItemType
impl Hash for CTorPath
impl Hash for KeyPath
impl Hash for KeyPathPattern
impl Hash for RelayId
impl Hash for RelayIdType
impl Hash for ChannelMethod
impl Hash for PtTargetAddr
impl Hash for CollapseReason
impl Hash for Reclaimed
impl Hash for AuthCertVersion
impl Hash for ConsensusFlavor
impl Hash for NetstatusKwd
impl Hash for SoftwareVersion
impl Hash for InternetHost
impl Hash for DigestName
impl Hash for OverloadGeneralVersion
impl Hash for RuleKind
impl Hash for BadSlug
impl Hash for Liveness
impl Hash for SocksAuth
impl Hash for Origin
impl Hash for zerocopy::byteorder::BigEndian
impl Hash for zerocopy::byteorder::LittleEndian
impl Hash for ZSTD_EndDirective
impl Hash for ZSTD_ErrorCode
impl Hash for ZSTD_ResetDirective
impl Hash for ZSTD_cParameter
impl Hash for ZSTD_dParameter
impl Hash for ZSTD_strategy
impl Hash for tor_hsservice::internal_prelude::Ordering
impl Hash for core::ascii::ascii_char::AsciiChar
impl Hash for CharCase
impl Hash for Infallible
impl Hash for Locality
impl Hash for core::net::ip_addr::IpAddr
impl Hash for Ipv6MulticastScope
impl Hash for SocketAddr
impl Hash for IntErrorKind
impl Hash for core::sync::atomic::Ordering
impl Hash for tor_hsservice::internal_prelude::io::ErrorKind
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for aho_corasick::util::primitives::PatternID
impl Hash for aho_corasick::util::primitives::StateID
impl Hash for aho_corasick::util::search::Match
impl Hash for aho_corasick::util::search::Span
impl Hash for i256
impl Hash for i512
impl Hash for i1024
impl Hash for u256
impl Hash for u512
impl Hash for u1024
impl Hash for ParseLengthError
impl Hash for Posit8
impl Hash for Posit16
impl Hash for Posit32
impl Hash for Posit64
impl Hash for Posit128
impl Hash for Posit256
impl Hash for Posit512
impl Hash for u1
impl Hash for u2
impl Hash for u3
impl Hash for u4
impl Hash for u5
impl Hash for u6
impl Hash for u7
impl Hash for u24
impl Hash for u40
impl Hash for u48
impl Hash for u56
impl Hash for AsciiStr
impl Hash for AsciiString
impl Hash for async_std::path::path::Path
impl Hash for async_std::path::pathbuf::PathBuf
impl Hash for TaskId
impl Hash for Base64Bcrypt
impl Hash for Base64Crypt
impl Hash for Base64Pbkdf2
impl Hash for Base64ShaCrypt
impl Hash for Base64
impl Hash for Base64Unpadded
impl Hash for Base64Url
impl Hash for Base64UrlUnpadded
impl Hash for Lsb0
impl Hash for Msb0
impl Hash for bstr::bstr::BStr
impl Hash for BString
impl Hash for bytes::bytes::Bytes
impl Hash for BytesMut
impl Hash for coarsetime::duration::Duration
impl Hash for coarsetime::instant::Instant
impl Hash for ObjectIdentifier
impl Hash for Limb
impl Hash for CompressedEdwardsY
impl Hash for MontgomeryPoint
impl Hash for CompressedRistretto
impl Hash for Scalar
impl Hash for StaticLabel
impl Hash for AssemblyOffset
impl Hash for DynamicLabel
impl Hash for VerifyingKey
impl Hash for errno::Errno
impl Hash for Blocking
impl Hash for Profile
impl Hash for Tag
impl Hash for FileTime
impl Hash for FullError
impl Hash for HeaderName
impl Hash for HeaderValue
impl Hash for Method
impl Hash for StatusCode
impl Hash for Authority
Case-insensitive hashing
Examples
let a: Authority = "HELLO.com".parse().unwrap();
let b: Authority = "hello.coM".parse().unwrap();
let mut s = DefaultHasher::new();
a.hash(&mut s);
let a = s.finish();
let mut s = DefaultHasher::new();
b.hash(&mut s);
let b = s.finish();
assert_eq!(a, b);impl Hash for PathAndQuery
impl Hash for Scheme
Case-insensitive hashing
impl Hash for Uri
impl Hash for Version
impl Hash for HttpDate
impl Hash for humantime::wrapper::Duration
impl Hash for Timestamp
impl Hash for DataLocale
impl Hash for Other
impl Hash for icu_locale_core::extensions::private::other::Subtag
impl Hash for Private
impl Hash for Extensions
impl Hash for Fields
impl Hash for icu_locale_core::extensions::transform::key::Key
impl Hash for Transform
impl Hash for icu_locale_core::extensions::transform::value::Value
impl Hash for Attribute
impl Hash for Attributes
impl Hash for icu_locale_core::extensions::unicode::key::Key
impl Hash for Keywords
impl Hash for Unicode
impl Hash for SubdivisionId
impl Hash for SubdivisionSuffix
impl Hash for icu_locale_core::extensions::unicode::value::Value
impl Hash for LanguageIdentifier
impl Hash for Locale
impl Hash for CurrencyType
impl Hash for NumberingSystem
impl Hash for RegionOverride
impl Hash for RegionalSubdivision
impl Hash for TimeZoneShortId
impl Hash for LocalePreferences
impl Hash for Language
impl Hash for Region
impl Hash for icu_locale_core::subtags::script::Script
impl Hash for icu_locale_core::subtags::Subtag
impl Hash for Variant
impl Hash for Variants
impl Hash for BidiClass
impl Hash for CanonicalCombiningClass
impl Hash for EastAsianWidth
impl Hash for GeneralCategoryOutOfBoundsError
impl Hash for GraphemeClusterBreak
impl Hash for HangulSyllableType
impl Hash for IndicConjunctBreak
impl Hash for IndicSyllabicCategory
impl Hash for JoiningType
impl Hash for LineBreak
impl Hash for icu_properties::props::Script
impl Hash for SentenceBreak
impl Hash for VerticalOrientation
impl Hash for WordBreak
impl Hash for DataMarkerId
impl Hash for DataMarkerIdHash
impl Hash for DataMarkerInfo
impl Hash for DataMarkerAttributes
impl Hash for EventAuxiliaryFlags
impl Hash for EventMask
impl Hash for ParsedEventMask
impl Hash for WatchDescriptor
impl Hash for WatchMask
impl Hash for rtentry
impl Hash for bcm_msg_head
impl Hash for bcm_timeval
impl Hash for j1939_filter
impl Hash for can_berr_counter
impl Hash for can_bittiming
impl Hash for can_bittiming_const
impl Hash for can_clock
impl Hash for can_ctrlmode
impl Hash for can_device_stats
impl Hash for __c_anonymous_sockaddr_can_j1939
impl Hash for __c_anonymous_sockaddr_can_tp
impl Hash for can_filter
impl Hash for can_frame
impl Hash for canfd_frame
impl Hash for canxl_frame
impl Hash for nl_mmap_hdr
impl Hash for nl_mmap_req
impl Hash for nl_pktinfo
impl Hash for nlattr
impl Hash for nlmsgerr
impl Hash for nlmsghdr
impl Hash for sockaddr_nl
impl Hash for pidfd_info
impl Hash for termios2
impl Hash for msqid_ds
impl Hash for semid_ds
impl Hash for sigset_t
impl Hash for sysinfo
impl Hash for timex
impl Hash for statvfs
impl Hash for _libc_fpstate
impl Hash for _libc_fpxreg
impl Hash for _libc_xmmreg
impl Hash for clone_args
impl Hash for flock64
impl Hash for flock
impl Hash for ipc_perm
impl Hash for mcontext_t
impl Hash for pthread_attr_t
impl Hash for ptrace_rseq_configuration
impl Hash for shmid_ds
impl Hash for sigaction
impl Hash for siginfo_t
impl Hash for stack_t
impl Hash for stat64
impl Hash for stat
impl Hash for statfs64
impl Hash for statfs
impl Hash for statvfs64
impl Hash for ucontext_t
impl Hash for user
impl Hash for user_fpregs_struct
impl Hash for user_regs_struct
impl Hash for Elf32_Chdr
impl Hash for Elf64_Chdr
impl Hash for __c_anonymous_ptrace_syscall_info_entry
impl Hash for __c_anonymous_ptrace_syscall_info_exit
impl Hash for __c_anonymous_ptrace_syscall_info_seccomp
impl Hash for __exit_status
impl Hash for __timeval
impl Hash for aiocb
impl Hash for cmsghdr
impl Hash for fanotify_event_info_error
impl Hash for fanotify_event_info_pidfd
impl Hash for fpos64_t
impl Hash for fpos_t
impl Hash for glob64_t
impl Hash for iocb
impl Hash for mallinfo2
impl Hash for mallinfo
impl Hash for mbstate_t
impl Hash for msghdr
impl Hash for ntptimeval
impl Hash for ptrace_peeksiginfo_args
impl Hash for ptrace_sud_config
impl Hash for ptrace_syscall_info
impl Hash for regex_t
impl Hash for sem_t
impl Hash for seminfo
impl Hash for tcp_info
impl Hash for termios
impl Hash for timespec
impl Hash for utmpx
impl Hash for __c_anonymous__kernel_fsid_t
impl Hash for af_alg_iv
extra_traits only.impl Hash for dmabuf_cmsg
impl Hash for dmabuf_token
impl Hash for dqblk
impl Hash for epoll_params
impl Hash for fanotify_event_info_fid
impl Hash for fanotify_event_info_header
impl Hash for fanotify_event_metadata
impl Hash for fanotify_response
impl Hash for fanout_args
impl Hash for ff_condition_effect
impl Hash for ff_constant_effect
impl Hash for ff_effect
impl Hash for ff_envelope
impl Hash for ff_periodic_effect
impl Hash for ff_ramp_effect
impl Hash for ff_replay
impl Hash for ff_rumble_effect
impl Hash for ff_trigger
impl Hash for file_handle
impl Hash for genlmsghdr
impl Hash for hwtstamp_config
impl Hash for ifinfomsg
impl Hash for in6_ifreq
impl Hash for inotify_event
impl Hash for input_absinfo
impl Hash for input_event
impl Hash for input_id
impl Hash for input_keymap_entry
impl Hash for input_mask
impl Hash for iw_discarded
impl Hash for iw_encode_ext
impl Hash for iw_freq
impl Hash for iw_michaelmicfailure
impl Hash for iw_missed
impl Hash for iw_mlme
impl Hash for iw_param
impl Hash for iw_pmkid_cand
impl Hash for iw_pmksa
impl Hash for iw_point
impl Hash for iw_priv_args
impl Hash for iw_quality
impl Hash for iw_range
impl Hash for iw_scan_req
impl Hash for iw_statistics
impl Hash for iw_thrspy
impl Hash for mnt_ns_info
impl Hash for mount_attr
impl Hash for mq_attr
impl Hash for msginfo
impl Hash for open_how
impl Hash for posix_spawn_file_actions_t
impl Hash for posix_spawnattr_t
impl Hash for pthread_barrier_t
impl Hash for pthread_barrierattr_t
impl Hash for pthread_cond_t
impl Hash for pthread_condattr_t
impl Hash for pthread_mutex_t
impl Hash for pthread_mutexattr_t
impl Hash for pthread_rwlock_t
impl Hash for pthread_rwlockattr_t
impl Hash for ptp_clock_caps
impl Hash for ptp_clock_time
impl Hash for ptp_extts_event
impl Hash for ptp_extts_request
impl Hash for ptp_pin_desc
impl Hash for ptp_sys_offset
impl Hash for ptp_sys_offset_extended
impl Hash for ptp_sys_offset_precise
impl Hash for sched_attr
impl Hash for sctp_authinfo
impl Hash for sctp_initmsg
impl Hash for sctp_nxtinfo
impl Hash for sctp_prinfo
impl Hash for sctp_rcvinfo
impl Hash for sctp_sndinfo
impl Hash for sctp_sndrcvinfo
impl Hash for seccomp_data
impl Hash for seccomp_notif
impl Hash for seccomp_notif_addfd
impl Hash for seccomp_notif_resp
impl Hash for seccomp_notif_sizes
impl Hash for signalfd_siginfo
impl Hash for sock_extended_err
impl Hash for sockaddr_alg
impl Hash for sockaddr_pkt
impl Hash for sockaddr_vm
impl Hash for sockaddr_xdp
impl Hash for tls12_crypto_info_aes_ccm_128
impl Hash for tls12_crypto_info_aes_gcm_128
impl Hash for tls12_crypto_info_aes_gcm_256
impl Hash for tls12_crypto_info_aria_gcm_128
impl Hash for tls12_crypto_info_aria_gcm_256
impl Hash for tls12_crypto_info_chacha20_poly1305
impl Hash for tls12_crypto_info_sm4_ccm
impl Hash for tls12_crypto_info_sm4_gcm
impl Hash for tls_crypto_info
impl Hash for tpacket2_hdr
impl Hash for tpacket3_hdr
impl Hash for tpacket_auxdata
impl Hash for tpacket_bd_ts
impl Hash for tpacket_hdr
impl Hash for tpacket_hdr_v1
impl Hash for tpacket_hdr_variant1
impl Hash for tpacket_req3
impl Hash for tpacket_req
impl Hash for tpacket_rollover_stats
impl Hash for tpacket_stats
impl Hash for tpacket_stats_v3
impl Hash for uinput_abs_setup
impl Hash for uinput_ff_erase
impl Hash for uinput_ff_upload
impl Hash for uinput_setup
impl Hash for uinput_user_dev
impl Hash for xdp_desc
impl Hash for xdp_mmap_offsets
impl Hash for xdp_mmap_offsets_v1
impl Hash for xdp_options
impl Hash for xdp_ring_offset
impl Hash for xdp_ring_offset_v1
impl Hash for xdp_statistics
impl Hash for xdp_statistics_v1
impl Hash for xdp_umem_reg
impl Hash for xdp_umem_reg_v1
impl Hash for xsk_tx_metadata_completion
impl Hash for xsk_tx_metadata_request
impl Hash for Elf32_Ehdr
impl Hash for Elf32_Phdr
impl Hash for Elf32_Shdr
impl Hash for Elf32_Sym
impl Hash for Elf64_Ehdr
impl Hash for Elf64_Phdr
impl Hash for Elf64_Shdr
impl Hash for Elf64_Sym
impl Hash for __c_anonymous_elf32_rel
impl Hash for __c_anonymous_elf32_rela
impl Hash for __c_anonymous_elf64_rel
impl Hash for __c_anonymous_elf64_rela
impl Hash for __c_anonymous_ifru_map
impl Hash for arpd_request
impl Hash for cpu_set_t
impl Hash for dirent64
impl Hash for dirent
impl Hash for dl_phdr_info
impl Hash for fsid_t
impl Hash for glob_t
impl Hash for in6_pktinfo
impl Hash for itimerspec
impl Hash for mntent
impl Hash for option
impl Hash for packet_mreq
impl Hash for passwd
impl Hash for regmatch_t
impl Hash for rlimit64
impl Hash for sembuf
impl Hash for spwd
impl Hash for ucred
impl Hash for Dl_info
impl Hash for addrinfo
impl Hash for arphdr
impl Hash for arpreq
impl Hash for arpreq_old
impl Hash for epoll_event
extra_traits and non-L4Re only.impl Hash for fd_set
impl Hash for file_clone_range
impl Hash for if_nameindex
impl Hash for ifaddrs
impl Hash for in6_rtmsg
impl Hash for in_addr
impl Hash for in_pktinfo
impl Hash for ip_mreq
impl Hash for ip_mreq_source
impl Hash for ip_mreqn
impl Hash for lconv
impl Hash for mmsghdr
impl Hash for sched_param
impl Hash for sigevent
extra_traits and non-L4Re only.impl Hash for sock_filter
impl Hash for sock_fprog
impl Hash for sockaddr
impl Hash for sockaddr_in6
impl Hash for sockaddr_in
impl Hash for sockaddr_ll
impl Hash for sockaddr_storage
impl Hash for sockaddr_un
impl Hash for statx
impl Hash for statx_timestamp
impl Hash for tm
impl Hash for utsname
impl Hash for group
impl Hash for hostent
impl Hash for in6_addr
impl Hash for iovec
impl Hash for ipv6_mreq
impl Hash for itimerval
impl Hash for linger
impl Hash for pollfd
impl Hash for protoent
impl Hash for rlimit
impl Hash for rusage
impl Hash for servent
impl Hash for sigval
impl Hash for timeval
impl Hash for tms
impl Hash for utimbuf
impl Hash for winsize
impl Hash for MachineId
impl Hash for metrics::key::Key
impl Hash for KeyName
impl Hash for Label
impl Hash for StreamResult
impl Hash for mio::token::Token
impl Hash for Config
impl Hash for DebouncedEvent
impl Hash for notify_types::event::Event
impl Hash for EventKindMask
impl Hash for BigInt
impl Hash for BigUint
impl Hash for TimeDiff
impl Hash for CMSOptions
impl Hash for Nid
impl Hash for OcspFlag
impl Hash for KeyIvPair
impl Hash for Pkcs7Flags
impl Hash for ExtensionContext
impl Hash for ShutdownState
impl Hash for SslMode
impl Hash for SslOptions
impl Hash for SslSessionCacheMode
impl Hash for SslVerifyMode
impl Hash for X509CheckFlags
impl Hash for X509VerifyFlags
impl Hash for RawOsStr
impl Hash for RawOsString
impl Hash for PotentialCodePoint
impl Hash for NonUtf8Error
impl Hash for TooLargeBufferRequiredError
impl Hash for UnexpectedNullPointerError
impl Hash for PwdGrp
impl Hash for RealEffectiveSavedIds
impl Hash for LazyStateID
impl Hash for Transition
impl Hash for NonMaxUsize
impl Hash for regex_automata::util::primitives::PatternID
impl Hash for SmallIndex
impl Hash for regex_automata::util::primitives::StateID
impl Hash for HalfMatch
impl Hash for regex_automata::util::search::Match
impl Hash for regex_automata::util::search::Span
impl Hash for RsaPrivateKey
impl Hash for rsa::key::RsaPublicKey
impl Hash for rustix::backend::event::epoll::CreateFlags
impl Hash for EventFlags
impl Hash for PollFlags
impl Hash for EventfdFlags
impl Hash for rustix::backend::fs::inotify::CreateFlags
impl Hash for ReadFlags
impl Hash for WatchFlags
impl Hash for Access
impl Hash for AtFlags
impl Hash for FallocateFlags
impl Hash for MemfdFlags
impl Hash for Mode
impl Hash for OFlags
impl Hash for RenameFlags
impl Hash for ResolveFlags
impl Hash for SealFlags
impl Hash for StatVfsMountFlags
impl Hash for rustix::backend::io::errno::Errno
impl Hash for DupFlags
impl Hash for FdFlags
impl Hash for ReadWriteFlags
impl Hash for SocketAddrUnix
impl Hash for RecvFlags
impl Hash for ReturnFlags
impl Hash for SendFlags
impl Hash for PipeFlags
impl Hash for SpliceFlags
impl Hash for TimerfdFlags
impl Hash for TimerfdTimerFlags
impl Hash for rustix::event::epoll::Event
impl Hash for IFlags
impl Hash for StatxAttributes
impl Hash for StatxFlags
impl Hash for XattrFlags
impl Hash for InlinedName
impl Hash for SocketAddrAny
impl Hash for Ipv4PathMtuDiscovery
impl Hash for Ipv6PathMtuDiscovery
impl Hash for SocketAddrNetlink
impl Hash for AddressFamily
impl Hash for Protocol
impl Hash for SocketFlags
impl Hash for SocketType
impl Hash for TxTimeFlags
impl Hash for rustix::net::types::UCred
impl Hash for SocketAddrXdp
impl Hash for SocketAddrXdpFlags
impl Hash for XdpDesc
impl Hash for XdpDescOptions
impl Hash for XdpMmapOffsets
impl Hash for XdpOptions
impl Hash for XdpOptionsFlags
impl Hash for XdpRingFlags
impl Hash for XdpRingOffset
impl Hash for XdpStatistics
impl Hash for XdpUmemReg
impl Hash for XdpUmemRegFlags
impl Hash for rustix::pid::Pid
impl Hash for PidfdFlags
impl Hash for PidfdGetfdFlags
impl Hash for FloatingPointEmulationControl
impl Hash for FloatingPointExceptionMode
impl Hash for SpeculationFeatureControl
impl Hash for SpeculationFeatureState
impl Hash for UnalignedAccessControl
impl Hash for WaitIdOptions
impl Hash for WaitOptions
impl Hash for ControlModes
impl Hash for InputModes
impl Hash for LocalModes
impl Hash for OutputModes
impl Hash for SpecialCodeIndex
impl Hash for Winsize
impl Hash for rustix::ugid::Gid
impl Hash for rustix::ugid::Uid
impl Hash for rustls_pki_types::server_name::Ipv4Addr
impl Hash for rustls_pki_types::server_name::Ipv6Addr
impl Hash for UnixTime
impl Hash for Handle
impl Hash for ByteBuf
impl Hash for serde_bytes::bytes::Bytes
impl Hash for Map<String, Value>
impl Hash for Number
impl Hash for SigId
impl Hash for DefaultKey
impl Hash for slotmap::KeyData
impl Hash for SockAddr
impl Hash for AlgorithmName
impl Hash for DsaPublicKey
impl Hash for Ed25519PublicKey
impl Hash for OpaquePublicKey
impl Hash for OpaquePublicKeyBytes
impl Hash for ssh_key_fork_arti::public::rsa::RsaPublicKey
impl Hash for SkEcdsaSha2NistP256
impl Hash for SkEd25519
impl Hash for ssh_key_fork_arti::public::PublicKey
impl Hash for sysinfo::common::Gid
impl Hash for sysinfo::common::Uid
impl Hash for sysinfo::common::system::Pid
impl Hash for Date
impl Hash for time::duration::Duration
impl Hash for ComponentRange
impl Hash for OffsetDateTime
impl Hash for PrimitiveDateTime
impl Hash for Time
impl Hash for UtcDateTime
impl Hash for UtcOffset
impl Hash for tokio::net::unix::ucred::UCred
impl Hash for tokio::runtime::id::Id
impl Hash for tokio::runtime::task::id::Id
impl Hash for SignalKind
impl Hash for tokio::time::instant::Instant
impl Hash for AnyDelimiterCodec
impl Hash for BytesCodec
impl Hash for LinesCodec
impl Hash for toml::de::error::Error
impl Hash for TomlError
impl Hash for InternalString
impl Hash for toml_edit::key::Key
impl Hash for RawString
impl Hash for Decor
impl Hash for Repr
impl Hash for toml_parser::lexer::token::Token
impl Hash for toml_parser::parser::event::Event
impl Hash for toml_parser::source::Span
impl Hash for ByteQty
impl Hash for CircId
impl Hash for DosParams
impl Hash for StreamId
impl Hash for Listen
impl Hash for DisfavouredKey
impl Hash for BridgeConfig
impl Hash for SeedHead
impl Hash for ArtiPath
impl Hash for KeystoreId
impl Hash for BridgeAddr
impl Hash for PtTarget
impl Hash for PtTargetSettings
impl Hash for PtTransportName
impl Hash for TransportId
impl Hash for RsaIdentity
impl Hash for MpscSpec
impl Hash for MpscUnboundedSpec
impl Hash for EncodedAuthCert
impl Hash for AuthCertKeyIds
impl Hash for ConsensusMethod
impl Hash for IgnoredPublicationTimeSp
impl Hash for UnexpectedArgument
impl Hash for NoFurtherArguments
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdaNetworkStatusVersionFlavour
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdaVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdiVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdiVotingDelay
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdaNetworkStatusVersionFlavour
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdaVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdiVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdiVotingDelay
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdaNetworkStatusVersionFlavour
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdaVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdiVoteStatus
impl Hash for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdiVotingDelay
impl Hash for IsStructural
impl Hash for RelayFamily
impl Hash for B16
impl Hash for B16U
impl Hash for B64
impl Hash for Base64Fingerprint
impl Hash for Fingerprint
impl Hash for SpFingerprint
impl Hash for Hostname
impl Hash for IdentifiedDigest
impl Hash for Ignored
impl Hash for NotPresent
impl Hash for Iso8601TimeNoSp
impl Hash for Iso8601TimeSp
impl Hash for PortPolicy
impl Hash for PortRange
impl Hash for TorVersion
impl Hash for SlugRef
impl Hash for Iso8601TimeSlug
impl Hash for tor_proto::channel::unique_id::UniqId
impl Hash for tor_proto::circuit::unique_id::UniqId
impl Hash for ProtoKind
impl Hash for Protocols
impl Hash for TargetPort
impl Hash for ObjectId
impl Hash for CoarseDuration
impl Hash for CoarseInstant
impl Hash for SendMeVersion
impl Hash for tracing::span::Span
impl Hash for Identifier
impl Hash for Field
impl Hash for tracing_core::metadata::Level
impl Hash for tracing_core::metadata::LevelFilter
impl Hash for tracing_core::span::Id
impl Hash for ConstTypeId
no_const_type_id only.impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Z0
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for UncasedStr
impl Hash for Uncased<'_>
impl Hash for OpaqueOrigin
impl Hash for Url
URLs hash like their serialization.
impl Hash for winnow::stream::bstr::BStr
impl Hash for winnow::stream::bstr::BStr
impl Hash for winnow::stream::bytes::Bytes
impl Hash for winnow::stream::bytes::Bytes
impl Hash for Const
impl Hash for Mut
impl Hash for NullPtrError
impl Hash for x25519_dalek::x25519::PublicKey
impl Hash for CharULE
impl Hash for Index8
impl Hash for Index16
impl Hash for Index32
impl Hash for HsClientNickname
impl Hash for IptLocalId
impl Hash for IsCurrent
impl Hash for HsId
impl Hash for HsNickname
impl Hash for InvalidNickname
impl Hash for FutureTimestamp
impl Hash for tor_hsservice::time_store::ParseError
impl Hash for Reference
impl Hash for Ed25519Identity
impl Hash for tor_hsservice::internal_prelude::fmt::Error
impl Hash for FileType
impl Hash for ByteString
impl Hash for CString
impl Hash for String
impl Hash for Layout
impl Hash for TypeId
impl Hash for ByteStr
impl Hash for CStr
impl Hash for PhantomPinned
impl Hash for Alignment
impl Hash for core::net::ip_addr::Ipv4Addr
impl Hash for core::net::ip_addr::Ipv6Addr
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for RangeFull
impl Hash for Location<'_>
impl Hash for OsString
impl Hash for std::os::unix::net::ucred::UCred
impl Hash for PrefixComponent<'_>
impl Hash for ThreadId
impl Hash for ArtiPathRange
impl Hash for tor_hsservice::internal_prelude::Duration
impl Hash for HsBlindId
impl Hash for tor_hsservice::internal_prelude::Instant
impl Hash for OsStr
impl Hash for tor_hsservice::internal_prelude::Path
impl Hash for tor_hsservice::internal_prelude::PathBuf
impl Hash for RelayIds
impl Hash for Slug
impl Hash for SystemTime
impl Hash for TimePeriod
impl Hash for __c_anonymous_ptrace_syscall_info_data
extra_traits only.impl Hash for EventData
impl<'a> Hash for ServerName<'a>
impl<'a> Hash for RelayIdRef<'a>
impl<'a> Hash for KeystoreSelector<'a>
impl<'a> Hash for Component<'a>
impl<'a> Hash for Prefix<'a>
impl<'a> Hash for Oid<'a>
impl<'a> Hash for NonBlocking<'a>
impl<'a> Hash for Metadata<'a>
impl<'a> Hash for MetadataBuilder<'a>
impl<'a> Hash for DnsName<'a>
impl<'a> Hash for CertificateDer<'a>
impl<'a> Hash for CertificateRevocationListDer<'a>
impl<'a> Hash for CertificateSigningRequestDer<'a>
impl<'a> Hash for Der<'a>
impl<'a> Hash for EchConfigListBytes<'a>
impl<'a> Hash for SubjectPublicKeyInfoDer<'a>
impl<'a> Hash for TrustAnchor<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a, M, T, O> Hash for PartialElement<'a, M, T, O>
tarpaulin_include only.impl<'k> Hash for log::kv::key::Key<'k>
impl<'k> Hash for KeyMut<'k>
impl<'r, R> Hash for UnwrapMut<'r, R>
impl<'s> Hash for toml_writer::string::TomlKey<'s>
impl<'s> Hash for toml_writer::string::TomlString<'s>
impl<'s> Hash for SignatureHashInputs<'s>
impl<'s> Hash for TomlKey<'s>
impl<'s> Hash for TomlString<'s>
impl<A> Hash for SmallVec<A>
impl<A, B> Hash for figment::value::magic::Either<A, B>
impl<A, B> Hash for EitherOrBoth<A, B>
impl<A, O> Hash for BitArray<A, O>where
A: BitViewSized,
O: BitOrder,
tarpaulin_include only.impl<B> Hash for Cow<'_, B>
impl<B, C> Hash for ControlFlow<B, C>
impl<DataStruct> Hash for ErasedMarker<DataStruct>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> Hash for Fwhere
F: FnPtr,
impl<F> Hash for FlagSet<F>
impl<Idx> Hash for core::ops::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<Inner> Hash for Frozen<Inner>where
Inner: Hash + Mutability,
impl<K, V> Hash for EnumMap<K, V>
impl<K, V> Hash for indexmap::map::slice::Slice<K, V>
impl<K, V> Hash for TiSlice<K, V>where
V: Hash,
impl<K, V> Hash for TiVec<K, V>where
V: Hash,
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<K, V, S> Hash for LiteMap<K, V, S>
impl<L, R> Hash for either::Either<L, R>
impl<M, T> Hash for Address<M, T>where
M: Mutability,
T: ?Sized,
impl<M, T, O> Hash for BitRef<'_, M, T, O>
tarpaulin_include only.impl<M, T, O> Hash for BitPtrRange<M, T, O>
tarpaulin_include only.impl<M, T, O> Hash for BitPtr<M, T, O>
tarpaulin_include only.impl<O> Hash for F32<O>where
O: Hash,
impl<O> Hash for F64<O>where
O: Hash,
impl<O> Hash for I16<O>where
O: Hash,
impl<O> Hash for I32<O>where
O: Hash,
impl<O> Hash for I64<O>where
O: Hash,
impl<O> Hash for I128<O>where
O: Hash,
impl<O> Hash for Isize<O>where
O: Hash,
impl<O> Hash for U16<O>where
O: Hash,
impl<O> Hash for U32<O>where
O: Hash,
impl<O> Hash for U64<O>where
O: Hash,
impl<O> Hash for U128<O>where
O: Hash,
impl<O> Hash for Usize<O>where
O: Hash,
impl<Ptr> Hash for Pin<Ptr>
impl<R> Hash for BitEnd<R>where
R: Hash + BitRegister,
impl<R> Hash for BitIdx<R>where
R: Hash + BitRegister,
impl<R> Hash for BitIdxError<R>where
R: Hash + BitRegister,
impl<R> Hash for BitMask<R>where
R: Hash + BitRegister,
impl<R> Hash for BitPos<R>where
R: Hash + BitRegister,
impl<R> Hash for BitSel<R>where
R: Hash + BitRegister,
impl<R> Hash for UnwrapErr<R>where
R: Hash + TryRngCore,
impl<S> Hash for Host<S>where
S: Hash,
impl<S> Hash for Group<S>where
S: Hash,
impl<S> Hash for Passwd<S>where
S: Hash,
impl<Size> Hash for EncodedPoint<Size>where
Size: ModulusSize,
impl<Storage> Hash for aws_lc_sys::universal_crypto::__BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<Storage> Hash for linux_raw_sys::general::__BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<Storage> Hash for linux_raw_sys::net::__BindgenBitfieldUnit<Storage>where
Storage: Hash,
impl<T> Hash for BitPtrError<T>
impl<T> Hash for BitSpanError<T>
impl<T> Hash for ExplicitOrAuto<T>where
T: Hash + NotAutoValue,
impl<T> Hash for KeywordOrString<T>
impl<T> Hash for Unknown<T>where
T: Hash,
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for OverflowError<T>where
T: Hash,
impl<T> Hash for MisalignError<T>where
T: Hash,
impl<T> Hash for ByAddress<T>
Raw pointer hashing
impl<T> Hash for ByThinAddress<T>
Raw pointer hashing
impl<T> Hash for CachePadded<T>where
T: Hash,
impl<T> Hash for EnumSet<T>where
T: EnumSetType,
impl<T> Hash for AssertAsync<T>where
T: Hash,
impl<T> Hash for AllowStdIo<T>where
T: Hash,
impl<T> Hash for Serde<T>where
T: Hash,
impl<T> Hash for indexmap::set::slice::Slice<T>where
T: Hash,
impl<T> Hash for __BindgenUnionField<T>
impl<T> Hash for NotNan<T>where
T: Float,
impl<T> Hash for OrderedFloat<T>where
T: Float,
impl<T> Hash for BoxSensitive<T>where
T: Hash,
impl<T> Hash for Redacted<T>where
T: Redactable + Hash,
impl<T> Hash for Sensitive<T>where
T: Hash,
impl<T> Hash for serde_spanned::spanned::Spanned<T>where
T: Hash,
impl<T> Hash for serde_spanned::spanned::Spanned<T>where
T: Hash,
impl<T> Hash for Formatted<T>where
T: Hash,
impl<T> Hash for RetainedOrderVec<T>where
T: Hash,
impl<T> Hash for IntegerDays<T>where
T: Hash,
impl<T> Hash for IntegerMilliseconds<T>where
T: Hash,
impl<T> Hash for IntegerMinutes<T>where
T: Hash,
impl<T> Hash for IntegerSeconds<T>where
T: Hash,
impl<T> Hash for Percentage<T>
impl<T> Hash for TryWriteableInfallibleAsWriteable<T>where
T: Hash,
impl<T> Hash for WriteableAsTryWriteableInfallible<T>where
T: Hash,
impl<T> Hash for Unalign<T>
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for Discriminant<T>
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for SyncView<T>
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T, A> Hash for Box<T, A>
impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, E> Hash for Result<T, E>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, O> Hash for BitBox<T, O>
tarpaulin_include only.impl<T, O> Hash for BitSlice<T, O>
tarpaulin_include only.impl<T, O> Hash for BitVec<T, O>
tarpaulin_include only.impl<T, U> Hash for hybrid_array::Array<T, U>
impl<T, U> Hash for Flatten<T, U>
impl<T, const CAP: usize> Hash for ArrayVec<T, CAP>where
T: Hash,
impl<T, const LEN: usize, const REVERSE_STR: bool> Hash for amplify::collection::array::Array<T, LEN, REVERSE_STR>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));