pub(crate) enum IptEstablisherError {
Ipt(IptError),
NetdirProviderShutdown(NetdirProviderShutdown),
BuildCircuit(Error),
CircuitState(Error),
CreateEstablishIntro(Error),
EstablishTimeout,
SendEstablishIntro(Error),
ClosedWithoutAck,
Bug(Bug),
}Expand description
An error from trying to work with an IptEstablisher.
Variants
Ipt(IptError)
We encountered a faulty IPT.
NetdirProviderShutdown(NetdirProviderShutdown)
The network directory provider is shutting down without giving us the netdir we asked for.
BuildCircuit(Error)
We encountered an error while building a circuit to an intro point.
CircuitState(Error)
We encountered an error while querying the circuit state.
CreateEstablishIntro(Error)
We encountered an error while building and signing our establish_intro message.
EstablishTimeout
We encountered a timeout after building the circuit.
SendEstablishIntro(Error)
We encountered an error while sending our establish_intro message.
ClosedWithoutAck
We did not receive an INTRO_ESTABLISHED message like we wanted; instead, the circuit was closed.
Bug(Bug)
We encountered a programming error.
Implementations
Sourceimpl IptEstablisherError
impl IptEstablisherError
Sourcefn ipt_failure(&self) -> Option<&IptError>
fn ipt_failure(&self) -> Option<&IptError>
Return the underlying IptError if this error appears to be the introduction point’s fault.
This corresponds to IptStatusStatus::Faulty: when we return Some`,
it means that we should try another relay as an introduction point,
though we don’t necessarily need to give up on this one.
Note that the intro point may be to blame even if we return None;
we only return true when we are certain that the intro point is
unlisted, unusable, or misbehaving.