pub(crate) struct IptEstablisher {
_terminate_tx: Sender<Void>,
state: Arc<Mutex<EstablisherState>>,
}Expand description
Handle onto the task which is establishing and maintaining one IPT
Fields
_terminate_tx: Sender<Void>A oneshot sender which, when dropped, notifies the running task that it’s time to shut down.
state: Arc<Mutex<EstablisherState>>Mutable state shared with the Establisher, Reactor, and MsgHandler.
Implementations
Sourceimpl IptEstablisher
impl IptEstablisher
Sourcepub(crate) fn launch<R: Runtime>(
runtime: &R,
params: IptParameters,
pool: Arc<HsCircPool<R>>,
keymgr: &Arc<KeyMgr>,
) -> Result<(Self, Receiver<IptStatus>), FatalError>
pub(crate) fn launch<R: Runtime>( runtime: &R, params: IptParameters, pool: Arc<HsCircPool<R>>, keymgr: &Arc<KeyMgr>, ) -> Result<(Self, Receiver<IptStatus>), FatalError>
Try to set up, and maintain, an IPT at target.
Rendezvous requests will be rejected or accepted
depending on the value of accepting_requests
(which must be Advertised or NotAdvertised).
Also returns a stream of events that is produced whenever we have a change in the IptStatus for this intro point. Note that this stream is potentially lossy.
The returned watch::Receiver will yield Faulty if the IPT
establisher is shut down (or crashes).
When the resulting IptEstablisher is dropped, it will cancel all tasks
and close all circuits used to establish this introduction point.
Sourcepub(crate) fn start_accepting(&self)
pub(crate) fn start_accepting(&self)
Begin accepting requests from this introduction point.
If any introduction requests are sent before we have called this method, they are treated as an error and our connection to this introduction point is closed.