struct IptMsgHandler {
established_tx: Option<Sender<Result<IntroEstablished, IptEstablisherError>>>,
introduce_tx: Sender<RendRequest>,
request_context: Arc<RendRequestContext>,
state: Arc<Mutex<EstablisherState>>,
lid: IptLocalId,
replay_log: OwnedMutexGuard<ReplayLog<IptReplayLogType>>,
}Expand description
MsgHandler type to implement a conversation with an introduction point.
This, like all MsgHandlers, is installed at the circuit’s reactor, and used to handle otherwise unrecognized message types.
Fields
established_tx: Option<Sender<Result<IntroEstablished, IptEstablisherError>>>A oneshot sender used to report our IntroEstablished message.
If this is None, then we already sent an IntroEstablished and we shouldn’t send any more.
introduce_tx: Sender<RendRequest>A channel used to report Introduce2 messages.
request_context: Arc<RendRequestContext>Keys that we’ll need to answer the introduction requests.
state: Arc<Mutex<EstablisherState>>Mutable state shared with the Establisher, Reactor, and MsgHandler.
lid: IptLocalIdUnique identifier for the introduction point (including the current keys). Used to tag requests.
replay_log: OwnedMutexGuard<ReplayLog<IptReplayLogType>>A replay log used to detect replayed introduction requests.