pub(crate) struct IptParameters {
pub(crate) config_rx: Receiver<Arc<OnionServiceConfig>>,
pub(crate) netdir_provider: Arc<dyn NetDirProvider>,
pub(crate) introduce_tx: Sender<RendRequest>,
pub(crate) lid: IptLocalId,
pub(crate) replay_log: ReplayLog<IptReplayLogType>,
pub(crate) target: RelayIds,
pub(crate) k_sid: Arc<HsIntroPtSessionIdKeypair>,
pub(crate) accepting_requests: RequestDisposition,
pub(crate) k_ntor: Arc<HsSvcNtorKeypair>,
}Expand description
Parameters for an introduction point
Consumed by IptEstablisher::new.
Primarily serves as a convenient way to bundle the many arguments required.
Does not include:
- The runtime (which would force this struct to have a type parameter)
- The circuit builder (leaving this out makes it possible to use this
struct during mock execution, where we don’t call
IptEstablisher::new).
Fields
config_rx: Receiver<Arc<OnionServiceConfig>>A receiver that we can use to tell us about updates in our configuration.
Configuration changes may tell us to change our introduction points or build new circuits to them.
netdir_provider: Arc<dyn NetDirProvider>A NetDirProvider that we’ll use to find changes in the network
parameters, and to look up information about routers.
introduce_tx: Sender<RendRequest>A shared sender that we’ll use to report incoming INTRODUCE2 requests for rendezvous circuits.
lid: IptLocalIdOpaque local ID for this introduction point.
This ID does not change within the lifetime of an IptEstablisher.
See IptLocalId for information about what changes would require a
new ID (and hence a new IptEstablisher).
replay_log: ReplayLog<IptReplayLogType>Persistent log for INTRODUCE2 requests.
We use this to record the requests that we see, and to prevent replays.
target: RelayIdsA set of identifiers for the Relay that we intend to use as the introduction point.
We use this to identify the relay within a NetDir, and to make sure
we’re connecting to the right introduction point.
k_sid: Arc<HsIntroPtSessionIdKeypair>Keypair used to authenticate and identify ourselves to this introduction point.
Later, we publish the public component of this keypair in our HsDesc, and clients use it to tell the introduction point which introduction circuit should receive their requests.
This is the K_hs_ipt_sid keypair.
accepting_requests: RequestDispositionWhether this IptEstablisher should begin by accepting requests, or
wait to be told that requests are okay.
k_ntor: Arc<HsSvcNtorKeypair>Keypair used to decrypt INTRODUCE2 requests from clients.
This is the K_hss_ntor keypair, used with the “HS_NTOR” handshake to
form a shared key set of keys with the client, and decrypt information
about the client’s chosen rendezvous point and extensions.