pub(crate) struct IptStatus {
pub(crate) status: IptStatusStatus,
pub(crate) wants_to_retire: Result<(), IptWantsToRetire>,
pub(crate) failing_since: Option<Instant>,
}Expand description
The current status of an introduction point.
Fields
status: IptStatusStatusThe current state of this introduction point as defined by
hssvc-ipt-algorithms.md.
TODO (#1235): Make that file unneeded.
wants_to_retire: Result<(), IptWantsToRetire>The current status of whether this introduction point circuit wants to be retired based on having processed too many requests.
failing_since: Option<Instant>If Some, a time after which all attempts have been unsuccessful.
Implementations
Sourceimpl IptStatus
impl IptStatus
Sourcefn note_open(&mut self, ipt_details: GoodIptDetails)
fn note_open(&mut self, ipt_details: GoodIptDetails)
Record that we have successfully connected to an introduction point.
Sourcefn note_attempt(&mut self)
fn note_attempt(&mut self)
Record that we are trying to connect to an introduction point.
Sourcefn note_error(&mut self, err: &IptEstablisherError, now: Instant)
fn note_error(&mut self, err: &IptEstablisherError, now: Instant)
Record that an error has occurred.
Sourcefn new() -> Self
fn new() -> Self
Return an IptStatus representing an establisher that has not yet taken
any action.
Sourcefn new_terminated() -> Self
fn new_terminated() -> Self
Produce an IptStatus representing a shut down or crashed establisher