pub(crate) struct State<R, M> {
new_configs: Receiver<Arc<OnionServiceConfig>>,
current_config: Arc<OnionServiceConfig>,
status_recv: Receiver<(IptLocalId, IptStatus)>,
irelays: Vec<IptRelay>,
last_irelay_selection_outcome: Result<(), ()>,
ipt_removal_cleanup_needed: bool,
shutdown: Receiver<Void>,
storage: StorageHandle<StateRecord>,
mockable: M,
runtime: PhantomData<R>,
}Expand description
State of an IPT Manager
Fields
new_configs: Receiver<Arc<OnionServiceConfig>>Source of configuration updates
current_config: Arc<OnionServiceConfig>Last configuration update we received
This is the snapshot of the config we are currently using. (Doing it this way avoids running our algorithms with a mixture of old and new config.)
status_recv: Receiver<(IptLocalId, IptStatus)>Channel for updates from IPT Establishers (receiver)
We arrange for all the updates to be multiplexed, as that makes handling them easy in our event loop.
irelays: Vec<IptRelay>State: selected relays
We append to this, and call retain on it,
so these are in chronological order of selection.
last_irelay_selection_outcome: Result<(), ()>Did we fail to select a relay last time?
This can only be caused (or triggered) by a busted netdir or config.
ipt_removal_cleanup_needed: boolHave we removed any IPTs but not yet cleaned up keys and logfiles?
shutdown: Receiver<Void>Signal for us to shut down
storage: StorageHandle<StateRecord>The on-disk state storage handle.
mockable: MMockable state, normally Real
This is in State so it can be passed mutably to tests,
even though the main code doesn’t need mut
since HsCircPool is a service with interior mutability.
runtime: PhantomData<R>Runtime (to placate compiler)
Implementations
Sourceimpl<R: Runtime, M: Mockable<R>> State<R, M>
impl<R: Runtime, M: Mockable<R>> State<R, M>
Sourcefn ipt_by_lid_mut(&mut self, needle: IptLocalId) -> Option<&mut Ipt>
fn ipt_by_lid_mut(&mut self, needle: IptLocalId) -> Option<&mut Ipt>
Find the Ipt with persistent local id lid
Sourcefn choose_new_ipt_relay(
&mut self,
imm: &Immutable<R>,
now: Instant,
) -> Result<(), ChooseIptError>
fn choose_new_ipt_relay( &mut self, imm: &Immutable<R>, now: Instant, ) -> Result<(), ChooseIptError>
Choose a new relay to use for IPTs
Sourcefn handle_ipt_status_update(
&mut self,
imm: &Immutable<R>,
lid: IptLocalId,
update: IptStatus,
)
fn handle_ipt_status_update( &mut self, imm: &Immutable<R>, lid: IptLocalId, update: IptStatus, )
Update self’s status tracking for one introduction point