pub(crate) struct IptsManagerView {
shared: Arc<Mutex<PublishIptSet>>,
notify: Sender<()>,
}Expand description
Shared view of introduction points - IPT manager’s view
This is the manager’s end of a bidirectional “channel”,
containing a shared PublishIptSet, i.e. an Option<IptSet>.
Fields
Actual shared data
notify: Sender<()>Notification sender
We don’t wrap the state in a postage::watch, because the publisher needs to be able to mutably borrow the data without re-notifying itself when it drops the guard.
Implementations
Sourceimpl IptsManagerView
impl IptsManagerView
Sourcepub(crate) fn borrow_for_update(
&mut self,
runtime: impl SleepProvider,
) -> impl DerefMut<Target = PublishIptSet> + '_
pub(crate) fn borrow_for_update( &mut self, runtime: impl SleepProvider, ) -> impl DerefMut<Target = PublishIptSet> + '_
Arrange to be able to update the list of introduction points
The manager may add new ipts, or delete old ones.
The returned value is a lock guard.
(It is not Send so cannot be held across await points.)
The publisher will be notified when it is dropped.
Sourcepub(crate) fn borrow_for_read(
&mut self,
) -> impl Deref<Target = PublishIptSet> + '_
pub(crate) fn borrow_for_read( &mut self, ) -> impl Deref<Target = PublishIptSet> + '_
Peek at the list of introduction points we are providing to the publisher
(Used for testing and during startup.)