pub(crate) struct IptsPublisherView {
shared: Arc<Mutex<PublishIptSet>>,
notify: Receiver<()>,
}Expand description
Shared view of introduction points - IPT publisher’s view
This is the publishers’s end of a bidirectional “channel”,
containing a shared PublishIptSet, i.e. an Option<IptSet>.
Fields
Actual shared data
notify: Receiver<()>Notification receiver
Implementations
Sourceimpl IptsPublisherView
impl IptsPublisherView
Sourcepub(crate) async fn await_update(&mut self) -> Option<Result<(), FatalError>>
pub(crate) async fn await_update(&mut self) -> Option<Result<(), FatalError>>
Wait until the IPT set has changed (or may have)
After this returns, to find out what the new IPT set is,
the publisher calls borrow_for_publish.
Will complete immediately if the IPT set has
changed since the last call to await_update.
Returns:
Some(Ok(())if the IPT set was (or may have been) updatedNoneif the manager is shutting down and the publisher should shut down tooSome(Err(..))if a fatal error occurred
Sourcepub(crate) fn borrow_for_publish(
&self,
) -> impl DerefMut<Target = PublishIptSet> + '_
pub(crate) fn borrow_for_publish( &self, ) -> impl DerefMut<Target = PublishIptSet> + '_
Look at the list of introduction points to publish
Whenever a publication attempt is started
note_publication_attempt
must be called on this same IptSet.
The returned value is a lock guard.
(It is not Send so cannot be held across await points.)
Sourcepub(crate) fn upload_view(&self) -> IptsPublisherUploadView
pub(crate) fn upload_view(&self) -> IptsPublisherUploadView
Obtain an IptsPublisherUploadView, for use just prior to a publication attempt