fn maybe_expand_path(p: &CfgPath, r: &CfgPathResolver) -> Option<PathBuf>Expand description
Try to expand a path, logging a warning on failure.
fn maybe_expand_path(p: &CfgPath, r: &CfgPathResolver) -> Option<PathBuf>Try to expand a path, logging a warning on failure.