read_blind_id_keypair

Function read_blind_id_keypair 

pub(super) fn read_blind_id_keypair(
    keymgr: &Arc<KeyMgr>,
    nickname: &HsNickname,
    period: TimePeriod,
) -> Result<Option<HsBlindIdKeypair>, FatalError>
Try to read the blinded identity key for a given TimePeriod.

Returns None if the service is running in “offline” mode.