pub(crate) struct Real<R: Runtime>(Arc<HsCircPool<R>>);Expand description
The real version of the mockable state of the reactor.
Tuple Fields
0: Arc<HsCircPool<R>>Trait Implementations
Sourceimpl<R: Runtime> From<Arc<HsCircPool<R>>> for Real<R>
impl<R: Runtime> From<Arc<HsCircPool<R>>> for Real<R>
Sourcefn from(value: Arc<HsCircPool<R>>) -> Self
fn from(value: Arc<HsCircPool<R>>) -> Self
Converts to this type from the input type.
Sourceimpl<R: Runtime> Mockable for Real<R>
impl<R: Runtime> Mockable for Real<R>
Sourcetype Tunnel = ServiceOnionServiceDirTunnel
type Tunnel = ServiceOnionServiceDirTunnel
The type of client circuit.
Sourcefn thread_rng(&self) -> Self::Rng
fn thread_rng(&self) -> Self::Rng
Return a random number generator.
Sourcefn get_or_launch_hs_dir<'life0, 'life1, 'async_trait, T>(
&'life0 self,
netdir: &'life1 NetDir,
target: T,
) -> Pin<Box<dyn Future<Output = Result<Self::Tunnel, Error>> + Send + 'async_trait>>where
T: CircTarget + Send + Sync + 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_or_launch_hs_dir<'life0, 'life1, 'async_trait, T>(
&'life0 self,
netdir: &'life1 NetDir,
target: T,
) -> Pin<Box<dyn Future<Output = Result<Self::Tunnel, Error>> + Send + 'async_trait>>where
T: CircTarget + Send + Sync + 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Create a circuit of the specified
kind to target.Sourcefn estimate_upload_timeout(&self) -> Duration
fn estimate_upload_timeout(&self) -> Duration
Return an estimate-based value for how long we should allow a single
directory upload operation to complete. Read more