pub(crate) struct Publisher<R: Runtime, M: Mockable> {
runtime: R,
nickname: HsNickname,
dir_provider: Arc<dyn NetDirProvider>,
mockable: M,
config: Arc<OnionServiceConfig>,
ipt_watcher: IptsPublisherView,
config_rx: Receiver<Arc<OnionServiceConfig>>,
keymgr: Arc<KeyMgr>,
status_tx: PublisherStatusSender,
path_resolver: Arc<CfgPathResolver>,
pow_manager: Arc<PowManagerGeneric<R, RendRequest>>,
update_from_pow_manager_rx: Receiver<TimePeriod>,
}Expand description
A handle for the Hsdir Publisher for an onion service.
This handle represents a set of tasks that identify the hsdirs for each relevant time period, construct descriptors, publish them, and keep them up-to-date.
Fields
runtime: RThe runtime.
nickname: HsNicknameThe service for which we’re publishing descriptors.
dir_provider: Arc<dyn NetDirProvider>A source for new network directories that we use to determine our HsDirs.
mockable: MMockable state.
This is used for launching circuits and for obtaining random number generators.
config: Arc<OnionServiceConfig>The onion service config.
ipt_watcher: IptsPublisherViewA channel for receiving IPT change notifications.
config_rx: Receiver<Arc<OnionServiceConfig>>A channel for receiving onion service config change notifications.
keymgr: Arc<KeyMgr>The key manager.
status_tx: PublisherStatusSenderA sender for updating the status of the onion service.
path_resolver: Arc<CfgPathResolver>Path resolver for configuration files.
pow_manager: Arc<PowManagerGeneric<R, RendRequest>>Proof-of-work state
update_from_pow_manager_rx: Receiver<TimePeriod>Queue on which we receive messages from the PowManager telling us that a seed has
rotated and thus we need to republish the descriptor for a particular time period.
Implementations
Sourceimpl<R: Runtime, M: Mockable> Publisher<R, M>
impl<R: Runtime, M: Mockable> Publisher<R, M>
Sourcepub(crate) fn new(
runtime: R,
nickname: HsNickname,
dir_provider: Arc<dyn NetDirProvider>,
mockable: impl Into<M>,
ipt_watcher: IptsPublisherView,
config_rx: Receiver<Arc<OnionServiceConfig>>,
status_tx: PublisherStatusSender,
keymgr: Arc<KeyMgr>,
path_resolver: Arc<CfgPathResolver>,
pow_manager: Arc<PowManagerGeneric<R, RendRequest>>,
update_from_pow_manager_rx: Receiver<TimePeriod>,
) -> Self
pub(crate) fn new( runtime: R, nickname: HsNickname, dir_provider: Arc<dyn NetDirProvider>, mockable: impl Into<M>, ipt_watcher: IptsPublisherView, config_rx: Receiver<Arc<OnionServiceConfig>>, status_tx: PublisherStatusSender, keymgr: Arc<KeyMgr>, path_resolver: Arc<CfgPathResolver>, pow_manager: Arc<PowManagerGeneric<R, RendRequest>>, update_from_pow_manager_rx: Receiver<TimePeriod>, ) -> Self
Create a new publisher.
When it launches, it will know no keys or introduction points, and will therefore not upload any descriptors.
The publisher won’t start publishing until you call Publisher::launch.
Sourcepub(crate) fn launch(self) -> Result<(), StartupError>
pub(crate) fn launch(self) -> Result<(), StartupError>
Launch the publisher reactor.