pub(crate) struct IntroRequest {
req: Introduce2,
key_gen: HsNtorHkdfKeyGenerator,
rend1_msg: Rendezvous1,
intro_payload: IntroduceHandshakePayload,
rend_point: VerbatimLinkSpecCircTarget<OwnedCircTarget>,
}Expand description
A decrypted request from an onion service client which we can choose to answer (or not).
This corresponds to a processed INTRODUCE2 message.
To accept this request, call its
establish_session method.
To reject this request, simply drop it.
Fields
req: Introduce2The introduce2 message itself. We keep this in case we want to look at the outer header.
key_gen: HsNtorHkdfKeyGeneratorThe key generator we’ll use to derive our shared keys with the client when creating a virtual hop.
rend1_msg: Rendezvous1The RENDEZVOUS1 message we’ll send to the rendezvous point.
(The rendezvous point will in turn send this to the client as a RENDEZVOUS2.)
intro_payload: IntroduceHandshakePayloadThe decrypted and parsed body of the introduce2 message.
rend_point: VerbatimLinkSpecCircTarget<OwnedCircTarget>The circuit target for the rendezvous point.
Implementations
Sourceimpl IntroRequest
impl IntroRequest
Sourcepub(crate) fn decrypt_from_introduce2(
req: Introduce2,
context: &RendRequestContext,
) -> Result<Self, IntroRequestError>
pub(crate) fn decrypt_from_introduce2( req: Introduce2, context: &RendRequestContext, ) -> Result<Self, IntroRequestError>
Try to decrypt an incoming Introduce2 request, using the set of keys provided.
Sourcepub(crate) async fn establish_session(
self,
filter: RequestFilter,
hs_pool: Arc<dyn RendCircConnector>,
provider: Arc<dyn NetDirProvider>,
) -> Result<OpenSession, EstablishSessionError>
pub(crate) async fn establish_session( self, filter: RequestFilter, hs_pool: Arc<dyn RendCircConnector>, provider: Arc<dyn NetDirProvider>, ) -> Result<OpenSession, EstablishSessionError>
Try to accept this client’s request.
To do so, we open a circuit to the client’s chosen rendezvous point, send it a RENDEZVOUS1 message, and wait for incoming BEGIN messages from the client.
Sourcepub(crate) fn intro_payload(&self) -> &IntroduceHandshakePayload
pub(crate) fn intro_payload(&self) -> &IntroduceHandshakePayload
Get the IntroduceHandshakePayload associated with this IntroRequest.