pub(crate) struct PersistFile {
file: BufWriter<File>,
needs_resynch: Result<(), ()>,
lock: Arc<LockFileGuard>,
}Expand description
Persistent state file, and associated data
Stored as ReplayLog.file.
Fields
file: BufWriter<File>A file logging fingerprints of the messages we have seen.
needs_resynch: Result<(), ()>Whether we had a possible partial write
See the comment inside ReplayLog::check_for_replay.
Ok means all is well.
Err means we may have written partial data to the actual file,
and need to make sure we’re back at a record boundary.
lock: Arc<LockFileGuard>Filesystem lock which must not be released until after we finish writing
Must come last so that the drop order is correct