PowNonceReplayLog

Type Alias PowNonceReplayLog 

pub(crate) type PowNonceReplayLog = ReplayLog<PowNonceReplayLogType>;
A ReplayLog for Proof-of-Work Nonces.

Aliased Type

pub(crate) struct PowNonceReplayLog {
    seen: Filter,
    file: Option<PersistFile>,
    replay_log_type: PhantomData<PowNonceReplayLogType>,
}

Fields

seen: Filter

The inner probabilistic data structure.

file: Option<PersistFile>

Persistent state file etc., if we’re persistent

If is is None, this RelayLog is ephemeral.

replay_log_type: PhantomData<PowNonceReplayLogType>

PhantomData so rustc doesn’t complain about the unused type param.

This type represents the type of data that we’re storing, as well as the type of the key/name for that data.