fn system_time_max() -> SystemTimeExpand description
Maximum value of SystemTime
Not a tight bound but tests guarantee no runtime panics.
fn system_time_max() -> SystemTimeMaximum value of SystemTime
Not a tight bound but tests guarantee no runtime panics.