pub struct FutureTimestamp {
offset: u64,
}Expand description
Representation of an absolute time, in the future, suitable for storing to disk
Only meaningful in combination with a Reference.
Obtain one of these from an Instant using Storing::store_future(),
and convert it back to an Instant with Loading::load_future(),
(Serialises as a representation of how many seconds this was into the future,
when it was stored - ie, with respect to the corresponding Reference;
in binary as a u64, in human readable formats as
T+ plus humantime’s formatting of the Duration in seconds.)
Fields
offset: u64How far this timestamp was in the future, when we stored it
Implementations