pub struct Loading {
inst: Instant,
elapsed: u64,
}Expand description
Context for loading Instants from disk
Obtained by Loading::start,
from a Reference
(loaded from disk alongside the converted timestamps).
Fields
inst: InstantThe current time when this Loading was created
elapsed: u64How long has elapsed, at inst, since the timestamps were stored
Implementations
Sourceimpl Loading
impl Loading
Sourcepub fn start(runtime: &impl SleepProvider, stored: Reference) -> Loading
pub fn start(runtime: &impl SleepProvider, stored: Reference) -> Loading
Sourcepub fn load_future(&self, stored: FutureTimestamp) -> Instant
pub fn load_future(&self, stored: FutureTimestamp) -> Instant
Convert a future Instant from a value saved on disk
If the Instant that was saved has since passed,
the returned value is the current time.
If the system clock is inaccurate (or was inaccurate when the timestamp was saved), the value may be wrong: but, regardless, the returned value will be no further in the future, than how far it was in the future when it was saved.
In other words, even in the presence of clock skew, the effect is, at worst, as if the local system’s clock has stood still, or has run very fast.
Sourcepub fn elapsed(&self) -> Duration
pub fn elapsed(&self) -> Duration
Returns how long has elapsed since the timestamps were stored
This depends on the system wall clock being right both when we stored, and now. In the presence of clock skew, may return a value which is far too large, or too small.
But, if the system wall clock seems to have gone backwards, returns zero.
The time is measured from when start was called.
If you need to know that time as an Instant,
use as_raw_parts.
Sourcepub fn as_raw_parts(&self) -> (u64, Instant)
pub fn as_raw_parts(&self) -> (u64, Instant)
Returns how long has elapsed, in seconds, and the Instant at which that was true
Returns number of seconds elapsed,
between when the timestamps were stored,
and the returned Instant.
See elapsed for details of clock skew handling.