pub struct TrackingInstantNow {
now: Instant,
earliest: Cell<Option<Duration>>,
}Expand description
Utility to track timeouts based on Instant (monotonic time)
Represents the current Instant (from when it was created).
See the module-level documentation for the general overview.
To calculate and check a timeout,
you can
calculate the future Instant at which you wish to wake up,
and compare it with a TrackingInstantNow,
via .cmp() or inequality operators and PartialOrd.
Or you can
use
.checked_sub()
to obtain a TrackingInstantOffsetNow.
Fields
now: InstantCurrent time
earliest: Cell<Option<Duration>>Duration until earliest time we should wake up
Implementations
Sourceimpl TrackingInstantNow
impl TrackingInstantNow
Sourcepub fn new(now: Instant) -> Self
pub fn new(now: Instant) -> Self
Creates a new timeout tracker, given a value for the current time
Sourcepub fn now(r: &impl SleepProvider) -> Self
pub fn now(r: &impl SleepProvider) -> Self
Creates a new timeout tracker from the current time as seen by a runtime
Sourcepub fn get_now_untracked(&self) -> Instant
pub fn get_now_untracked(&self) -> Instant
Return the “current time” value in use
If you do comparisons with this, they won’t be tracked, obviously.
Sourceimpl TrackingInstantNow
impl TrackingInstantNow
Sourcepub async fn wait_for_earliest(self, runtime: &impl SleepProvider)
pub async fn wait_for_earliest(self, runtime: &impl SleepProvider)
Wait for the earliest timeout implied by any of the comparisons
Waits until the earliest future time at which any of the comparisons performed might change their answer.
If there were no comparisons there are no timeouts, so we wait forever.
Sourceimpl TrackingInstantNow
impl TrackingInstantNow
Sourcefn cmp(&self, t: Instant) -> Ordering
fn cmp(&self, t: Instant) -> Ordering
Check if time t has been reached yet (and remember that we want to wake up then)
Also available via PartialOrd
Sourceimpl TrackingInstantNow
impl TrackingInstantNow
Sourcepub fn checked_sub(
&self,
offset: Duration,
) -> Option<TrackingInstantOffsetNow<'_>>
pub fn checked_sub( &self, offset: Duration, ) -> Option<TrackingInstantOffsetNow<'_>>
Return a tracker representing a specific offset before the current time
You can use this to pre-calculate an offset from the current time,
to compare other Instants with.
This can be convenient to avoid repetition; also, when working with checked time arithmetic, this can helpfully centralise the out-of-bounds error handling site.