pub struct TrackingNow {
instant: TrackingInstantNow,
system_time: TrackingSystemTimeNow,
}Expand description
Timeout tracker that can handle both Instants and SystemTimes
Internally, the two kinds of timeouts are tracked separately:
this contains a TrackingInstantNow and a TrackingSystemTimeNow.
Fields
instant: TrackingInstantNowFor Instants
system_time: TrackingSystemTimeNowFor SystemTimes
Implementations
Sourceimpl TrackingNow
impl TrackingNow
Sourcepub fn new(instant: Instant, system_time: SystemTime) -> TrackingNow
pub fn new(instant: Instant, system_time: SystemTime) -> TrackingNow
Creates a new combined timeout tracker, given values for the current time
Sourcepub fn now(r: &impl SleepProvider) -> Self
pub fn now(r: &impl SleepProvider) -> Self
Creates a new timeout tracker from the current times as seen by a runtime
Sourcepub fn instant(&self) -> &TrackingInstantNow
pub fn instant(&self) -> &TrackingInstantNow
Access the specific timeout tracker for Instant
Sourcepub fn system_time(&self) -> &TrackingSystemTimeNow
pub fn system_time(&self) -> &TrackingSystemTimeNow
Access the specific timeout tracker for SystemTime
Sourceimpl TrackingNow
impl TrackingNow
Sourcepub async fn wait_for_earliest(self, runtime: &impl SleepProvider)
pub async fn wait_for_earliest(self, runtime: &impl SleepProvider)
Wait for the earliest timeout implied by any of the comparisons
Waits until the earliest future time at which any of the comparisons performed might change their answer.
If there were no comparisons there are no timeouts, so we wait forever.
Sourceimpl TrackingNow
impl TrackingNow
Sourcepub fn checked_sub(
&self,
offset: Duration,
) -> Option<TrackingInstantOffsetNow<'_>>
pub fn checked_sub( &self, offset: Duration, ) -> Option<TrackingInstantOffsetNow<'_>>
Return a tracker representing an Instant a specific offset before the current time
See TrackingInstantNow::checked_sub() for more details.
Instant-only
The returned tracker handles only Instants,
for reasons relating to clock warps:
broadly, waiting for a particular SystemTime must always be done
by working with the future SystemTime at which to wake up;
whereas, waiting for a particular Instant can be done by calculating Durationss.
For the same reason there is no
.checked_sub() method on TrackingSystemTimeNow.