pub(crate) type LinkSpecs = Vec<EncodedLinkSpec>;Expand description
Convenience alias for link specifiers of an intro point
Aliased Type
pub(crate) struct LinkSpecs { /* private fields */ }pub(crate) type LinkSpecs = Vec<EncodedLinkSpec>;Convenience alias for link specifiers of an intro point
pub(crate) struct LinkSpecs { /* private fields */ }