pub(crate) fn negotiated_capabilities(
intro: &IntroduceHandshakePayload,
) -> Result<Protocols, IntroRequestError>Expand description
Return a set of capabilities requested by the client in an INTRODUCE2 message payload.
The returned set will include capabilities that areā¦
- Requested explicitly by using
SUBPROTOCOL_REQUEST - Requested implicitly by using
FLOWCTRL_CC
Returns an error if the client requested any capability that we do not support, or which may not be included in a list of requested protocols.