fn extend_key_map(
key_map: &mut BTreeMap<HsClientNickname, HsClientDescEncKey>,
keys: impl IntoIterator<Item = (HsClientNickname, HsClientDescEncKey)>,
)Expand description
Helper for extending a key map with additional keys.
Logs a warning if any of the keys are already present in the map.