pub struct Dir {
inner: Dir,
}dirfd)Expand description
An object providing access to a directory on the filesystem.
Directories are automatically closed when they go out of scope. Errors detected
on closing are ignored by the implementation of Drop.
Platform-specific behavior
On supported systems (including Windows and some UNIX-based OSes), this function acquires a
handle/file descriptor for the directory. This allows functions like Dir::open_file to
avoid TOCTOU errors when the directory itself is being moved.
On other systems, it stores an absolute path (see canonicalize()). In the latter case, no
TOCTOU guarantees are made.
Examples
Opens a directory and then a file inside it.
#![feature(dirfd)]
use std::{fs::Dir, io};
fn main() -> std::io::Result<()> {
let dir = Dir::open("foo")?;
let mut file = dir.open_file("bar.txt")?;
let contents = io::read_to_string(file)?;
assert_eq!(contents, "Hello, world!");
Ok(())
}Fields
inner: Dirdirfd)Implementations
Sourceimpl Dir
impl Dir
Sourcepub fn open<P>(path: P) -> Result<Dir, Error>
🔬This is a nightly-only experimental API. (dirfd)
pub fn open<P>(path: P) -> Result<Dir, Error>
dirfd)Attempts to open a directory at path in read-only mode.
Errors
This function will return an error if path does not point to an existing directory.
Other errors may also be returned according to OpenOptions::open.
Examples
#![feature(dirfd)]
use std::{fs::Dir, io};
fn main() -> std::io::Result<()> {
let dir = Dir::open("foo")?;
let mut f = dir.open_file("bar.txt")?;
let contents = io::read_to_string(f)?;
assert_eq!(contents, "Hello, world!");
Ok(())
}Sourcepub fn open_file<P>(&self, path: P) -> Result<File, Error>
🔬This is a nightly-only experimental API. (dirfd)
pub fn open_file<P>(&self, path: P) -> Result<File, Error>
dirfd)Attempts to open a file in read-only mode relative to this directory.
Errors
This function will return an error if path does not point to an existing file.
Other errors may also be returned according to OpenOptions::open.
Examples
#![feature(dirfd)]
use std::{fs::Dir, io};
fn main() -> std::io::Result<()> {
let dir = Dir::open("foo")?;
let mut f = dir.open_file("bar.txt")?;
let contents = io::read_to_string(f)?;
assert_eq!(contents, "Hello, world!");
Ok(())
}Trait Implementations
Sourceimpl AsFd for Dir
impl AsFd for Dir
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>