pub struct BorrowedBuf<'data> {
buf: &'data mut [MaybeUninit<u8>],
filled: usize,
init: bool,
}core_io_borrowed_buf)Expand description
A borrowed byte buffer which is incrementally filled.
This type makes it safer to work with MaybeUninit buffers, such as to read into a buffer
without having to initialize it first. It tracks the region of bytes that have been filled and
whether the unfilled region was initialized.
In summary, the contents of the buffer can be visualized as:
[ capacity ]
[ filled | unfilled (may be initialized) ]A BorrowedBuf is created around some existing data (or capacity for data) via a unique reference
(&mut). The BorrowedBuf can be configured (e.g., using clear or set_init), but cannot be
directly written. To write into the buffer, use unfilled to create a BorrowedCursor. The cursor
has write-only access to the unfilled portion of the buffer (you can think of it as a
write-only iterator).
The lifetime 'data is a bound on the lifetime of the underlying data.
Fields
buf: &'data mut [MaybeUninit<u8>]core_io_borrowed_buf)filled: usizecore_io_borrowed_buf)init: boolcore_io_borrowed_buf)Implementations
Sourceimpl<'data> BorrowedBuf<'data>
impl<'data> BorrowedBuf<'data>
Sourcepub fn capacity(&self) -> usize
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn capacity(&self) -> usize
core_io_borrowed_buf)Returns the total capacity of the buffer.
Sourcepub fn len(&self) -> usize
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn len(&self) -> usize
core_io_borrowed_buf)Returns the length of the filled part of the buffer.
Sourcepub fn is_init(&self) -> bool
🔬This is a nightly-only experimental API. (borrowed_buf_init)
pub fn is_init(&self) -> bool
borrowed_buf_init)Returns the length of the initialized part of the buffer.
Sourcepub fn filled(&self) -> &[u8] ⓘ
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn filled(&self) -> &[u8] ⓘ
core_io_borrowed_buf)Returns a shared reference to the filled portion of the buffer.
Sourcepub fn filled_mut(&mut self) -> &mut [u8] ⓘ
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn filled_mut(&mut self) -> &mut [u8] ⓘ
core_io_borrowed_buf)Returns a mutable reference to the filled portion of the buffer.
Sourcepub fn into_filled(self) -> &'data [u8] ⓘ
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn into_filled(self) -> &'data [u8] ⓘ
core_io_borrowed_buf)Returns a shared reference to the filled portion of the buffer with its original lifetime.
Sourcepub fn into_filled_mut(self) -> &'data mut [u8] ⓘ
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn into_filled_mut(self) -> &'data mut [u8] ⓘ
core_io_borrowed_buf)Returns a mutable reference to the filled portion of the buffer with its original lifetime.
Sourcepub fn unfilled<'this>(&'this mut self) -> BorrowedCursor<'this> ⓘ
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn unfilled<'this>(&'this mut self) -> BorrowedCursor<'this> ⓘ
core_io_borrowed_buf)Returns a cursor over the unfilled part of the buffer.
Sourcepub fn clear(&mut self) -> &mut BorrowedBuf<'data>
🔬This is a nightly-only experimental API. (core_io_borrowed_buf)
pub fn clear(&mut self) -> &mut BorrowedBuf<'data>
core_io_borrowed_buf)Clears the buffer, resetting the filled region to empty.
The contents of the buffer are not modified.
Sourcepub unsafe fn set_init(&mut self) -> &mut BorrowedBuf<'data>
🔬This is a nightly-only experimental API. (borrowed_buf_init)
pub unsafe fn set_init(&mut self) -> &mut BorrowedBuf<'data>
borrowed_buf_init)Asserts that the unfilled part of the buffer is initialized.
Safety
All the bytes of the buffer must be initialized.