pub(crate) trait FromStr: Sized {
type Err;
// Required method
fn from_str(s: &str) -> Result<Self, Self::Err>;
}Expand description
Parse a value from a string
FromStr’s from_str method is often used implicitly, through
str’s parse method. See parse’s documentation for examples.
FromStr does not have a lifetime parameter, and so you can only parse types
that do not contain a lifetime parameter themselves. In other words, you can
parse an i32 with FromStr, but not a &i32. You can parse a struct that
contains an i32, but not one that contains an &i32.
Input format and round-tripping
The input format expected by a type’s FromStr implementation depends on the type. Check the
type’s documentation for the input formats it knows how to parse. Note that the input format of
a type’s FromStr implementation might not necessarily accept the output format of its
Display implementation, and even if it does, the Display implementation may not be lossless
so the round-trip may lose information.
However, if a type has a lossless Display implementation whose output is meant to be
conveniently machine-parseable and not just meant for human consumption, then the type may wish
to accept the same format in FromStr, and document that usage. Having both Display and
FromStr implementations where the result of Display cannot be parsed with FromStr may
surprise users.
Examples
Basic implementation of FromStr on an example Point type:
use std::str::FromStr;
#[derive(Debug, PartialEq)]
struct Point {
x: i32,
y: i32
}
#[derive(Debug, PartialEq, Eq)]
struct ParsePointError;
impl FromStr for Point {
type Err = ParsePointError;
fn from_str(s: &str) -> Result<Self, Self::Err> {
let (x, y) = s
.strip_prefix('(')
.and_then(|s| s.strip_suffix(')'))
.and_then(|s| s.split_once(','))
.ok_or(ParsePointError)?;
let x_fromstr = x.parse::<i32>().map_err(|_| ParsePointError)?;
let y_fromstr = y.parse::<i32>().map_err(|_| ParsePointError)?;
Ok(Point { x: x_fromstr, y: y_fromstr })
}
}
let expected = Ok(Point { x: 1, y: 2 });
// Explicit call
assert_eq!(Point::from_str("(1,2)"), expected);
// Implicit calls, through parse
assert_eq!("(1,2)".parse(), expected);
assert_eq!("(1,2)".parse::<Point>(), expected);
// Invalid input string
assert!(Point::from_str("(1 2)").is_err());Required Associated Types
Required Methods
1.0.0 (const: unstable) · Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Parses a string s to return a value of this type.
If parsing succeeds, return the value inside Ok, otherwise
when the string is ill-formatted return an error specific to the
inside Err. The error type is specific to the implementation of the trait.
Examples
Basic usage with i32, a type that implements FromStr:
use std::str::FromStr;
let s = "5";
let x = i32::from_str(s).unwrap();
assert_eq!(5, x);Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl FromStr for Num
impl FromStr for Num
type Err = Either<ParseIntError, ParseFloatError>
Sourceimpl FromStr for log::LevelFilter
impl FromStr for log::LevelFilter
type Err = ParseLevelError
Sourceimpl FromStr for EcdsaCurve
impl FromStr for EcdsaCurve
type Err = LabelError
Sourceimpl FromStr for PaddingLevel
impl FromStr for PaddingLevel
type Err = ParseError
Sourceimpl FromStr for tor_general_addr::general::SocketAddr
impl FromStr for tor_general_addr::general::SocketAddr
type Err = AddrParseError
Sourceimpl FromStr for RelayIdType
impl FromStr for RelayIdType
type Err = RelayIdError
Sourceimpl FromStr for PtTargetAddr
impl FromStr for PtTargetAddr
type Err = BridgeAddrError
Sourceimpl FromStr for AuthCertVersion
impl FromStr for AuthCertVersion
type Err = ParseError
Sourceimpl FromStr for tor_netdoc::doc::netstatus::DirectorySignatureHashAlgo
impl FromStr for tor_netdoc::doc::netstatus::DirectorySignatureHashAlgo
type Err = ParseError
Sourceimpl FromStr for tor_netdoc::parse2::poc::netstatus::DirectorySignatureHashAlgo
impl FromStr for tor_netdoc::parse2::poc::netstatus::DirectorySignatureHashAlgo
type Err = ParseError
Sourceimpl FromStr for NdaNetworkStatusVersion
impl FromStr for NdaNetworkStatusVersion
type Err = ParseError
Sourceimpl FromStr for Ed25519AlgorithmString
impl FromStr for Ed25519AlgorithmString
type Err = FromStrError
Sourceimpl FromStr for InternetHost
impl FromStr for InternetHost
type Err = InvalidInternetHost
Sourceimpl FromStr for OverloadGeneralVersion
impl FromStr for OverloadGeneralVersion
type Err = ParseError
Sourceimpl FromStr for IptKeyRole
impl FromStr for IptKeyRole
type Err = ParseError
1.0.0 · Sourceimpl FromStr for core::net::socket_addr::SocketAddr
impl FromStr for core::net::socket_addr::SocketAddr
type Err = AddrParseError
Sourceimpl FromStr for AsciiString
impl FromStr for AsciiString
type Err = AsAsciiStrError
Sourceimpl FromStr for ed25519::Signature
Decode a signature from hexadecimal.
impl FromStr for ed25519::Signature
Decode a signature from hexadecimal.
Upper and lower case hexadecimal are both accepted, however mixed case is rejected.
Sourceimpl FromStr for HeaderName
impl FromStr for HeaderName
type Err = InvalidHeaderName
Sourceimpl FromStr for HeaderValue
impl FromStr for HeaderValue
type Err = InvalidHeaderValue
Sourceimpl FromStr for StatusCode
impl FromStr for StatusCode
type Err = InvalidStatusCode
Sourceimpl FromStr for PathAndQuery
impl FromStr for PathAndQuery
type Err = InvalidUri
Sourceimpl FromStr for icu_locale_core::extensions::private::other::Subtag
impl FromStr for icu_locale_core::extensions::private::other::Subtag
type Err = ParseError
Sourceimpl FromStr for icu_locale_core::extensions::transform::key::Key
impl FromStr for icu_locale_core::extensions::transform::key::Key
type Err = ParseError
Sourceimpl FromStr for SubdivisionId
impl FromStr for SubdivisionId
type Err = ParseError
Sourceimpl FromStr for SubdivisionSuffix
impl FromStr for SubdivisionSuffix
type Err = ParseError
Sourceimpl FromStr for AlgorithmName
impl FromStr for AlgorithmName
type Err = LabelError
Sourceimpl FromStr for ValueDeserializer
Available on crate feature parse only.
impl FromStr for ValueDeserializer
parse only.Sourceimpl FromStr for DocumentMut
Available on crate feature parse only.
impl FromStr for DocumentMut
parse only.Sourceimpl FromStr for ImDocument<String>
Available on crate feature parse only.
impl FromStr for ImDocument<String>
parse only.Sourceimpl FromStr for InternalString
impl FromStr for InternalString
type Err = Infallible
Sourceimpl FromStr for BridgeConfig
impl FromStr for BridgeConfig
type Err = BridgeParseError
Sourceimpl FromStr for BridgeConfigBuilder
BridgeConfigBuilder parses the same way as BridgeConfig
impl FromStr for BridgeConfigBuilder
BridgeConfigBuilder parses the same way as BridgeConfig
type Err = BridgeParseError
Sourceimpl FromStr for BridgeAddr
impl FromStr for BridgeAddr
type Err = BridgeAddrError
Sourceimpl FromStr for PtTransportName
impl FromStr for PtTransportName
type Err = TransportIdError
Sourceimpl FromStr for TransportId
impl FromStr for TransportId
type Err = TransportIdError
Sourceimpl FromStr for EncodedAuthCert
impl FromStr for EncodedAuthCert
type Err = ErrorProblem
Sourceimpl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdaVoteStatus
impl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::cons::NdaVoteStatus
Sourceimpl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdaVoteStatus
impl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::md::NdaVoteStatus
Sourceimpl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdaVoteStatus
impl FromStr for tor_netdoc::parse2::poc::netstatus::ns_per_flavour_macros::vote::NdaVoteStatus
Sourceimpl FromStr for ContactInfo
impl FromStr for ContactInfo
type Err = InvalidContactInfo
Sourceimpl FromStr for IdentifiedDigest
impl FromStr for IdentifiedDigest
Sourceimpl FromStr for AddrPortPattern
impl FromStr for AddrPortPattern
type Err = PolicyError
Sourceimpl FromStr for PortPolicy
impl FromStr for PortPolicy
type Err = PolicyError
Sourceimpl FromStr for Iso8601TimeSlug
impl FromStr for Iso8601TimeSlug
type Err = BadIso8601TimeSlug
Sourceimpl FromStr for Protocols
A Protocols set can be parsed from a string according to the
format used in Tor consensus documents.
impl FromStr for Protocols
A Protocols set can be parsed from a string according to the format used in Tor consensus documents.
A protocols set is represented by a space-separated list of
entries. Each entry is of the form Name=Versions, where Name
is the name of a protocol, and Versions is a comma-separated
list of version numbers and version ranges. Each version range is
a pair of integers separated by -.
No protocol name may be listed twice. No version may be listed twice for a single protocol. All versions must be in range 0 through 63 inclusive.
type Err = ParseError
Sourceimpl FromStr for tracing_core::metadata::LevelFilter
impl FromStr for tracing_core::metadata::LevelFilter
type Err = ParseLevelFilterError
Sourceimpl FromStr for Url
Parse a string as an URL, without a base URL or encoding override.
impl FromStr for Url
Parse a string as an URL, without a base URL or encoding override.
type Err = ParseError
Sourceimpl FromStr for AttributeTypeAndValue
Parse an AttributeTypeAndValue string.
impl FromStr for AttributeTypeAndValue
Parse an AttributeTypeAndValue string.
This function follows the rules in RFC 4514.
Sourceimpl FromStr for RdnSequence
Parse an RdnSequence string.
impl FromStr for RdnSequence
Parse an RdnSequence string.
Follows the rules in RFC 4514.
Sourceimpl FromStr for RelativeDistinguishedName
Parse a RelativeDistinguishedName string.
impl FromStr for RelativeDistinguishedName
Parse a RelativeDistinguishedName string.
This function follows the rules in RFC 4514.
Sourceimpl FromStr for IptLocalId
impl FromStr for IptLocalId
type Err = InvalidIptLocalId
Sourceimpl FromStr for HsNickname
impl FromStr for HsNickname
type Err = InvalidNickname
Sourceimpl FromStr for FutureTimestamp
impl FromStr for FutureTimestamp
type Err = ParseError
Sourceimpl FromStr for ByteString
impl FromStr for ByteString
type Err = Infallible
1.0.0 · Sourceimpl FromStr for String
Available on non-no_global_oom_handling only.
impl FromStr for String
no_global_oom_handling only.type Err = Infallible
1.5.0 · Sourceimpl FromStr for SocketAddrV4
impl FromStr for SocketAddrV4
type Err = AddrParseError
1.5.0 · Sourceimpl FromStr for SocketAddrV6
impl FromStr for SocketAddrV6
type Err = AddrParseError
Sourceimpl FromStr for HsClientDescEncKey
impl FromStr for HsClientDescEncKey
1.32.0 · Sourceimpl FromStr for tor_hsservice::internal_prelude::PathBuf
impl FromStr for tor_hsservice::internal_prelude::PathBuf
type Err = Infallible
Sourceimpl<C> FromStr for SigningKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Available on crate feature pem only.
impl<C> FromStr for SigningKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
<C as CurveArithmetic>::Scalar: Invert<Output = CtOption<<C as CurveArithmetic>::Scalar>> + SignPrimitive<C>,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
pem only.Sourceimpl<C> FromStr for ecdsa::Signature<C>where
C: PrimeCurve + CurveArithmetic,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
Available on crate feature arithmetic only.
impl<C> FromStr for ecdsa::Signature<C>where
C: PrimeCurve + CurveArithmetic,
<<C as Curve>::FieldBytesSize as Add>::Output: ArrayLength<u8>,
arithmetic only.Sourceimpl<C> FromStr for VerifyingKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate feature pem only.
impl<C> FromStr for VerifyingKey<C>where
C: PrimeCurve + AssociatedOid + CurveArithmetic + PointCompression,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
pem only.Sourceimpl<C> FromStr for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
Available on crate feature pem only.
impl<C> FromStr for elliptic_curve::public_key::PublicKey<C>where
C: AssociatedOid + CurveArithmetic,
<C as CurveArithmetic>::AffinePoint: FromEncodedPoint<C> + ToEncodedPoint<C>,
<C as Curve>::FieldBytesSize: ModulusSize,
pem only.Sourceimpl<C> FromStr for NonZeroScalar<C>where
C: CurveArithmetic,
impl<C> FromStr for NonZeroScalar<C>where
C: CurveArithmetic,
Sourceimpl<Size> FromStr for EncodedPoint<Size>where
Size: ModulusSize,
Decode a SEC1-encoded point from hexadecimal.
impl<Size> FromStr for EncodedPoint<Size>where
Size: ModulusSize,
Decode a SEC1-encoded point from hexadecimal.
Upper and lower case hexadecimal are both accepted, however mixed case is rejected.