struct RendRequestReceiverInner<R, Q> {Show 15 fields
queue: BTreeSet<RendRequestOrdByEffort<Q>>,
queue_pow_disabled: VecDeque<Q>,
waker: Option<Waker>,
runtime: R,
nickname: HsNickname,
netdir_provider: Arc<dyn NetDirProvider>,
config_rx: Receiver<Arc<OnionServiceConfig>>,
update_period_start: Instant,
num_enqueued_gte_suggested: usize,
num_dequeued: u32,
idle_time: Duration,
last_transition: Instant,
total_effort: u64,
suggested_effort: Arc<Mutex<Effort>>,
status_tx: PowManagerStatusSender,
}Expand description
Inner implementation for RendRequestReceiver.
Fields
queue: BTreeSet<RendRequestOrdByEffort<Q>>Internal priority queue of requests.
queue_pow_disabled: VecDeque<Q>Internal FIFO queue of requests used when PoW is disabled.
We have this here to support switching back and forth between PoW enabled and disabled at runtime, although that isn’t currently supported.
waker: Option<Waker>Waker to inform async readers when there is a new message on the queue.
runtime: RRuntime, used to get current time in a testable way.
nickname: HsNicknameNickname, use when reporting metrics.
netdir_provider: Arc<dyn NetDirProvider>NetDirProvider, for getting configuration values in consensus parameters.
config_rx: Receiver<Arc<OnionServiceConfig>>Current configuration, used to see whether PoW is enabled or not.
update_period_start: InstantWhen the current update period started.
num_enqueued_gte_suggested: usizeNumber of requests that were enqueued during the current update period, and had an effort greater than or equal to the suggested effort.
num_dequeued: u32Number of requests that were dequeued during the current update period.
idle_time: DurationAmount of time during the current update period that we spent with no requests in the queue.
last_transition: InstantTime that the queue last went from having items in it to not having items in it, or vice versa. This is used to update idle_time.
total_effort: u64Sum of all effort values that were validated and enqueued during the current update period.
suggested_effort: Arc<Mutex<Effort>>Most recent published suggested effort value.
We write to this, which is then published in the pow-params line by PowManagerGeneric.
status_tx: PowManagerStatusSenderSender for reporting back onion service status.