pub(super) fn build_sign<Rng: RngCore + CryptoRng, KeyRng: RngCore + EntropicRng, R: Runtime>(
keymgr: &Arc<KeyMgr>,
pow_manager: &Arc<PowManagerGeneric<R, RendRequest>>,
config: &Arc<OnionServiceConfigPublisherView>,
authorized_clients: Option<&BTreeMap<HsClientNickname, HsClientDescEncKey>>,
ipt_set: &IptSet,
period: TimePeriod,
revision_counter: RevisionCounter,
rng: &mut Rng,
key_rng: &mut KeyRng,
now: SystemTime,
max_hsdesc_len: usize,
) -> Result<VersionedDescriptor, FatalError>Expand description
Build the descriptor.
The now argument is used for computing the expiry of the intro_{auth, enc}_key_cert
certificates included in the descriptor. The expiry will be set to 54 hours from now.
Note: blind_id_kp is the blinded hidden service signing keypair used to sign descriptor
signing keys (KP_hs_blind_id, KS_hs_blind_id).