pub(crate) type IptReplayLog = ReplayLog<IptReplayLogType>;Expand description
A ReplayLog for Introduce2 messages.
Aliased Type
pub(crate) struct IptReplayLog {
seen: Filter,
file: Option<PersistFile>,
replay_log_type: PhantomData<IptReplayLogType>,
}Fields
seen: FilterThe inner probabilistic data structure.
file: Option<PersistFile>Persistent state file etc., if we’re persistent
If is is None, this RelayLog is ephemeral.
replay_log_type: PhantomData<IptReplayLogType>PhantomData so rustc doesn’t complain about the unused type param.
This type represents the type of data that we’re storing, as well as the type of the key/name for that data.